(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    140783,       2415]*)
(*NotebookOutlinePosition[    141520,       2440]*)
(*  CellTagsIndexPosition[    141476,       2436]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Options explorer", "Subsection"],

Cell[TextData[{
  "Here we assume that the package ",
  StyleBox["OptionsExplorer", "MR"],
  StyleBox["`", "MR"],
  " has been installed as it discribed in file ",
  StyleBox["Installation.nb", "MR"],
  " and there is no loading needed."
}], "Text"],

Cell["\<\
Options frequently used to describe parameters of function. Lets look on next \
example:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[Sin[2  x]/2]\)], "Input"],

Cell[BoxData[
    \(Cos[x]\ Sin[x]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Here the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function ",
  StyleBox["Simplify", "MR"],
  " factorized trigonometric expression. But this expression often preferred \
to set in a reduced form. This goal can be achived by toggling the value of \
option ",
  StyleBox["Trig", "MR"],
  ": "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[1/2\ Sin[2\ x], Trig \[Rule] False]\)], "Input"],

Cell[BoxData[
    \(1\/2\ Sin[2\ x]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This task can be done more easely with ",
  StyleBox["OptionsExplorer", "MR"],
  ". Select the expression (or put cursor just after it) and press \
\[AltKey]",
  StyleBox["\[KeyBar]", "MR"],
  "\[ControlKey]\[LeftModified]o\[RightModified] to open its dialog window. \
(The command shortcut present here is for OS Windows, in other OS use Command \
key instead of \[AltKey]). Another way to start dialog is using menu command \
",
  StyleBox["Input \[RightTriangle] Options Selector", "SR"],
  ". The described actions open the window:"
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007l0001BA000`40O003
h00Oob48oB4800000f]I@Q12403o@Q3i@Q018@P00003JeUoof]I0?m[FOQ[
F@52404Q200000=[FGooJeT0of]In6]I0D8@0B48000016]IOom[FF]Ioa[F
iA[F16]I00Eood8@@Q1[FGoo00924004JeUood8@@Q03JeT1@Q018@P00004
JeUoof]IJeWo6]KU6]H5JeT01Goo@Q1246]IOol00T8@00A[FGoo@Q12409[
F@52404Q200000A[FGooJeU[FOlJe^DJePI[F@05Oom2448@JeUoo`02@Q00
0f]IOom24002JeT1@Q018@P00004JeUoof]IJeWo6]KU6]H7JeT01Goo@Q12
46]IOol00T8@00E[FGooJeU[FD8@004Q200000A[FGooJeU[FOlJe^DJePQ[
F@05Oom2448@JeUoo`02@Q03JeT1@Q018@P00004JeUoof]IJeWo6]KU6]H9
JeT01Goo@Q1246]IOol00T8@0V]I0D8@0B48000016]IOom[FF]Ioa[FiA[F
2V]I00Iood8@@Q1[FGoo@Q02JeT1@Q018@P00004JeUoof]IJeWo6]KU6]H;
JeT01Goo@Q1246]IOol00V]I0D8@0B48000016]IOom[FF]Ioa[FiA[F36]I
00=ood8@@Q000f]I0D8@0B48000016]IOom[FF]Ioa[FiA[F3F]I00=ood8@
@Q000V]I0D8@0B48000016]IOom[FF]Ioa[FiA[F3V]I00Eood8@JeU[FD8@
004Q200000A[FGooJeU[FOlJe^DJePm[F@04Oom[FF]I@Q018@P00004JeUo
of]IJeWo6]KU6]HBJeT1@Q018@P00004JeUoof]IJeWo6]KU6]HBJeT1@Q01
8@P00004JeUoof]IJeWo6]KU6]HBJeT1@Q018@P00004JeUoof]IJeWo6]KU
6]HBJeT1@Q018@P00004JeUoof]IJeWo6]KU6]H@8@P2JeT1@Q018@P00004
JeUoof]IJeWo6]KU6]H00f]I@Q12400<@Q001248JeU[FD8@0B48000016]I
Oom[FF]Ioa[FiA[F00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[
FGooJeU[FOlJe^DJeP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004
JeUoof]IJeWo6]KU6]H00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B480000
16]IOom[FF]Ioa[FiA[F00=[FGooJeT02f]I00E24248JeU[FD8@004Q2000
00A[FGooJeU[FOlJe^DJeP03JeUoof]I00A[F@03001[FF]I00A[F@05@Q0Q
26]IJeU240018@P00004JeUoof]IJeWo6]KU6]H00f]IOom[F@03JeT30005
JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]Ioa[FiA[F00=[FGooJeT0
0V]I1@0016]I00E24248JeU[FD8@004Q200000A[FGooJeU[FOlJe^DJeP04
JeUoof]IJeT70003JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]Ioa[F
iA[F00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FOlJ
e^DJeP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeWo
6]KU6]H00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]I
oa[FiA[F00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[
FOlJe^DJeP03JeUoogoo00]oo`05@Q0Q26]IJeU240018@P00004JeUoof]I
JeWo6]KU6]H?JeT01248JeU[FD8@0B48000016]IOom[FF]Ioa[FiA[F00mo
of]IOom[FGooJeUoof]IOom[FGooJeUoof]IOol00f]I0D8@0B48000016]I
Oom[FF]Ioa[FiA[F011[FGooJeUoof]IOom[FGooJeUoof]IOom[FGooJeUo
o`9[F@52404Q200000A[FGooJeU[FOlJe^DJeP0?Oom[FGooJeUoof]IOom[
FGooJeUoof]IOom[FGoo00=[F@52404Q200000A[FGooJeU[FOlJe^DJeP0@
JeUoof]IOom[FGooJeUoof]IOom[FGooJeUoof]IOol2JeT1@Q018@P00004
JeUoof]IJeWo6]KU6]H03gooJeUoof]IOom[FGooJeUoof]IOom[FGooJeUo
o`03JeT1@Q018@P00004JeUoof]IJeWo6]KU6]H046]IOom[FGooJeUoof]I
Oom[FGooJeUoof]IOom[FGoo0V]I0D8@0B48000016]IOom[FF]Ioa[FiA[F
00moof]IOom[FGooJeUoof]IOom[FGooJeUoof]IOol00f]I0D8@0B480000
16]IOom[FF]Ioa[FiA[F011[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo
JeUoo`9[F@52404Q200000A[FGooJeU[FOlJe^DJeP0?Oom[FGooJeUoof]I
Oom[FGooJeUoof]IOom[FGoo00=[F@52404Q200000A[FGooJeU[FOlJe^DJ
eP0@JeUoof]IOom[FGooJeUoof]IOom[FGooJeUoof]IOol2JeT1@Q018@P0
0004JeUoof]IJeWo6]KU6]H03gooJeUoof]IOom[FGooJeUoof]IOom[FGoo
JeUoo`03JeT1@Q018@P00004JeUoof]IJeWo6]KU6]H046]IOom[FGooJeUo
of]IOom[FGooJeUoof]IOom[FGoo0V]I0D8@0B48000016]IOom[FF]Ioa[F
iA[F00moof]IOom[FGooJeUoof]IOom[FGooJeUoof]IOol00f]I0D8@0B48
000016]IOom[FF]Ioa[FiA[F011[FGooJeUoof]IOom[FGooJeUoof]IOom[
FGooJeUoo`9[F@52404Q200000A[FGooJeU[FOlJe^DJeP0?Oom[FGooJeUo
of]IOom[FGooJeUoof]IOom[FGoo00=[F@52404Q200000A[FGooJeU[FOlJ
e^DJeP0@JeUoof]IOom[FGooJeUoof]IOom[FGooJeUoof]IOol2JeT1@Q01
8@P00004JeUoof]IJeWo6]KU6]H03gooJeUoof]IOom[FGooJeUoof]IOom[
FGooJeUoo`03JeT1@Q018@P00004JeUoof]IJeWo6]KU6]H046]IOom[FGoo
JeUoof]IOom[FGooJeUoof]IOom[FGoo0V]I0D8@0B48000016]IOom[FF]I
oa[FiA[F00moof]IOom[FGooJeUoof]IOom[FGooJeUoof]IOol00f]I0D8@
0B48000016]IOom[FF]Ioa[FiA[F011[FGooJeUoof]IOom[FGooJeUoof]I
Oom[FGooJeUoo`9[F@52404Q200000A[FGooJeU[FOlJe^DJeP0?Oom[FGoo
JeUoof]IOom[FGooJeUoof]IOom[FGoo00=[F@52404Q200000A[FGooJeU[
FOlJe^DJeP0@JeUoof]IOom[FGooJeUoof]IOom[FGooJeUoof]IOol2JeT1
@Q018@P00004JeUoof]IJeWo6]KU6]H03gooJeUoof]IOom[FGooJeUoof]I
Oom[FGooJeUoo`03JeT1@Q018@P00004JeUoof]IJeWo6]KU6]H046]IOom[
FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo0V]I0D8@0B48000016]IOom[
FF]Ioa[FiA[F00moof]IOom[FGooJeUoof]IOom[FGooJeUoof]IOol00f]I
0D8@0B48000016]IOom[FF]Ioa[FiA[F011[FGooJeUoof]IOom[FGooJeUo
of]IOom[FGooJeUoo`9[F@52404Q200000A[FGooJeU[FOlJe^DJeP0?Oom[
FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo00=[F@52404Q200000A[FGoo
JeU[FOlJe^DJeP0@JeUoof]IOom[FGooJeUoof]IOom[FGooJeUoof]IOol2
JeT1@Q018@P00004JeUoof]IJeWo6]KU6]H03gooJeUoof]IOom[FGooJeUo
of]IOom[FGooJeUoo`03JeT1@Q018@P00004JeUoof]IJeWo6]KU6]H046]I
Oom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo0V]I0D8@0B48000016]I
Oom[FF]Ioa[FiA[F00moof]IOom[FGooJeUoof]IOom[FGooJeUoof]IOol0
0f]I0D8@0B48000016]IOom[FF]Ioa[FiA[F011[FGooJeUoof]IOom[FGoo
JeUoof]IOom[FGooJeUoo`9[F@52404Q200000A[FGooJeU[FOlJe^DJeP0?
Oom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo00=[F@52404Q200000A[
FGooJeU[FOlJe^DJeP0@JeUoof]IOom[FGooJeUoof]IOom[FGooJeUoof]I
Ool2JeT1@Q018@P00004JeUoof]IJeWo6]KU6]H03gooJeUoof]IOom[FGoo
JeUoof]IOom[FGooJeUoo`03JeT1@Q018@P00004JeUoof]IJeWo6]KU6]H0
46]IOom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo0V]I0D8@0B480000
16]IOom[FF]Ioa[FiA[F00moof]IOom[FGooJeUoof]IOom[FGooJeUoof]I
Ool00f]I0D8@0B48000016]IOom[FF]Ioa[FiA[F011[FGooJeUoof]IOom[
FGooJeUoof]IOom[FGooJeUoo`9[F@52404Q200000A[FGooJeU[FOlJe^DJ
eP0?Oom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo00=[F@52404Q2000
00A[FGooJeU[FOlJe^DJeP0@JeUoof]IOom[FGooJeUoof]IOom[FGooJeUo
of]IOol2JeT1@Q018@P00004JeUoof]IJeWo6]KU6]H03gooJeUoof]IOom[
FGooJeUoof]IOom[FGooJeUoo`03JeT1@Q018@P00004JeUoof]IJeWo6]KU
6]H046]IOom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo0V]I0D8@0B48
000016]IOom[FF]Ioa[FiA[F00moof]IOom[FGooJeUoof]IOom[FGooJeUo
of]IOol00f]I0D8@0B48000016]IOom[FF]Ioa[FiA[F011[FGooJeUoof]I
Oom[FGooJeUoof]IOom[FGooJeUoo`9[F@52404Q200000A[FGooJeU[FOlJ
e^DJeP0?Oom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo00=[F@52404Q
200000A[FGooJeU[FOlJe^DJeP0@JeUoof]IOom[FGooJeUoof]IOom[FGoo
JeUoof]IOol2JeT1@Q018@P00004JeUoof]IJeWo6]KU6]H03gooJeUoof]I
Oom[FGooJeUoof]IOom[FGooJeUoo`03JeT1@Q018@P00004JeUoof]IJeWo
6]KU6]H046]IOom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo0V]I0D8@
0B48000016]IOom[FF]Ioa[FiA[F00moof]IOom[FGooJeUoof]IOom[FGoo
JeUoof]IOol00f]I0D8@0B48000016]IOom[FF]Ioa[FiA[F011[FGooJeUo
of]IOom[FGooJeUoof]IOom[FGooJeUoo`9[F@52404Q200000A[FGooJeU[
FOlJe^DJeP0?Oom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo00=[F@52
404Q200000A[FGooJeU[FOlJe^DJeP0@JeUoof]IOom[FGooJeUoof]IOom[
FGooJeUoof]IOol2JeT1@Q018@P00004JeUoof]IJeWo6]KU6]H03gooJeUo
of]IOom[FGooJeUoof]IOom[FGooJeUoo`03JeT1@Q018@P00004JeUoof]I
JeWo6]KU6]H046]IOom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo0V]I
0D8@0B48000016]IOom[FF]IofNIiFNI00moof]IOom[FGooJeUoof]IOom[
FGooJeUoof]IOol00f]I0D8@0B48000016]IOom[FF]IofNIiFNI011[FGoo
JeUoof]IOom[FGooJeUoof]IOom[FGooJeUoo`9[F@52404Q200000A[FGoo
JeU[FOmWVNEWV@0?Oom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo00=[
F@52404Q200000A[FGooJeU[FOmWVNEWV@0@JeUoof]IOom[FGooJeUoof]I
Oom[FGooJeUoof]IOol2JeT1@Q018@P00004JeUoof]IJeWoIiWUIiT03goo
JeUoof]IOom[FGooJeUoof]IOom[FGooJeUoo`03JeT1@Q018@P00004JeUo
of]IJeWoIiWUIiT046]IOom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo
0V]I0D8@0B48000016]IOom[FF]IofNIiFNI00moof]IOom[FGooJeUoof]I
Oom[FGooJeUoof]IOol00f]I0D8@0B48000016]IOom[FF]IofNI<FNIC248
2VNIC2484VNI011[FGooJeUoof]IOom[FGooJeUoof]IOom[FGooJeUoo`9[
F@52404Q200000A[FGooJeU[FOmWVC5WV@03JeU2448@04Q240038@QWVFNI
00QWV@03JeU2448@04Q240038@QWVFNI011WV@0?Oom[FGooJeUoof]IOom[
FGooJeUoof]IOom[FGoo00=[F@52404Q200000A[FGooJeU[FOmWVC5WV@03
JeUooe/i04MK>@03@Q0Q26NI00UWV@03JeUooe/i04MK>@03@Q0Q26NI015W
V@0@JeUoof]IOom[FGooJeUoof]IOom[FGooJeUoof]IOol2JeT1@Q018@P0
0004JeUoof]IJeWoIiTaIiT00f]IOomK>@17FcT00d8@8@QWV@09IiT00f]I
OomK>@17FcT00d8@8@QWV@0AIiT03gooJeUoof]IOom[FGooJeUoof]IOom[
FGooJeUoo`03JeT1@Q018@P00004JeUoof]IJeWoIiTaIiT00f]IOomK>@17
FcT00d8@8@QWV@09IiT00f]IOomK>@17FcT00d8@8@QWV@0AIiT046]IOom[
FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo0V]I0D8@0B48000016]IOom[
FF]IofNI<FNI00=[FGooFcT0Ae/i00=24248IiT02FNI00=[FGooFcT0Ae/i
00=24248IiT04FNI00moof]IOom[FGooJeUoof]IOom[FGooJeUoof]IOol0
0f]I0D8@0B48000016]IOom[FF]IofNI<FNI00=[FGooFcT0Ae/i00=24248
IiT02FNI00=[FGooFcT0Ae/i00=24248IiT04FNI011[FGooJeUoof]IOom[
FGooJeUoof]IOom[FGooJeUoo`9[F@52404Q200000A[FGooJeU[FOmWVC5W
V@03JeUooe/i01iK>@<0009K>@800004FcT00000000NFcT00d8@8@QWV@09
IiT00f]IOomK>@0@FcT30004FcT8000015/i000000000U/i0`0015/i1000
0U/i1@0045/i00=24248IiT04FNI00moof]IOom[FGooJeUoof]IOom[FGoo
JeUoof]IOol00f]I0D8@0B48000016]IOom[FF]IofNI<FNI00=[FGooFcT0
7E/i00D005/iFcUK>@00009K>@04001K>E/i000OFcT00d8@8@QWV@09IiT0
0f]IOomK>@0?FcT01@00FcUK>E/i00000U/i00D005/iFcUK>@00009K>@05
001K>E/iFcT00002FcT01@00FcUK>E/i00000U/i00<005/iFcT01U/i00<0
05/iFcT045/i00=24248IiT04FNI011[FGooJeUoof]IOom[FGooJeUoof]I
Oom[FGooJeUoo`9[F@52404Q200000A[FGooJeU[FOmWVC5WV@03JeUooe/i
01eK>@05001K>E/iFcT00002FcT00`00FcT0000PFcT00d8@8@QWV@09IiT0
0f]IOomK>@0?FcT00`00FcUK>@04FcT01@00FcUK>E/i00000U/i00D005/i
FcUK>@00009K>@03001K>E/i00AK>@03001K>E/i00IK>@03001K>E/i011K
>@03@Q0Q26NI015WV@0?Oom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo
00=[F@52404Q200000A[FGooJeU[FOmWVC5WV@03JeUooe/i01eK>@05001K
>E/iFcT00002FcT3000PFcT00d8@8@QWV@09IiT00f]IOomK>@0?FcT00`00
FcUK>@05FcT40002FcT01@00FcUK>E/i00000U/i00<005/iFcT015/i1@00
15/i00<005/iFcT045/i00=24248IiT04FNI011[FGooJeUoof]IOom[FGoo
JeUoof]IOom[FGooJeUoo`9[F@52404Q200000A[FGooJeU[FOmWVC5WV@03
JeUooe/i01eK>@05001K>E/iFcT00002FcT01000FcUK>@007e/i00=24248
IiT02FNI00=[FGooFcT03e/i00<005/iFcT015/i00D005/iFcUK>@00009K
>@80009K>@04001K>E/i0003FcT01000FcUK>@000e/i00<005/iFcT00U/i
00<005/iFcT045/i00=24248IiT04FNI00moof]IOom[FGooJeUoof]IOom[
FGooJeUoof]IOol00f]I0D8@0B48000016]IOom[FF]IofNI<FNI00=[FGoo
FcT07E/i00D005/iFcUK>@00009K>@03001K>@00008001iK>@03@Q0Q26NI
00UWV@03JeUooe/i00mK>@03001K>E/i00EK>@<0009K>@800003FcT00000
00AK>@@000=K>@<000EK>@03001K>E/i011K>@03@Q0Q26NI015WV@0@JeUo
of]IOom[FGooJeUoof]IOom[FGooJeUoof]IOol2JeT1@Q018@P00004JeUo
of]IJeWoIiTaIiT00f]IOomK>@0MFcT01@00FcUK>E/i00000U/i00<005/i
FcT085/i00=24248IiT02FNI00=[FGooFcT03e/i00D005/iFcUK>@00021K
>@03001K>E/i011K>@03@Q0Q26NI015WV@0?Oom[FGooJeUoof]IOom[FGoo
JeUoof]IOom[FGoo00=[F@52404Q200000A[FGooJeU[FOmWVC5WV@03JeUo
oe/i01iK>@<0009K>@80029K>@03@Q0Q26NI00UWV@03JeUooe/i011K>@@0
01mK>@80019K>@03@Q0Q26NI015WV@0@JeUoof]IOom[FGooJeUoof]IOom[
FGooJeUoof]IOol2JeT1@Q018@P00004JeUoof]IJeWoIiTaIiT00f]IOomK
>@17FcT00d8@8@QWV@09IiT00f]IOomK>@17FcT00d8@8@QWV@0AIiT03goo
JeUoof]IOom[FGooJeUoof]IOom[FGooJeUoo`03JeT1@Q018@P00004JeUo
of]IJeWoIiTaIiT00f]IOomK>@17FcT00d8@8@QWV@09IiT00f]IOomK>@17
FcT00d8@8@QWV@0AIiT046]IOom[FGooJeUoof]IOom[FGooJeUoof]IOom[
FGoo0V]I0D8@0B48000016]IOom[FF]IofNI<FNI00=[FGooFcT0Ae/i00=2
4248IiT02FNI00=[FGooFcT0Ae/i00=24248IiT04FNI00moof]IOom[FGoo
JeUoof]IOom[FGooJeUoof]IOol00f]I0D8@0B48000016]IOom[FF]IofNI
<FNI00=[FGooOol0Agoo00=24248IiT02FNI00=[FGooOol0Agoo00=24248
IiT04FNI011[FGooJeUoof]IOom[FGooJeUoof]IOom[FGooJeUoo`9[F@52
404Q200000A[FGooJeU[FOmWVC5WVD][F@038@QWVFNI00QWVD][F@038@QW
VFNI011WV@0?Oom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo00=[F@52
404Q200000A[FGooJeU[FOmWVNEWV@0@JeUoof]IOom[FGooJeUoof]IOom[
FGooJeUoof]IOol2JeT1@Q018@P00004JeUoof]IJeWoIiWUIiT03gooJeUo
of]IOom[FGooJeUoof]IOom[FGooJeUoo`03JeT1@Q018@P00004JeUoof]I
JeWoIiWUIiT046]IOom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo0V]I
0D8@0B48000016]IOom[FF]IofNIiFNI00moof]IOom[FGooJeUoof]IOom[
FGooJeUoof]IOol00f]I0D8@0B48000016]IOom[FF]IofNIiFNI011[FGoo
JeUoof]IOom[FGooJeUoof]IOom[FGooJeUoo`9[F@52404Q200000A[FGoo
JeU[FOlHI^DHIP0?Oom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo00=[
F@52404Q200000A[FGooJeU[FOmkg^EkgP0@JeUoof]IOom[FGooJeUoof]I
Oom[FGooJeUoof]IOol2JeT1@Q018@P00004JeUoof]IJeWoNmkUNmh03goo
JeUoof]IOom[FGooJeUoof]IOom[FGooJeUoo`03JeT1@Q018@P00004JeUo
of]IJeWoNmkUNmh046]IOom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo
0V]I0D8@0B48000016]IOom[FF]I6G_N0P002g_N0P0097_N0`00og_NUW_N
00moof]IOom[FGooJeUoof]IOom[FGooJeUoof]IOol00f]I0D8@0B480000
16]IOom[FF]I6G_N00<007_NNmh02g_N00<007_NNmh09G_N00<007_NNmh0
og_NTg_N011[FGooJeUoof]IOom[FGooJeUoof]IOom[FGooJeUoo`9[F@52
404Q200000A[FGooJeU[FAUkgP03001kgW_N00=kgP8000IkgP03001kgW_N
00ekgP<000=kgPD0009kgPD000=kgP@000YkgP03001kgW_N00EkgP<000=k
gPD000=kgP800003Nmh00000009kgP@00?mkgVYkgP0?Oom[FGooJeUoof]I
Oom[FGooJeUoof]IOom[FGoo00=[F@52404Q200000A[FGooJeU[FAUkgP03
001kgW_N00]kgP03001kgW_N00ikgP03001kgW_N00=kgP03001kgW_N00Ek
gP03001kgW_N009kgP05001kgW_NNmh0000;Nmh00`00NmikgP05Nmh00`00
NmikgP03Nmh00`00NmikgP03Nmh00`00NmikgP020002Nmh00`00NmikgP3o
Nmi/Nmh046]IOom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo0V]I0D8@
0B48000016]IOom[FF]I6G_N00<007_NNmh017_N00<007_NNmh017_N00<0
07_NNmh03W_N00<007_NNmh00g_N00<007_NNmh01G_N00<007_NNmh00W_N
00D007_NNmikgP0000AkgPT000IkgP03001kgW_N00=kgP03001kgW_N00=k
gP05001kgW_NNmh00002Nmh00`00NmikgP3oNmi/Nmh03gooJeUoof]IOom[
FGooJeUoof]IOom[FGooJeUoo`03JeT1@Q018@P00004JeUoof]IJeTINmh0
0`00NmikgP05Nmh00`00NmikgP03Nmh00`00NmikgP0>Nmh00`00NmikgP03
Nmh00`00NmikgP05Nmh00`00NmikgP02Nmh01@00NmikgW_N00002g_N00<0
07_NNmh01G_N00<007_NNmh00g_N00<007_NNmh00g_N00D007_NNmikgP00
009kgPD00?mkgVYkgP0@JeUoof]IOom[FGooJeUoof]IOom[FGooJeUoof]I
Ool2JeT1@Q018@P00004JeUoof]IJeTINmh00`00NmikgP06Nmh00`00Nmik
gP02Nmh00`00NmikgP0>Nmh00`00NmikgP03Nmh20006Nmh00`00NmikgP02
Nmh00`00NmikgP02000:Nmh00`00NmikgP06Nmh00`00NmikgP03Nmh20004
Nmh01@00NmikgW_N00000W_N00D007_NNmikgP000?mkgVYkgP0?Oom[FGoo
JeUoof]IOom[FGooJeUoof]IOom[FGoo00=[F@52404Q200000A[FGooJeU[
FAUkgP03001kgW_N00=kgP04001kgW_N0004Nmh00`00NmikgP0>Nmh00`00
NmikgP02Nmh200000g_N00000002Nmh30005Nmh200000g_N0000000BNmh0
0`00NmikgP02Nmh2000017_N000007_N0P000W_N0P000g_N0`00og_NJg_N
011[FGooJeUoof]IOom[FGooJeUoof]IOom[FGooJeUoo`9[F@52404Q2000
00A[FGooJeU[FAUkgP03001kgW_N00AkgP8000EkgP03001kgW_N00]kgP04
001kgW_N0002Nmh00`00NmikgP0RNmh01000NmikgP000W_N00<007_NNmh0
og_NO7_N00moof]IOom[FGooJeUoof]IOom[FGooJeUoof]IOol00f]I0D8@
0B48000016]IOom[FF]I6G_N0P002g_N0P003G_N1`002W_N00<007_NNmh0
5g_N1`00og_NOW_N011[FGooJeUoof]IOom[FGooJeUoof]IOom[FGooJeUo
o`9[F@52404Q200000A[FGooJeU[FOmkg^EkgP0?Oom[FGooJeUoof]IOom[
FGooJeUoof]IOom[FGoo00=[F@52404Q200000A[FGooJeU[FOmkg^EkgQ0Q
209[F@52404Q200000A[FGooJeU[FOmkg^EkgP03JeU2448@00a240048@Q[
FF]I@Q018@P00004JeUoof]IJeWoNmkUNmh00f]IOom[F@0;JeT01D8@8@Q[
FF]I@Q000B48000016]IOom[FF]Iog_NiG_N00=[FGooJeT02f]I00E24248
JeU[FD8@004Q200000A[FGooJeU[FOmkg^EkgP03JeUoof]I00][F@05@Q0Q
26]IJeU240018@P00004JeUoof]IJeWoNmkUNmh00f]IOom[F@0;JeT01D8@
8@Q[FF]I@Q000B48000016]IOom[FF]Iog_NiG_N00=[FGooJeT02f]I00E2
4248JeU[FD8@004Q200000A[FGooJeU[FOmkg^EkgP03JeUoof]I00][F@05
@Q0Q26]IJeU240018@P00004JeUoof]IJeWoNmkUNmh00f]IOom[F@0;JeT0
1D8@8@Q[FF]I@Q000B48000016]IOom[FF]I6G_N0P002g_N0P00og_N_G_N
00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FAUkgP03
001kgW_N00]kgP03001kgW_N0?mkg[]kgP03JeUoof]I00][F@05@Q0Q26]I
JeU240018@P00004JeUoof]IJeTINmh00`00NmikgP03Nmh20006Nmh00`00
NmikgP0=Nmh30003Nmh50003Nmh800001G_N00000000Nmh010000g_N1@00
0g_N0`000g_N1@0000=kgP0000001@000W_N1@000g_N0`000W_N1@000g_N
0`000W_N0`0000EkgP00000007_N00<000EkgP800003Nmh0000000<00004
Nmh000000002Nmh30005Nmh30002Nmh50003Nmh30002Nmh300001G_N0000
0000Nmh010002g_N00<007_NNmh00g_N0`0000AkgP000000009kgP800003
Nmh0000000=kgP<000=kgP<0009kgPL0009kgPD000=kgP<0009kgPD000=k
gP<00<9kgP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]I
JeTINmh00`00NmikgP0;Nmh00`00NmikgP0>Nmh00`00NmikgP03Nmh00`00
NmikgP03Nmh01@00NmikgW_N00000W_N00D007_NNmikgP00009kgP05001k
gW_NNmh00003Nmh00`00NmikgP03Nmh01@00NmikgW_N00000g_N00<007_N
Nmh00g_N00D007_N001kgP00009kgP05001kgW_NNmh00003Nmh01@00Nmik
gW_N00000g_N00<007_NNmh00W_N00D007_NNmikgP00009kgP05001kgW_N
Nmh00003Nmh00`00NmikgP03Nmh00`00NmikgP020002Nmh01@00NmikgW_N
00000W_N00D007_NNmikgP0000=kgP05001kgW_NNmh00003Nmh00`00Nmik
gP02Nmh01@00NmikgW_N00000W_N00D007_NNmikgP00009kgP05001kgW_N
Nmh0000;Nmh00`00NmikgP03Nmh01@00NmikgW_N00000W_N00<007_NNmh0
0P000g_N00L007_NNmikgP00Nmh00003Nmh02000NmikgP00Nmh007_N0002
Nmh01@00NmikgW_N00000g_N00D007_NNmikgP0000=kgP03001kgW_N009k
gP05001kgW_NNmh00031Nmh00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48
000016]IOom[FF]I6G_N00<007_NNmh017_N00<007_NNmh017_N00<007_N
Nmh03W_N00<007_NNmh00g_N00<007_NNmh00g_N00D007_NNmikgP00009k
gP05001kgW_NNmh00006Nmh01@00NmikgW_N00001G_N00D007_NNmikgP00
00=kgP03001kgW_N00=kgP05001kgP00Nmh00002Nmh01@00NmikgW_N0000
0g_N00<007_NNmh01G_N00<007_NNmh00W_N00D007_NNmikgP00009kgP05
001kgW_NNmh00003Nmh00`00NmikgP03Nmh01@00NmikgW_N00000W_N00D0
07_NNmikgP00009kgP03001kgW_N00EkgP03001kgW_N00EkgP03001kgW_N
009kgP05001kgW_NNmh00002Nmh01@00NmikgW_N00001W_N00<007_NNmh0
0W_N2@0017_N1@000W_N00D007_NNmikgP0000=kgP03001kgW_N00=kgP05
001kgW_NNmh00002Nmh01@00Nmh007_N00000W_N00D007_NNmikgP0000=k
gP03001kgW_N00EkgP03001kgW_N009kgP03001kgW_N0<=kgP03JeUoof]I
00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeTINmh00`00NmikgP05
Nmh00`00NmikgP03Nmh00`00NmikgP0>Nmh00`00NmikgP03Nmh00`00Nmik
gP04Nmh40002Nmh01@00NmikgW_N00000g_N0`0017_N00<007_NNmh00g_N
00D007_NNmikgP0000=kgP03001kgW_N00=kgP05001kgP00Nmh00003Nmh4
0003Nmh00`00NmikgP05Nmh00`00NmikgP02Nmh01@00NmikgW_N00000W_N
00D007_NNmikgP0000=kgP03001kgP0000=kgP05001kgW_NNmh00002Nmh0
1@00NmikgW_N00000W_N00<007_NNmh01G_N00<007_NNmh01G_N00<007_N
Nmh00W_N00D007_NNmikgP00009kgP05001kgW_NNmh00003Nmh3000<Nmh0
0`00NmikgP04Nmh00`00Nmh00003Nmh01@00NmikgW_N00000g_N00<007_N
Nmh00g_N00D007_NNmikgP00009kgP05001kgP00Nmh00003Nmh40003Nmh0
0`00NmikgP05Nmh00`00NmikgP02Nmh00`00NmikgP33Nmh00f]IOom[F@0;
JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]I6G_N00<007_NNmh01W_N
00<007_NNmh00W_N00<007_NNmh03W_N00<007_NNmh00g_N0P0017_N00D0
07_NNmikgP00009kgP80009kgP04001kgW_N0003Nmh01@00NmikgW_N0000
1G_N00D007_NNmikgP0000=kgP8000AkgP05001kgP00Nmh00002Nmh01@00
NmikgW_N00000g_N00<007_NNmh01G_N00<007_NNmh00W_N00D007_NNmik
gP00009kgP80009kgP04001kgW_NNmh30003Nmh01@00NmikgW_N00000W_N
0P000W_N00@007_NNmh000=kgP05001kgW_NNmh00007Nmh00`00NmikgP02
Nmh01@00NmikgW_N00000W_N0P000W_N00@007_NNmh000=kgP03001kgW_N
00QkgP03001kgW_N00EkgP03001kgP0000=kgP05001kgW_NNmh00003Nmh0
0`00NmikgP03Nmh01@00NmikgW_N00000W_N00D007_N001kgP00009kgP05
001kgW_NNmh00003Nmh00`00NmikgP05Nmh00`00NmikgP02Nmh01@00Nmik
gW_N0000`G_N00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGoo
JeU[FAUkgP03001kgW_N00=kgP04001kgW_N0004Nmh00`00NmikgP0>Nmh0
0`00NmikgP02Nmh200000g_N00000003Nmh30002Nmh200000g_N00000004
Nmh40002Nmh50003Nmh30003Nmh2000017_N000007_N0`0000=kgP00Nmh0
0g_N0`000g_N1@000W_N0`001G_N0`000W_N0P0000=kgP00000017_N00<0
07_N00000W_N0P000W_N0P0000AkgP00001kgP8000AkgP@0009kgPD0009k
gP<000EkgP<0009kgP800003Nmh0000000AkgP@0019kgP03001kgP00009k
gP80009kgP80009kgPD000=kgP<0009kgP<00003Nmh007_N00=kgP<000=k
gPD0009kgP<000EkgP@00<5kgP03JeUoof]I00][F@05@Q0Q26]IJeU24001
8@P00004JeUoof]IJeTINmh00`00NmikgP04Nmh20005Nmh00`00NmikgP0;
Nmh01000NmikgP000W_N00<007_NNmh077_N00<007_NNmh087_N00<007_N
Nmh06G_N00D007_NNmikgP0001MkgP03001kgW_N031kgP03001kgW_N00Yk
gP03001kgW_N01UkgP03001kgW_N0=1kgP03JeUoof]I00][F@05@Q0Q26]I
JeU240018@P00004JeUoof]IJeTINmh2000;Nmh2000=Nmh7000ONmh3000W
Nmh00`00NmikgP0@Nmh6000ONmh00`00NmikgP0WNmh2000`Nmh00`00Nmik
gP38Nmh00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]I
og_NiG_N00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[
FOmkg^EkgP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]I
JeWoNmkUNmh00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[
FF]Iog_NiG_N00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGoo
JeU[FOmkg^EkgP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUo
of]IJeWoNmkUNmh00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]I
Oom[FF]Iog_NiG_N00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[
FGooJeU[FOmkg^EkgP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004
JeUoof]IJeWoNmkUNmh00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B480000
16]IOom[FF]Iog_NiG_N00=[FGooJeT02f]I00E24248JeU[FD8@004Q2000
00A[FGooJeU[FAUkgP8000]kgP800?mkg[ekgP03JeUoof]I00][F@05@Q0Q
26]IJeU240018@P00004JeUoof]IJeTINmh00`00NmikgP0;Nmh00`00Nmik
gP3oNmjkNmh00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[
FF]I6G_N00<007_NNmh00g_N0P001W_N00<007_NNmh03G_N0`000g_N1@00
00=kgP0000001@000W_N10000g_N0`0017_N0`000W_N0`0000EkgP000000
07_N00@000EkgP<0009kgPD000=kgPD00003Nmh0000000<00005Nmh00000
001kgP030003Nmh3000:Nmh00`00NmikgP05Nmh30004Nmh30004Nmh3003o
Nmh/Nmh00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]I
6G_N00<007_NNmh02g_N00<007_NNmh03W_N00<007_NNmh017_N00<007_N
Nmh00W_N00D007_N001kgP00009kgP03001kgW_N00AkgP05001kgW_NNmh0
0002Nmh01@00NmikgW_N00000W_N00D007_NNmikgP00009kgP05001kgW_N
Nmh00003Nmh01@00NmikgW_N00000W_N00<007_NNmh00g_N00D007_NNmik
gP0000AkgP03001kgW_N009kgP05001kgW_NNmh00003Nmh01@00NmikgW_N
00002W_N00<007_NNmh00g_N00D007_NNmikgP00009kgP05001kgW_NNmh0
0002Nmh01@00NmikgW_N0000og_N:g_N00=[FGooJeT02f]I00E24248JeU[
FD8@004Q200000A[FGooJeU[FAUkgP03001kgW_N00AkgP03001kgW_N00Ak
gP03001kgW_N00ikgP03001kgW_N00AkgP03001kgW_N009kgP05001kgP00
Nmh00002Nmh00`00NmikgP04Nmh00`00NmikgP04Nmh01@00NmikgW_N0000
0W_N00D007_NNmikgP0000IkgP05001kgW_NNmh00006Nmh00`00NmikgP03
Nmh01@00NmikgW_N000017_N00<007_NNmh00W_N00D007_NNmikgP0000=k
gP03001kgW_N00EkgPT000QkgP04001kgW_N0003Nmh01000NmikgP000g_N
00<007_NNmh0og_N:G_N00=[FGooJeT02f]I00E24248JeU[FD8@004Q2000
00A[FGooJeU[FAUkgP03001kgW_N00EkgP03001kgW_N00=kgP03001kgW_N
00ikgP03001kgW_N00AkgP03001kgW_N009kgP05001kgP00Nmh00002Nmh5
0002Nmh00`00NmikgP04Nmh01@00NmikgW_N00000W_N00D007_NNmikgP00
00=kgP<000AkgP03001kgW_N00AkgP03001kgW_N00AkgP@000AkgP03001k
gW_N009kgP05001kgW_NNmh00003Nmh00`00NmikgP0<Nmh00`00NmikgP07
Nmh01000NmikgP000g_N00@007_NNmh000=kgP03001kgW_N0?mkgRUkgP03
JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeTINmh00`00
NmikgP06Nmh00`00NmikgP02Nmh00`00NmikgP0>Nmh00`00NmikgP04Nmh0
0`00NmikgP02Nmh01@00Nmh007_N00000W_N00D007_NNmikgP00009kgP03
001kgW_N00AkgP05001kgW_NNmh00002Nmh20002Nmh01000NmikgP000g_N
00D007_NNmikgP0000IkgP8000AkgP05001kgW_NNmh00004Nmh00`00Nmik
gP02Nmh20002Nmh01@00NmikgW_N00003G_N00<007_NNmh01W_N0P000g_N
00D007_NNmikgP00009kgP05001kgW_NNmh0003oNmh[Nmh00f]IOom[F@0;
JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]I6G_N00<007_NNmh00g_N
00@007_NNmh000AkgP03001kgW_N00ikgP03001kgW_N009kgP<000=kgP<0
0003Nmh007_N00=kgP<000=kgP03001kgW_N00EkgP<0009kgP800003Nmh0
000000AkgP@0009kgPD0009kgP800003Nmh0000000=kgP<000=kgP<000=k
gP800003Nmh0000000=kgPD001EkgP04001kgW_N0003Nmh01000NmikgP00
0g_N00<007_NNmh0og_N:G_N00=[FGooJeT02f]I00E24248JeU[FD8@004Q
200000A[FGooJeU[FAUkgP03001kgW_N00AkgP8000EkgP03001kgW_N00]k
gP04001kgW_N0002Nmh00`00NmikgP0DNmh01@00NmikgW_N000067_N00<0
07_NNmh087_N00<007_NNmh04W_N00D007_NNmikgP00009kgP05001kgW_N
Nmh00002Nmh01@00NmikgW_N0000og_N:g_N00=[FGooJeT02f]I00E24248
JeU[FD8@004Q200000A[FGooJeU[FAUkgP8000]kgP8000ekgPL000=kgP03
001kgW_N015kgP@002ikgP03001kgW_N021kgP<000AkgP<000AkgP<00?mk
gRakgP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeWo
NmkUNmh00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]I
og_NiG_N00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[
FOmkg^EkgP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]I
JeWoNmkUNmh00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[
FF]Iog_NiG_N00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGoo
JeU[FOmkg^EkgP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUo
of]IJeWoNmkUNmh00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]I
Oom[FF]Iog_NiG_N00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[
FGooJeU[FOmkg^EkgP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004
JeUoof]IJeWoNmkUNmh00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B480000
16]IOom[FF]I6G_N0P002g_N0P008W_N0`00:7_N1000og_NK7_N00=[FGoo
JeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FAUkgP03001kgW_N
00]kgP03001kgW_N025kgP03001kgW_N02UkgP03001kgW_N0?mkgV]kgP03
JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeTINmh00`00
NmikgP03Nmh20006Nmh00`00NmikgP0=Nmh30004Nmh30002Nmh700000g_N
000000020003Nmh50003Nmh400000g_N00000002Nmh20002Nmh50004Nmh3
0004Nmh00`00NmikgP02Nmh30005Nmh200000g_N00000003000017_N0000
00000W_N0`001G_N0`000W_N1@000g_N0`000W_N0`0000AkgP00000000Uk
gP03001kgW_N00=kgP<00004Nmh000000002Nmh200000g_N00000003Nmh3
0003Nmh30002Nmh70002Nmh50003Nmh30002Nmh50003Nmh3003UNmh00f]I
Oom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]I6G_N00<007_N
Nmh02g_N00<007_NNmh037_N00D007_NNmikgP00009kgP05001kgW_NNmh0
0002Nmh01@00Nmh007_N00000W_N00D007_NNmikgP0000AkgP03001kgW_N
009kgP03001kgW_N00AkgP04001kgW_N0005Nmh00`00NmikgP03Nmh01@00
NmikgW_N00000g_N0P0017_N00<007_NNmh00g_N00<007_NNmh00P000W_N
00D007_NNmikgP00009kgP05001kgW_NNmh00003Nmh01@00NmikgW_N0000
0g_N00<007_NNmh00W_N00D007_NNmikgP00009kgP05001kgW_NNmh0000;
Nmh00`00NmikgP03Nmh01@00NmikgW_N00000W_N00<007_NNmh00P000g_N
00L007_NNmikgP00Nmh00003Nmh02000NmikgP00Nmh007_N0002Nmh01@00
NmikgW_N00000g_N00D007_NNmikgP0000=kgP03001kgW_N009kgP05001k
gW_NNmh0003TNmh00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]I
Oom[FF]I6G_N00<007_NNmh017_N00<007_NNmh017_N00<007_NNmh037_N
00<007_NNmh017_N00D007_NNmikgP00009kgP05001kgP00Nmh00002Nmh0
1@00NmikgW_N000017_N00<007_NNmh00W_N00<007_NNmh01G_N0P001W_N
00<007_NNmh00g_N00<007_NNmh017_N00<007_N000017_N00<007_NNmh0
0g_N00D007_NNmikgP00009kgP05001kgW_NNmh00002Nmh00`00NmikgP05
Nmh00`00NmikgP05Nmh00`00NmikgP02Nmh01@00NmikgW_N00000W_N00D0
07_NNmikgP0000AkgPT000AkgPD0009kgP05001kgW_NNmh00003Nmh00`00
NmikgP03Nmh01@00NmikgW_N00000W_N00D007_N001kgP00009kgP05001k
gW_NNmh00003Nmh00`00NmikgP05Nmh00`00NmikgP02Nmh00`00NmikgP3V
Nmh00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]I6G_N
00<007_NNmh01G_N00<007_NNmh00g_N00<007_NNmh037_N00<007_NNmh0
17_N00D007_NNmikgP00009kgP05001kgP00Nmh00002Nmh01@00NmikgW_N
000017_N00<007_NNmh00W_N1@000g_N0P001W_N00<007_NNmh00g_N00<0
07_NNmh017_N00@007_NNmh000=kgP03001kgP0000=kgP05001kgW_NNmh0
0002Nmh01@00NmikgW_N00000W_N00<007_NNmh01G_N00<007_NNmh01G_N
00<007_NNmh00W_N00D007_NNmikgP00009kgP05001kgW_NNmh0000;Nmh0
0`00NmikgP04Nmh00`00Nmh00003Nmh01@00NmikgW_N00000g_N00<007_N
Nmh00g_N00D007_NNmikgP00009kgP05001kgP00Nmh00003Nmh40003Nmh0
0`00NmikgP05Nmh00`00NmikgP02Nmh00`00NmikgP3VNmh00f]IOom[F@0;
JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]I6G_N00<007_NNmh01W_N
00<007_NNmh00W_N00<007_NNmh037_N00<007_NNmh017_N00D007_NNmik
gP00009kgP05001kgP00Nmh00002Nmh20002Nmh00`00NmikgP02Nmh00`00
NmikgP02Nmh01@00NmikgW_N00000W_N00@007_NNmh000EkgP03001kgW_N
00=kgP03001kgW_N00=kgP05001kgW_NNmh00003Nmh30003Nmh01@00Nmik
gW_N00000W_N0P000W_N00@007_NNmh000=kgP05001kgW_NNmh00007Nmh0
0`00NmikgP02Nmh01@00NmikgW_N00000W_N0P000W_N00<007_NNmh027_N
00<007_NNmh01G_N00<007_N00000g_N00D007_NNmikgP0000=kgP03001k
gW_N00=kgP05001kgW_NNmh00002Nmh01@00Nmh007_N00000W_N00D007_N
NmikgP0000=kgP03001kgW_N00EkgP03001kgW_N009kgP05001kgW_NNmh0
003TNmh00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]I
6G_N00<007_NNmh00g_N00@007_NNmh000AkgP03001kgW_N00akgP03001k
gW_N00EkgP<0009kgP<00004Nmh007_NNmh200000g_N00000005Nmh00`00
NmikgP03Nmh30002Nmh20002Nmh20002Nmh30004Nmh500001G_N00000000
Nmh00`000W_N00<007_N00000W_N0P000W_N0P0000AkgP00001kgP8000Ak
gP@0009kgPD0009kgP<000EkgP<0009kgP800003Nmh0000001=kgP03001k
gP00009kgP80009kgP80009kgPD000=kgP<0009kgP<00003Nmh007_N00=k
gP<000=kgPD0009kgP<000EkgP@00>AkgP03JeUoof]I00][F@05@Q0Q26]I
JeU240018@P00004JeUoof]IJeTINmh00`00NmikgP04Nmh20005Nmh00`00
NmikgP0<Nmh01@00NmikgW_N00006G_N00<007_NNmh067_N00<007_NNmh0
2g_N00D007_NNmikgP0001MkgP03001kgW_N02UkgP03001kgW_N00YkgP03
001kgW_N01UkgP03001kgW_N0?=kgP03JeUoof]I00][F@05@Q0Q26]IJeU2
40018@P00004JeUoof]IJeTINmh2000;Nmh2000?Nmh4000HNmh2000DNmh0
0`00NmikgP0@Nmh6000ONmh00`00NmikgP0PNmh2000`Nmh00`00NmikgP3[
Nmh00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]Iog_N
iG_N00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FOmk
g^EkgP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeWo
NmkUNmh00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]I
og_NiG_N00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[
FOmkg^EkgP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]I
JeWoNmkUNmh00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[
FF]Iog_NiG_N00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGoo
JeU[FOmkg^EkgP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUo
of]IJeWoNmkUNmh00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]I
Oom[FF]Iog_NiG_N00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[
FGooJeU[FAUkgP8000]kgP80031kgP<0061kgP<00?mkgRMkgP03JeUoof]I
00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeTINmh00`00NmikgP0;
Nmh00`00NmikgP0_Nmh00`00NmikgP0hNmh00`00NmikgP0UNmh00`00Nmik
gP3oNmhVNmh00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[
FF]I6G_N00<007_NNmh00g_N0P001W_N00<007_NNmh02g_N0`0000EkgP00
000007_N00@000=kgP@000AkgP800003Nmh0000000L00003Nmh000000080
00EkgP<0009kgPD000=kgP<0009kgP<00005Nmh00000001kgP040005Nmh0
0`00NmikgP02Nmh00`00NmikgP07Nmh01000NmikgW_N0`0000EkgP000000
07_N00@000=kgP@000AkgP800003Nmh0000000L00003Nmh00000008000Ek
gP<0009kgPD000=kgP<0009kgP<00005Nmh00000001kgP04003oNmh2Nmh0
0f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]I6G_N00<0
07_NNmh02g_N00<007_NNmh037_N00D007_NNmikgP00009kgP05001kgW_N
Nmh00002Nmh01@00NmikgW_N00000W_N00<007_NNmh00P000W_N00D007_N
001kgP00009kgP05001kgW_NNmh00003Nmh01@00NmikgW_N00000g_N00<0
07_NNmh00W_N00D007_NNmikgP00009kgP05001kgW_NNmh00002Nmh01@00
NmikgW_N00002W_N00<007_NNmh017_N0`0017_N00D007_NNmikgP00009k
gP05001kgW_NNmh00002Nmh01@00NmikgW_N00000W_N00<007_NNmh00P00
0W_N00D007_N001kgP00009kgP05001kgW_NNmh00003Nmh01@00NmikgW_N
00000g_N00<007_NNmh00W_N00D007_NNmikgP00009kgP05001kgW_NNmh0
0002Nmh01@00NmikgW_N0000og_N0G_N00=[FGooJeT02f]I00E24248JeU[
FD8@004Q200000A[FGooJeU[FAUkgP03001kgW_N00AkgP03001kgW_N00Ak
gP03001kgW_N00akgPD000IkgP03001kgW_N00AkgP04001kgW_N0003Nmh0
2000NmikgP00Nmh007_N0002Nmh01@00NmikgW_N00000g_N00<007_NNmh0
1G_N00<007_NNmh00W_N00D007_NNmikgP00009kgP05001kgW_NNmh00006
Nmh00`00NmikgP04Nmh60005Nmh01000NmikgP000g_N1@001W_N00<007_N
Nmh017_N00@007_NNmh000=kgP08001kgW_N001kgP00Nmh0009kgP05001k
gW_NNmh00003Nmh00`00NmikgP05Nmh00`00NmikgP02Nmh01@00NmikgW_N
00000W_N00D007_NNmikgP0000IkgP03001kgW_N0?ikgP03JeUoof]I00][
F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeTINmh00`00NmikgP05Nmh0
0`00NmikgP03Nmh00`00NmikgP0=Nmh00`00Nmh00004Nmh30004Nmh30003
Nmh01@00NmikgW_N00000W_N00D007_N001kgP00009kgP05001kgW_NNmh0
0003Nmh00`00NmikgP05Nmh00`00NmikgP02Nmh01@00NmikgW_N00000W_N
00D007_NNmikgP0000=kgP<000]kgP03001kgW_N00EkgP<000AkgP03001k
gP0000AkgP<000AkgP<000=kgP05001kgW_NNmh00002Nmh01@00Nmh007_N
00000W_N00D007_NNmikgP0000=kgP03001kgW_N00EkgP03001kgW_N009k
gP05001kgW_NNmh00002Nmh01@00NmikgW_N00000g_N0`00og_N0W_N00=[
FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FAUkgP03001k
gW_N00IkgP03001kgW_N009kgP03001kgW_N00ekgP03001kgP0000=kgP05
001kgW_NNmh00002Nmh01@00NmikgW_N00000W_N00D007_NNmikgP00009k
gP05001kgP00Nmh00002Nmh20002Nmh01@00NmikgW_N00001g_N00<007_N
Nmh00W_N00D007_NNmikgP00009kgP80009kgP04001kgW_N0003Nmh00`00
NmikgP02Nmh00`00NmikgP02Nmh00`00NmikgP05Nmh00`00NmikgP05Nmh0
0`00Nmh00003Nmh01@00NmikgW_N00000W_N00D007_NNmikgP00009kgP05
001kgW_NNmh00002Nmh01@00Nmh007_N00000W_N0P000W_N00D007_NNmik
gP0000MkgP03001kgW_N009kgP05001kgW_NNmh00002Nmh20002Nmh01000
NmikgP000g_N00<007_NNmh0oW_N00=[FGooJeT02f]I00E24248JeU[FD8@
004Q200000A[FGooJeU[FAUkgP03001kgW_N00=kgP04001kgW_N0004Nmh0
0`00NmikgP0=Nmh00`00Nmh00004Nmh40003Nmh400000g_N00000002Nmh2
00001W_N00000000Nmh0009kgP800003Nmh0000000=kgPD0009kgP<000Ek
gP<0009kgP800003Nmh0000000AkgP@0015kgP03001kgW_N00EkgP03001k
gP0000AkgP@000=kgP@00003Nmh00000009kgP800006Nmh00000001kgP00
0W_N0P0000=kgP0000000g_N1@000W_N0`001G_N0`000W_N0P0000=kgP00
000017_N1000og_N0G_N00=[FGooJeT02f]I00E24248JeU[FD8@004Q2000
00A[FGooJeU[FAUkgP03001kgW_N00AkgP8000EkgP03001kgW_N00ikgP03
001kgW_N02IkgP03001kgW_N02mkgP<000EkgP03001kgW_N02IkgP03001k
gW_N0?mkgQikgP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUo
of]IJeTINmh2000;Nmh2000?Nmh2000`Nmh00`00NmikgP0XNmh00`00Nmik
gP03Nmh2000`Nmh00`00NmikgP3oNmhFNmh00f]IOom[F@0;JeT01D8@8@Q[
FF]I@Q000B48000016]IOom[FF]Iog_NiG_N00=[FGooJeT02f]I00E24248
JeU[FD8@004Q200000A[FGooJeU[FOmkg^EkgP03JeUoof]I00][F@05@Q0Q
26]IJeU240018@P00004JeUoof]IJeWoNmkUNmh00f]IOom[F@0;JeT01D8@
8@Q[FF]I@Q000B48000016]IOom[FF]Iog_NiG_N00=[FGooJeT02f]I00E2
4248JeU[FD8@004Q200000A[FGooJeU[FOmkg^EkgP03JeUoof]I00][F@05
@Q0Q26]IJeU240018@P00004JeUoof]IJeWoNmkUNmh00f]IOom[F@0;JeT0
1D8@8@Q[FF]I@Q000B48000016]IOom[FF]Iog_NiG_N00=[FGooJeT02f]I
00E24248JeU[FD8@004Q200000A[FGooJeU[FOmWVNEWV@03JeUoof]I00][
F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeWoIiWUIiT00f]IOom[F@0;
JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]IofNIiFNI00=[FGooJeT0
2f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FOmWVNEWV@03JeUoof]I
00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeWoIiWUIiT00f]IOom[
F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]IofNIiFNI00=[FGoo
JeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FOmWVNEWV@03JeUo
of]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeWoIiT7IiTo8@P7
IiTo8@P7IiTo8@PCIiT00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B480000
16]IOom[FF]IofNI1fNI00=[FD8@@Q00>d8@00<Q26NIIiT01FNI00=[FD8@
@Q00>d8@00<Q26NIIiT01FNI00=[FD8@@Q00>d8@00<Q26NIIiT04FNI00=[
FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FOmWV@MWV@03
JeUooe/i03YK>@03@Q0Q26NI00IWV@03JeUooe/i03YK>@03@Q0Q26NI00IW
V@03JeUooe/i03YK>@03@Q0Q26NI019WV@03JeUoof]I00][F@05@Q0Q26]I
JeU240018@P00004JeUoof]IJeWoIiT7IiT00f]IOomK>@0jFcT00d8@8@QW
V@06IiT00f]IOomK>@0jFcT00d8@8@QWV@06IiT00f]IOomK>@0jFcT00d8@
8@QWV@0BIiT00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[
FF]IofNI1fNI00=[FGooFcT0>U/i00=24248IiT01VNI00=[FGooFcT0>U/i
00=24248IiT01VNI00=[FGooFcT0>U/i00=24248IiT04VNI00=[FGooJeT0
2f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FOmWV@MWV@03JeUooe/i
03YK>@03@Q0Q26NI00IWV@03JeUooe/i03YK>@03@Q0Q26NI00IWV@03JeUo
oe/i03YK>@03@Q0Q26NI019WV@03JeUoof]I00][F@05@Q0Q26]IJeU24001
8@P00004JeUoof]IJeWoIiT7IiT00f]IOomK>@0jFcT00d8@8@QWV@06IiT0
0f]IOomK>@0jFcT00d8@8@QWV@06IiT00f]IOomK>@0jFcT00d8@8@QWV@0B
IiT00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]IofNI
1fNI00=[FGooFcT04U/i0`0000EK>@00000005/i00D0009K>@D001AK>@03
@Q0Q26NI00IWV@03JeUooe/i00iK>@<00003FcT0000000=K>@<0009K>@<0
0004FcT000000002FcT4000AFcT00d8@8@QWV@06IiT00f]IOomK>@0?FcT5
0003FcT500000e/i000000020005FcT3000AFcT00d8@8@QWV@0BIiT00f]I
Oom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]IofNI1fNI00=[
FGooFcT04e/i00D005/iFcUK>@0000AK>@03001K>E/i00AK>@03001K>E/i
01AK>@03@Q0Q26NI00IWV@03JeUooe/i00mK>@03001K>E/i0080009K>@05
001K>E/iFcT00002FcT01@00FcUK>E/i00000U/i00<005/iFcT04e/i00=2
4248IiT01VNI00=[FGooFcT045/i00@005/iFcT0009K>@05001K>E/iFcT0
0002FcT01@00FcUK>E/i00000e/i00D005/iFcUK>@00011K>@03@Q0Q26NI
019WV@03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeWo
IiT7IiT00f]IOomK>@0CFcT50004FcT00`00FcUK>@04FcT00`00FcUK>@0D
FcT00d8@8@QWV@06IiT00f]IOomK>@0?FcT01@00FcT005/i00000U/i00D0
05/iFcUK>@00009K>@05001K>E/iFcT00002FcT00`00FcUK>@0CFcT00d8@
8@QWV@06IiT00f]IOomK>@0@FcT01000FcUK>@000U/i00D005/iFcUK>@00
00IK>@05001K>E/iFcT0000DFcT00d8@8@QWV@0BIiT00f]IOom[F@0;JeT0
1D8@8@Q[FF]I@Q000B48000016]IOom[FF]IofNI1fNI00=[FGooFcT055/i
00<005/i00001E/i00<005/iFcT015/i00<005/iFcT055/i00=24248IiT0
1VNI00=[FGooFcT03e/i00D005/i001K>@00009K>@05001K>E/iFcT00002
FcT01@00FcUK>E/i00000U/i1@004E/i00=24248IiT01VNI00=[FGooFcT0
45/i00<005/iFcT015/i10000e/i0`0015/i00<005/iFcT04U/i00=24248
IiT04VNI00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[
FOmWV@MWV@03JeUooe/i01AK>@03001K>@0000EK>@03001K>E/i00AK>@03
001K>E/i01AK>@03@Q0Q26NI00IWV@03JeUooe/i00mK>@05001K>@00FcT0
0002FcT01@00FcUK>E/i00000U/i0P000U/i00@005/iFcT000=K>@03001K
>E/i00mK>@03@Q0Q26NI00IWV@03JeUooe/i011K>@03001K>E/i00=K>@05
001K>E/iFcT00002FcT01@00FcUK>E/i00000e/i00<005/iFcT04U/i00=2
4248IiT04VNI00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGoo
JeU[FOmWV@MWV@03JeUooe/i01AK>@03001K>@0000EK>@03001K>E/i00AK
>@03001K>E/i01AK>@03@Q0Q26NI00IWV@03JeUooe/i00mK>@80009K>@04
001K>E/iFcT30002FcT200000e/i00000004FcT3000BFcT00d8@8@QWV@06
IiT00f]IOomK>@0@FcT00`00FcUK>@04FcT30004FcT40002FcT5000AFcT0
0d8@8@QWV@0BIiT00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]I
Oom[FF]IofNI1fNI00=[FGooFcT05E/i00<005/iFcT015/i00<005/iFcT0
15/i00<005/iFcT055/i00=24248IiT01VNI00=[FGooFcT03e/i0P000U/i
00<005/iFcT095/i00=24248IiT01VNI00=[FGooFcT045/i00<005/iFcT0
4U/i00<005/iFcT04U/i00=24248IiT04VNI00=[FGooJeT02f]I00E24248
JeU[FD8@004Q200000A[FGooJeU[FOmWV@MWV@03JeUooe/i01AK>@8000EK
>@8000EK>@8001IK>@03@Q0Q26NI00IWV@03JeUooe/i00iK>@<00004FcT0
0000000UFcT00d8@8@QWV@06IiT00f]IOomK>@0?FcT3000XFcT00d8@8@QW
V@0BIiT00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]I
ofNI1fNI00=[FGooFcT0>U/i00=24248IiT01VNI00=[FGooFcT0>U/i00=2
4248IiT01VNI00=[FGooFcT0>U/i00=24248IiT04VNI00=[FGooJeT02f]I
00E24248JeU[FD8@004Q200000A[FGooJeU[FOmWV@MWV@03JeUooe/i03YK
>@03@Q0Q26NI00IWV@03JeUooe/i03YK>@03@Q0Q26NI00IWV@03JeUooe/i
03YK>@03@Q0Q26NI019WV@03JeUoof]I00][F@05@Q0Q26]IJeU240018@P0
0004JeUoof]IJeWoIiT7IiT00f]IOomK>@0jFcT00d8@8@QWV@06IiT00f]I
OomK>@0jFcT00d8@8@QWV@06IiT00f]IOomK>@0jFcT00d8@8@QWV@0BIiT0
0f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]IofNI1fNI
00=[FGooOol0>Woo00=24248IiT01VNI00=[FGooOol0>Woo00=24248IiT0
1VNI00=[FGooOol0>Woo00=24248IiT04VNI00=[FGooJeT02f]I00E24248
JeU[FD8@004Q200000A[FGooJeU[FOmWV@MWVCi[F@038@QWVFNI00EWVCi[
F@038@QWVFNI00EWVCi[F@038@QWVFNI015WV@03JeUoof]I00][F@05@Q0Q
26]IJeU240018@P00004JeUoof]IJeWoIiWUIiT00f]IOom[F@0;JeT01D8@
8@Q[FF]I@Q000B48000016]IOom[FF]IofNIiFNI00=[FGooJeT02f]I00E2
4248JeU[FD8@004Q200000A[FGooJeU[FOmWVNEWV@03JeUoof]I00][F@05
@Q0Q26]IJeU240018@P00004JeUoof]IJeWoIiWUIiT00f]IOom[F@0;JeT0
1D8@8@Q[FF]I@Q000B48000016]IOom[FF]IofNIiFNI00=[FGooJeT02f]I
00E24248JeU[FD8@004Q200000A[FGooJeU[FOmWVNEWV@03JeUoof]I00][
F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeWo6]KU6]H00f]IOom[F@0;
JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]Ioa[FiA[F00=[FGooJeT0
2f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FOlJe^DJeP03JeUoof]I
00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeWo6]KU6]H00f]IOom[
F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]Ioa[FiA[F00=[FGoo
JeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FOlJe^DJeP03JeUo
of]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeWo6]KU6]H00f]I
Oom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]Ioa[FiA[F00=[
FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FA/JePAoo`lJ
ePAoof4JePEooh<JePEoobLJePMooiHJeP03JeUoof]I00][F@05@Q0Q26]I
JeU240018@P00004JeUoof]IJeTK6]H4Ool?6]H4OomQ6]H5Oon36]H5OolW
6]H7OonF6]H00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[
FF]I6a[F0Woo4a[F0WooHQ[F0WooQQ[F0Woo;1[F0WooV1[F00=[FGooJeT0
2f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FA/JeP9oo`PJeP=oo`PJ
eP9ooa0JeP9oo`046]IoogooOol76]H6Ool36]H8Ool56]H6Ool56]H6Ool6
6]H4Ool;6]H5Ool46]H2Ool00a[FOomoo`02Ool76]H4Ool46]H8Ool56]H5
Ool46]H4Ool00a[FOomoo`02Ool36]H6Ool;6]H5Ool46]H8Ool=6]H2Ool0
11[FOomoogoo1A[F27oo0a[F0goo00@JeWooOolJeP=oo`046]Ioogoo6]H4
Ool46]H8Ool36]H8Ool36]H8Ool66]H2OonG6]H00f]IOom[F@0;JeT01D8@
8@Q[FF]I@Q000B48000016]IOom[FF]I6a[F0Woo21[F0goo21[F0Woo41[F
1goo1A[F27oo0Q[F27oo11[F27oo0a[F27oo11[F1goo21[F1goo0a[F27oo
1A[F1goo0Q[F27oo11[F1goo0a[F17oo00<JeWooOol00Woo0a[F1goo2A[F
1goo0a[F27oo3A[F1goo11[F27oo0a[F0goo00@JeWooOolJeP=oo`036]Io
ogoo00Ioo`<JePQoo`<JePQoo`<JePQoo`HJeP9ooiLJeP03JeUoof]I00][
F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeTK6]H2OolC6]H2Ool@6]H2
Ool46]H2Ool36]H2Ool<6]H2Ool66]H2Ool96]H3Ool56]H00goo6]HJeP02
6]H2Ool36]H2Ool76]H3Ool36]H3Ool26]H3Ool36]H3Ool46]H2Ool36]H2
Ool56]H2Ool66]H3Ool36]H3Ool36]H2Ool36]H2Ool46]H2Ool36]H2Ool8
6]H3Ool36]H3Ool46]H2OolA6]H2Ool46]H2Ool66]H2Ool76]H2Ool011[F
Oomooa[F0Woo0Q[F0goo0a[F0goo1A[F0Woo2A[F0Woo21[F0Woo2A[F17oo
UQ[F00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FA/J
eP9oo`TJeP9oo`PJeP9ooa0JeP9oo`@JeP9oo`<JePUoo`DJeP9oo`HJePUo
o`8JeP9oo`/JeP9oo``JeP9oo`DJeP9oo`8JeP9oo`DJeP9oo`@JeP9oo`XJ
eP9oo`HJeP9oo`DJeP9oo`<JeP9oo`<JeP9oo`HJePEoo`PJeP9oo`DJeP9o
o`@JeP9ooa4JeP9oo`@JeP9oo`HJeP9oo`LJeP9oo`046]Ioogoo6]H2Ool2
6]H2Ool56]H2Ool56]H2Ool96]H2Ool86]H2Ool96]H2Ool00a[FOomoo`2E
6]H00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]I6a[F
0Woo2A[F0goo1a[F0Woo51[F17oo0a[F2Goo1A[F0Woo1Q[F2Goo0Q[F0Woo
1A[F0Woo11[F0Woo31[F0Woo1A[F0Woo0Q[F0Woo1A[F0Woo11[F0Woo2Q[F
0Woo1Q[F0Woo1A[F0Woo0a[F0Woo0a[F0Woo11[F1Goo2Q[F0Woo1A[F0Woo
11[F0Woo5A[F17oo1Q[F0Woo1a[F0Woo00@JeWooOolJeP9oo`8JeP9oo`DJ
eP9oo`DJeP9oo`TJeP9oo`PJeP9oo`PJeP9oo`8JeP9ooiDJeP03JeUoof]I
00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeTK6]H2Ool96]H4Ool6
6]H2OolA6]H6Ool46]H2Ool56]H2Ool56]H2Ool66]H2Ool56]H2Ool26]H3
Ool46]H2Ool46]H2Ool<6]H3Ool36]H3Ool26]H3Ool36]H3Ool46]H2Ool:
6]H2Ool66]H3Ool36]H3Ool36]H3Ool26]H2Ool46]H2Ool36]H2Ool86]H3
Ool36]H3Ool46]H2OolB6]H6Ool76]H2Ool76]H2Ool011[FOomooa[F0Woo
0Q[F0goo0a[F0goo1A[F0Woo2A[F0Woo21[F0Woo1a[F0Woo11[F0WooU1[F
00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FA/JeP9o
o`/JeP9oo`HJeP9ooa0JePAoo`PJePMoo`HJeP9oo`LJePMoo`@JePQoo`8J
ePQoo`TJePMoo`8JePUoo`<JePQoo`@JePAoo`LJePMoo`<JePQoo`@JePMo
o`TJePMoo`<JePQoo`dJePAoo`PJePAoo`HJePUoo`036]Ioogoo00Moo`HJ
eP9oo`LJePAoo`HJePQoo`8JePAoo`8JePAooi<JeP03JeUoof]I00][F@05
@Q0Q26]IJeU240018@P00004JeUoof]IJeTK6]H2Ool66]H2Ool36]H2Ool6
6]H2Ool@6]H2Ool46]H2Ool56]H5Ool76]H2Ool86]H5Ool66]H5Ool011[F
OolJeQ[F27oo2Q[F1Goo0a[F0goo00<JeWooOol00Woo11[F27oo11[F17oo
21[F1Goo11[F0goo00@JeWooOomoo`HJePIoo`XJePEoo`@JePQoo`dJeP9o
o`@JeP9oo`@JePAoo`HJePEoo`036]Ioogoo008JeP=oo`036]Ioogoo009o
o`LJeP9oo`LJePAoo`HJePQoo`8JePAoo`8JePAooi<JeP03JeUoof]I00][
F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeTK6]H2Ool66]H2Ool36]H2
Ool66]H2Ool@6]H2Ool46]H2OolA6]H2OolN6]H2OolT6]H2Oom56]H2OolA
6]H2Ool46]H2OolW6]H2OolC6]H2OonS6]H00f]IOom[F@0;JeT01D8@8@Q[
FF]I@Q000B48000016]IOom[FF]I6a[F17oo11[F1Woo1A[F17oo4A[F1goo
3a[F17oo7Q[F0Woo91[F0Woo2Q[F0Woo>A[F1goo3A[F1goo1Q[F0Woo7A[F
17oo2A[F0Woo21[F1gooWQ[F00=[FGooJeT02f]I00E24248JeU[FD8@004Q
200000A[FGooJeU[FA/JePAoo`DJePAoo`HJePAooa8JeP=oo`036]Ioogoo
00lJePAooahJeP9oob@JeP9oo`XJeP9oocXJePIoo`hJeP=oo`036]Ioogoo
00HJeP9ooadJePAoo`TJeP9oo`TJePIooihJeP03JeUoof]I00][F@05@Q0Q
26]IJeU240018@P00004JeUoof]IJeWo6]KU6]H00f]IOom[F@0;JeT01D8@
8@Q[FF]I@Q000B48000016]IOom[FF]Ioa[FiA[F00=[FGooJeT02f]I00E2
4248JeU[FD8@004Q200000A[FGooJeU[FOlJe^DJeP03JeUoof]I00][F@05
@Q0Q26]IJeU240018@P00004JeUoof]IJeWo6]KU6]H00f]IOom[F@0;JeT0
1D8@8@Q[FF]I@Q000B48000016]IOom[FF]Ioa[FiA[F00=[FGooJeT02f]I
00E24248JeU[FD8@004Q200000A[FGooJeU[FOlJe^DJeP03JeUoof]I00][
F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeWo6]KU6]H00f]IOom[F@0;
JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]Ioa[FiA[F00=[FGooJeT0
2f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FOlJe^DJeP03JeUoogoo
00]oo`05@Q0Q26]IJeU240018@P00004JeUoof]IJeWo6]KU6]H?JeT01248
JeU[FD8@0B48000016]IOom[FF]Ioa[FiA[F42480V]I0D8@0B48000016]I
Oom[FF]Ioa[FiA[F00=[FD8@@Q00348@00@Q26]IJeU2404Q200000A[FGoo
JeU[FOlJe^DJeP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUo
of]IJeWo6]KU6]H00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]I
Oom[FF]Ioa[FiA[F00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[
FGooJeU[FOlJe^DJeP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004
JeUoof]IJeWo6]KU6]H016]IOom[FF]I1`000f]I00E24248JeU[FD8@004Q
200000A[FGooJeU[FOlJe^DJeP03JeUoof]I009[F@D000A[F@05@Q0Q26]I
JeU240018@P00004JeUoof]IJeWo6]KU6]H00f]IOom[F@03JeT30005JeT0
1D8@8@Q[FF]I@Q000B48000016]IOom[FF]Ioa[FiA[F00=[FGooJeT016]I
00<006]IJeT016]I00E24248JeU[FD8@004Q200000A[FGooJeU[FOlJe^DJ
eP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeWo6]KU
6]H00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]Ioa[F
iA[F00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FOlJ
e^DJeP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeWo
6]KU6]H00f]IOomoo`0;Ool01D8@8@Q[FF]I@Q000B48000016]IOom[FF]I
oa[FiA[F3f]I00@Q26]IJeU2404Q200000=[FGooJeT0of]In6]I0D8@0B48
000036]IOom[FF]I28h4S@R>18d8[PB=2:h4S@<8[P032:d8[PR^00H8[P0D
3:h8[PR^2:h<c`R^3<h8[Pc?2:h<c`S>3<l<cPc?2<h<c`c>3<l<cPP<c`0D
4>l<ca3_3<l@l0c_4>l<ka3`4>l@l0c_4?0@ka3`4>l@l13_4?0@k`@@l00T
5A0@l1D@4?0E414@5A0A41D@4A0E414@5A4E41DA5A0E4AD@5A4E41DA5A0E
4AD@6C4E4ATa5A4I<ADa6C4E<ATa5C4I<ADa11Ta01@I<QTa6C8I<AUB6C4I
DQTa7E8I<AeB6C4MDQUB7E8IDQeB6E8MDQUB21eB010MLaeB7G<MDR5c7G8Q
Laeb8G<MLR5c7G8QLaec8G<MLPPQL`0@8I<QLb6C8G<UU26C8I@QTbFD8I<U
U26C9I@QTbFD8I<39I@00bFC9I@UU0029I@01BFd9I@U]2FD:K@00bFd00`Y
]BFd:KDU]2Ve9K@Y]BFd:KDY]2Ve:K@2:KD01RWE:K@YeBVe:MDY]@@Ye@0D
;MDYeBgE:MD]eRWE;MDYeBgF;MD]eRWE;OH]eBgf;MD]mRge;OH]m@@]mP09
<OH]mS7f;OHamRgf<OH]mS7g008amP0e;OHb5c7f<QLamS8G<QHb5c8F<QLb
5S8G<QHf5c8G=QLb5cHG<QLf5c8G=QLb5cHG<QLf=cHG=SLf5cHh=SLf>3Hg
=SPf=cHh=SLj>3Hg>SPf=cXh=SPj>3Hh>SPf>3YH=SPjF3Xh>UPj>004>UP0
43YI>UPjFCYH?UTjF3iI>UPnFCYH?UTjF3ii>UTnNCYI33ii00a2NSii@WXn
ND9j?WU2NSii@YXnND:J?WT<@YX044JJ@YY2VT:JAY]2VTJK@YY6^d:JA[]2
VTJkA[Y6^dJj0dJk00=6^TJkA[/00TJk01A:^dJkA[]6^dZkA[]:fdJkB]a6
^d[LA[]:g4[KB]a:fd[LB]]:g4[K0d[L00=:fd[LB]`00T[L00U>o4[LC_a:
g4klB]a>o4[lC_d00Tkl00U:o4kmC_a>oDklC_e>o4kmC_`00dkm00U>o5<M
C_eC7DkmDae?7E<MCad00e<M00=?7E<NDad00U<M01AC7U<MDaiC7E<NDaeC
7U<MEciC7ELnDaeG?U<nEciC?ULnDciG?U<n15Ln55<n0V]I0D8@0B480000
16]IOom[FF]I1@B=00T8[PB=2:h4S@R^18d8[PB]2:h00Woo00<8[@R^2:d0
2PR^018<cPR^3<h8[Pc?2<h<c`S>3<l8cPc?3<h<c`c>3<l<cPc?3<h63<l0
8Q3_3<l@k`c_4>l<ka3_3>l@l0c_4?0@ka3`4>l@l13_4?0@ka3`4>lA413_
4A0@l1D@4?0E414@5A0A41D@4A0E414@0QD@01HE4A4@5A4E41DA5A0E4AD@
5C4E41Da5A0I<AD@6C4E<ATa5C4I<ADa6C4E<@<I<@045C4I<ATa6C836C40
4QUB6C4IDQTa7E8IDAUB6E4MDQUA7E8IDQeB6E8MDQUB7E8IDPHMDP0B7G<M
DQeb7G8QLaeb7G<MLR5c7G8QLaeb8G<MLR5c7G<QLaeb0R5c00LQTb5c8I<Q
Lb6C8G<QT`04Ool02b6C9I@QTbFD8I<UU26C9I@QTbFD8I<00RFD00HU]2FC
9K@UU2Fd9I@69K@04RVd9K@Y]2Fd:KDU]2Ve9K@Y]BFd:KDY]2WE:K@YeBVe
:MDY]0HYe@0F;MDYeBgE:MD]eBWE;MDYeBgF:MD]eRgE;OH]eBgf;OD]mRge
;OH]mBgf;OD2;OH09S7f;OHamRgf<OH]mS7f;OHb5Rgf<QHamS8G<OHb5c8F
<QLb5S8G<QHb5c8F<QLb5SHG<QHf5c8G=QLb5cHG<QLf=c8G=SLf5cHg<QL2
=SL05SHh=SLf>3Hg=SPf=cHh=SLj>3Hg>SPf=cXh=SLj>3Hh>UPf>3YH>SPj
F3Hh1SYH018jFCYH>UPjF3iI>UPjFCYH?UTjF3iI>UPnNCYH?WTjNCii>WT:
?WT03T9j?WTnNCii@WXnND:J?WU2VSii@YXnVD:J?YT3@YX00d:I@YY2VP08
@YX03TJk@YY6^T:JA[]2VTJk@[Y6^d:jA[]6^TJkA[X3A[/00dJjA[]6^`04
A[/04T[KA[]:fdJkB]]6^d[KA]]:g4KKB]a:fd[LB]]:g4[KB]a:f`=:g00=
B]]:g4[LC_a:g4klB]a>o4[lC_a:o4klB_`00Tkl01I>oDklC_e>o4kmC_a>
oDklC_e>o4lMC_aC7DklDae?7E<MCaeC7DlMDae?7@=C7@0FCaeC7E<MDaiC
7E<NDaeC?U<MDciC7ELnDaeG?U<mEciC?ELnDciG?U<mEchDDch2JeT1@Q01
8@P0000>JeUoof]IJeT8SPB=2:h4S@R^18d8[PB=2:h4[@<8[P032:eoogoo
00H8[P0D3:h8[PR^2:h<c`R^3<h8[Pc?2<h<c`S>3<l<cPc?3<h<c`c>3<l<
cP@<c`0H4<l<c`c?3<l@k`c?4>l<ca3`3>l@k`c_4?0@ka3`3>l@l13_4?0@
ka3`4>l@l13_0Q3`00XA413`5A0@l1D@4?0E414@5A0A40<E400I4A0E4AD@
5A4E41DA5A0E4AD@5C4E41Da5A0I<ADA6C4E<ATa5C4I<ADa6C4E<ATa5C40
11Ta01@I<QTa6C8I<AUB6C4IDQTa7E8IDAeB6E4MDQUB7E8IDQeB6E8MDQUB
21eB010MLaeB7G<MDR5c7G8QLaeb8G<MLR5c7G8QLaec8G<ML`PQL`098I<Q
Lb6C8G<UU7oo9I@QTbFD009oo`058I<UU26C9I@QT`039I@01bFC9K@UU2Fd
9I@U]2FD008U]00D:K@U]2Fd9K@Y]BFd:KDU]2Ve9K@Y]BFd:KDY]2Ve:K@Y
eBVe:MDY]0@Ye@0H;MDYeBWE:MD]eBWE;MDYeBgF:MD]eBWE;MH]eBgF;MD]
mRgE;OH]eBgf;OD]mRge12gf00TamRgf<OH]mS7f;OHamRgf<OL00S7f034]
mS8G<OHb5c7f<QLb5S8G<QHb5c8F<QLb5SHG<QLf5c8G=QLb5cHG<QLf=cHG
=SLb5cHh=QLf=cHG=SPf=cHh=SLf>3Hg=SPf=cXh=SLj>3Hg>SPf>3Xh=SPj
F3Hh>UPf>008>UP043YI>UPjFCYH?UTjF3iI>UPnFCYH?UTjF3ii>UTnNCYI
33ii00a2NSii@WXnND9j?WU2NSii@YXnND:J?WT<@YX044JJ@YY6VT:JAY]2
VTJk@YY6^d:JA[]2VTJkA[Y6^dJj0dJk00=6^TJkA[/00TJk01A:^dJkA[]6
^d[KA[]:fdJkB]a6fd[LA]]:g4[KB]a:fd[LB]]:g4[K0d[L00=:fdkLB]`0
0T[L00U>o4[LC_a:g4klB_a>o4[lC_d00dkl00Q>oDklC_e>o4kmC_a>oDkl
0dkm00U>o5<MC_eC7DkmDae?7E<MCad00e<M00=?7E<NDad00U<M011C7U<M
DaiC7E<NDaeC?U<MEciC7ELnDaeG?U<nEciC?P=G?P03DciG?ULn018Q209C
?P9[F@52404Q200000A[FGooJeU[F@L4S@072:h4S@R^18d8[PB]2:h00Woo
00D4[@R^2:h8[PR]00P8[P0D2<h8[Pc>2:h<cPS>3<l8cPc?2<h<c`S>3<l<
cPc?3<h<c`c>3<l<cP8<c`0V3>l<c`c_3<l@k`c?4>l<ka3_3>l@k`c_4?0<
ka3`4>l@l13_4?0@ka3`4>l@l13_4A0@ka4@4?0E413`5A0A41D@4A0E414@
5A0A408E400F5A4E41DA5A0E4AD@5A4E41Da5A0E<AD@6C4E<1Ta5C4I<ADa
6C4E<ATa5C436C405ADa6C4I<ATb6C4IDATa6E8I<AUB6E4MDQUA7E8IDAeB
6E4MDQUB7E8IDP037E802AUB7E8MDQeb7E8MLQeB7G<MDP027G803R5c7G8M
Laeb8G<MLR5c7G8QLaeb8G<MLb5c7G828G<01R6C8G<QTb5c8I<QL`8QT`0>
9IAoogoo8I<UU26C9I@QTbFD8I<UU26C9I@QT`8UU0049K@UTbFd9I@89K@0
3RVd9K@Y]2Fd:KDU]2Ve9K@Y]BFd:KDY]2WE:K@3:MD00bWD:MDYe@04:MD0
5RgE:MD]eBWE;MDYeBgE:MD]mRWE;OH]eBgf;MD]mRge;OH]mBgf;OD]mRge
0Rgf02HamRgf<OH]mS7f;OHamRgf<QH]mS8F<OHb5c7f<QLb5S8G<QHb5c8F
<QLb5S8G<QHf5c8F=QLb5cHG<QLf5c8G=SLb5cHg=QLf=c8g0SHg018f>3Hg
=SPf=cHh=SLf>3Hg>SPf=cXh=SLj>3Hg>SPf>3YH=SP3>UP00cIH>UPjF004
>UP03SYI>UPjF3YH?UTjF3iI>UPnNCYH?WTjF3ii>UP3?WT00cYi?WTnN@08
?WT03T9j?WTnNCii@YXnND:J?WU2VSii@YXnVD:J?YT:@YX04TJJ@YY2VT:J
A[]2VTJj@YY6^d:JA[]2^TJk@[Y6^dJjA[]6^P=6^`03A[Y6^dJk00A6^`0B
B]]6^d[KA]]:fdKKB]]6fd[LA]]:g4[KB]a:fd[LB]]:g4[K0T[L00i:o4[K
B_a:g4klB]a>o4[lC_a:o4klB_a>o4[l0Tkl01I>oDklC_e>o4kmC_a>oDkl
Cae>o4lMC_eC7DklDae?7E<MCaeC7DlMDae?7@IC7@0BDaiC7E<NDaeC?U<M
DciC7ELnDaeG?U<mEciC?ELnDciG?Woo448@00<Q25<nDch00V]I0D8@0B48
00002F]IOom[FF]I28h4S@R>18d8[P05Ool010R^2:d8[PR^1Woo00D<[PR^
2:h8[Pc?00=oo`083<l8[WooOol<c`c>3<l8cPAoo`<<c`9oo`<<c`054>mo
ogoo3<l@l005Ool01a3`3>l@l13_4?0@ka3`00Ioo`054?0E413`5A0@l005
Ool00a4@5A0A4002Ool011DA5A0E4AD@1Goo00@E41Ta5A4I<@Aoo`045C4I
<ADa6C43Ool26C400aTbOomoo`02Ool00aTa6E8I<@02Ool02AeB6C4MDQUB
7E8IDQeB6E8MDP07Ool27E800aec7E8ML`02Ool00aeb8G<MLP07Ool011eb
8G=oogoo125c17oo00DQLbFD8I<QU26C00=oo`058I=oogoo9I@QT`039I@0
0bFC9I@UU0029I@01BFd9I@U]2FD:K@00bFd00`Y]BFd:KDU]2Ve9K@Y]BFd
:KDY]2Ve:K@2:KD01RWE:K@YeBVe:MDY]@@Ye@0D;MDYeBgE:MD]eRWE;MDY
eBgF;MD]eRWE;OH]eBgf;MD]mRge;OH]m@@]mP09<OH]mS7f;OHamRgf<OH]
mS7g008amP0e;OHb5c7f<QLamS8G<QHb5c8F<QLb5S8G<QHf5c8G=QLb5cHG
<QLf5c8G=QLb5cHG<QLf=cHG=SLf5cHh=SLf>3Hg=SPf=cHh=SLj>3Hg>SPf
=cXh=SPj>3Hh>SPf>3YH=SPjF3Xh>UPj>004>UP043YI>UPjFCYH?UTjF3iI
>UPnFCYH?UTjF3ii>UTnNCYI33ii00a2NSii@WXnND9j?WU2NSii@YXnND:J
?WT<@YX044JJ@YY2VT:JAY]2VTJK@YY6^d:JA[]2VTJkA[Y6^dJj0dJk00=6
^TJkA[/00TJk01A:^dJkA[]6^dZkA[]:fdJkB]a6^d[LA[]:g4[KB]a:fd[L
B]]:g4[K0d[L00=:fd[LB]`00T[L00U>o4[LC_a:g4klB]a>o4[lC_d00Tkl
00U:o4kmC_a>oDklC_e>o4kmC_`00dkm00U>o5<MC_eC7DkmDae?7E<MCad0
0e<M00=?7E<NDad00U<M01AC7U<MDaiC7E<NDaeC7U<MEciC7ELnDaeG?U<n
EciC?ULnDciG?U<n15Ln00=oof]IJeT03F]I00A24248DciC?P9[F@52404Q
200000A[FGooJeU[F@<4S@=oo`0318d8[PB=00=oo`071:d8[WooOol8[@R^
2:d00Woo0`R^0Woo0`R^00H<cWooOol8[Pc?2<h2Ool01Pc?2<ioogoo3<l<
cP9oo`043<l<cPc?3<l2Ool01Pc?Ool@k`c?4>l<k`9oo`054>l<ka3`3>l@
l002Ool0113_4?0@ka3`0Woo00<@ka4@4>l00Woo00LE413`5A0A47oo4A0E
4002Ool00a4@5A0E4002Ool01aDA5A0E4AD@OolE41Da009oo`065A0I<AD@
OolE<ATa0Woo00@E<ATa5C4I<@9oo`045C4I<GooOol26C42Ool02ATa6E8I
<AeB6E4IDQUA7E8ID@02Ool011eB6E8MDQUB0goo0aeB0Woo00PMLaeBOomo
ob5c7G8MLaeb0Woo00LQLaebOomoob5c7G<QL`02Ool01b5c8I=oogoo8G<Q
Tb5c009oo`8QT`=oo`098I<UU26C9I@QTbFD8I<UU26C008UU0069K@UTbFd
9I@U]2FD1RFd018Y]2Fd:K@U]2Ve9K@Y]BFd:KDU]2Ve:K@YeBVd:MDY]BWE
:K@6:MD05RgE:MD]eBWE;MDYeBgE:MD]eRWE;MH]eBgf;MD]mRge;OH]mBgf
;OD]mRge0Rgf02HamRgf<OH]mS7f;OHamRgf<QH]mS8F<OHb5c7f<QLb5S8G
<QHb5c8F<QLb5S8G<QHf5c8F=QLb5cHG<QLf5c8G=SLb5cHg=QLf=c8G0SHg
01Hf>3Hg=SPf=cHh=SLf>3Hg>SPf=cXh=SLj>3Hg>SPf>3YH=SPjF3Xh>UPf
>0HjF00B>UTjF3YH>UPnFCYH>UTjF3iI>UPnFCYH?WTjF3ii>WTnNCYi2Sii
00i2NSii?WTnND9j?WU2VSii@YXnND:J?YU2VSjI0d:J00=2VD:J@YX024:J
00i6^d:JA[Y2VTJk@YY6^d:jA[]2^TJkA[Y6^dJj0dJk00=6^TJkA[/014Jk
019:fdJkB]]6^d[KA[]:fdKKB]a6fd[LB]]:g4[KB]a:fd[LB]/3B]`03D[K
B]a:g4klB]a>o4[LC_a:o4klB_a>o4[l009>o00FC_e>o4kmC_a>oDklC_e>
o4kmC_a?7DklDae>o5<MCaeC7DlMDae?7E<MCad3Dad05dlMDaeC7E<NDaeC
7U<MDciC7E<nDaeG?U<MEciC?ELnDceG?U<nEciC?ELnOol03f]I00A24248
DciC?P9[F@52404Q200000M[FGooJeU[F@R>18d8[P02Ool01@B=2:h4S@R^
1:d00Woo00@8[PR]Oomoo`@8[P9oo`083:h8[WooOol<c`R^3<h8[P9oo`08
3<l8cWooOol<c`c>3<l<cP9oo`053<moogoo3<l@c`023<l2Ool01Pc?4>l<
ca3`3>l@k`9oo`054>l@l0c_4?0@k`02Ool01A3`4>l@l13_4?000Woo00T@
l7ooOolE413`5A0A41D@4A000QD@0Woo00/E4AD@OomooaDA5A0E4AD@5C4E
41Da009oo`075A4I<ADa6C4E<ATa5C400Woo00<I<ADa6C400Woo00@I<ATb
6C4I<P9oo`0<6C5oogoo7E8IDAeB6E4MDQUB7E8IDQeB0Woo00<IDQeB7E80
0QeB0Woo0QeB00DMLgooOolMDR5c009oo`047G8QLaeb8G<2Ool011ec8G=o
ogoo0R5c0Woo0b5c00@QTgooOolQL`9oo`049I@QTbFD8I<2Ool012FD8I<U
U26C0bFD00LUTbFd9I@U]2FD9K@UU0029K@052Vd9K@U]2Fd:KDU]2Ve9K@Y
]BFd:KDU]2Ve:K@Y]BVd:MDY]BWE:K@4:MD062gE:MDYeBWE;MDYeBgE:MD]
eRWE;MDYeBgF;MD]eRgE;OH]eBgf;MD]mRge;OH]m@@]mP09<OH]mS7f;OHa
mRgf<OH]mS7g008amP0a;OHb5c7f<QLamS8G<QHb5c8F<QLb5S8G<QHf5c8G
=QLb5cHG<QLf5c8G=SLf5cHg<QLf>3HG=SLf5cHh=SLf>3Hg=SPf=cHh=SLj
>3Hg>SPf=cXh=SPj>3Hh>UPf>3YH=SP023YH010jFCYH>UTjF3iI>UPnFCYH
?UTjF3iI>UPnNCYI?WTjF@`nN@0<@WXnND9j?WU2NSii@WXnND:J?WU2VSii
34:J0116VT:JAYY2VTJK@YY6^d:JA[]2VTJk@YY6^dJjA[]6^P=6^`03A[Y6
^dJk0096^`0DB[]6^dJkA[]:fdJkB]]6^d[LA]]:g4KKB]a:fd[LB]]:g4[K
B]a:f`=:g003B]]>g4[L009:g009C_a:g4klB]a>o4[lC_a:o4km00=>o008
C_e>o4kmC_a>oDklC_e>o0=>o@09C_aC7DkmDae>oE<MCaeC7DlM00=C7@03
CaeC7U<M009C7@0@DaiC7E<NDaeC7U<MDciC7ELnDaeG?U<MEciC?ULnDch3
Ech015<nEciG?Woo16]I0P0016]I0P000f]I00A24248DciC?P9[F@52404Q
200000A[FGooJeU[F@84S@9oo`<4S@042:h4S@R^18d2Ool010R^Oomoo`B]
0`R^0Woo0PR^0Woo0`R^00D8cWooOol8[Pc>009oo`042<h<c`S>3<l2Ool0
1`c>Oomoo`c?3<h<c`c>009oo`033>l<cgoo00Eoo`0<4>l<ka3_3>l@l0c_
4?0@ka3`4>l@l13_0Woo00/@l7ooOol@ka4@4?0E413`5A0A41D@009oo`0;
4A0E47ooOolE41DA5A0E4AD@5A4E4002Ool01aDa5A0E<AD@6C4E<1Ta009o
o`035C4I<ADa009oo`<I<@045C5oogoo6C82Ool02ATa6E8I<AUB6E4MDQUA
7E8ID@02Ool011eB6E8MDQUB0QeB0Woo0QeB0Woo00@MLQeBOomoo`8MLP06
8G<MLWooOolQLaeb0Woo00HQLaebOomoob5c7G828G<2Ool0126COomoob5c
0R6C00hUU7ooOolQTbFD8I<UU26C9I@QTbFD8I<UU26C0RFD00@U]2FC9K@U
U0PU]00>:K@U]2Vd9K@Y]BFd:KDU]2Ve9K@Y]BVd:MDY]0<Ye@03:M@YeBWE
00@Ye@0F;MDYeBgE:MD]eBWE;MDYeBgf:MD]mRgE;OH]eBgf;OD]mRge;OH]
mBgf;OD2;OH09S7f;OHamRgf<OH]mS7f;OHb5Rgf<QHamS8G<OHb5c8F<QLb
5S8G<QHb5c8F<QLb5SHG<QHf5c8G=QLb5cHG<QLf=c8G=SLf5cHg<SL2=SL0
4SHh=SLf>3Hg=SPf=cHh=SLj>3Hg>SPf=cXh=SLj>3Hh>UPf>0<jF003=UPj
F3YH00@jF00>>UTjF3YH>UPnFCYH?UTjF3ii>UPnNCYH?WTjF0<nN@03>WTn
NCii00PnN@0>@WXnNCii?WU2VSii@YXnND:J?WU2VSjI@YXnV@Y2VP0BAYY2
VT:J@YY6^d:JA[Y2VTJk@YY6^d:jA[]2^TJkA[Y6^dJj0dJk00=6^TJkA[/0
14Jk019:fdJkB]]6fd[KA]]:fdKKB]a6fd[LB]]:g4[KB]a:fd[LB]/2B]`0
3T[lB]]:o4[LC_a:g4klB_a>o4[lC_a:o4klB_`2C_`05TkmC_a>oDklC_e>
o4kmC_a?7DklCae>oE<MC_aC7DlMDae?7E<MCaeC7DlM1U<M019C7U<MDaiC
7E<nDaeC?U<MEciC7ELnDceG?U<mEciC?ULnOol4JeT30002JeT30003JeT0
148@8@QC?U<n0V]I0D8@0B4800001V]IOom[FF]I28h4S@9oo`042:h4S@R^
18d32:h2Ool00`R^Oomoo`042:h2Ool22:h2Ool010c>2:h<c`R^0Woo00P<
c`c>Oomoo`c?3<h<c`c>0Woo00<<cgooOol00`c?00@@kgooOol<c`Ioo`0;
4?0<ka3`4>l@l13_4?0@ka3`4>l@l004Ool00a3`Oomoo`06Ool01QD@4A1o
ogoo5A4E40Qoo`0:6C5oogoo5A4I<ADa6C4E<ATa5C42Ool36C42Ool011Ta
6C8I<AUB0Woo00`I<GooOolMDQTa7E8IDQeB6E8MDQUB7E82Ool67E82Ool0
1aeB7G=oogoo7G8QLaeb00Moo`047G8QLgooOol28G<2Ool0125c8I<QLb6C
0Woo00LQTgooOolUU26C9I@QT`02Ool00bFD8I<UU0029I@00bFC9I@UU002
9I@01BFd9I@U]2FD:K@00bFd00`Y]BFd:KDU]2Ve9K@Y]BFd:KDY]2Ve:K@2
:KD01RWE:K@YeBVe:MDY]@@Ye@0D;MDYeBgE:MD]eRWE;MDYeBgF;MD]eRWE
;OH]eBgf;MD]mRge;OH]m@@]mP09<OH]mS7f;OHamRgf<OH]mS7g008amP0e
;OHb5c7f<QLamS8G<QHb5c8F<QLb5S8G<QHf5c8G=QLb5cHG<QLf5c8G=QLb
5cHG<QLf=cHG=SLf5cHh=SLf>3Hg=SPf=cHh=SLj>3Hg>SPf=cXh=SPj>3Hh
>SPf>3YH=SPjF3Xh>UPj>004>UP043YI>UPjFCYH?UTjF3iI>UPnFCYH?UTj
F3ii>UTnNCYI33ii00a2NSii@WXnND9j?WU2NSii@YXnND:J?WT<@YX044JJ
@YY2VT:JAY]2VTJK@YY6^d:JA[]2VTJkA[Y6^dJj0dJk00=6^TJkA[/00TJk
01A:^dJkA[]6^dZkA[]:fdJkB]a6^d[LA[]:g4[KB]a:fd[LB]]:g4[K0d[L
00=:fd[LB]`00T[L00U>o4[LC_a:g4klB]a>o4[lC_d00Tkl00U:o4kmC_a>
oDklC_e>o4kmC_`00dkm00U>o5<MC_eC7DkmDae?7E<MCad00e<M00=?7E<N
Dad00U<M01AC7U<MDaiC7E<NDaeC7U<MEciC7ELnDaeG?U<nEciC?ULnDciG
?U<n15Ln00=oof]IJeT00f]I1P0016]I00A24248DciC?P9[F@52404Q2000
00A[FGooJeU[F@84S@9oo`0718d8[PB=2:h4S@R^18d00Woo00L8[WooOol8
[@R^2:d8[P02Ool22:h2Ool32:h01@c>Oomoo`R^3<l00Woo00@8cPc?2<h<
c`9oo`053<ioogoo3<l<cP023<l2Ool03Pc?Oomoo`c?4>l<ka3_3>l@k`c_
4?0<ka3`4>l7Ool0213_4A1oogoo4?0E413`5A02Ool01Q4@5A1oogoo4A0E
409oo`044A0E4AD@5A42Ool02QD@OomooaDa5A0I<AD@6C4E<ATa0Woo00<E
<ATa5C400Woo00@I<ADa6C4I<@9oo`0<6C5oogoo6C4IDQTa7E8IDAUB6E4M
DQUA0Woo00HMDQUB7E8IDQeB6E82Ool27E82Ool021ec7E8MLQeb8G<MLQec
7G82Ool01R5c7G9oogoo8G<ML`9oo`8QL`058I<QLgooOolQT`02Ool48I<2
Ool02B6C9I@QTbFD8I<UU26C9I@QT`029I@01RFd9I<U]2FD9K@UU0HU]00B
:K@U]2Vd9K@Y]BFd:KDU]2Ve9K@Y]BVd:MDY]2WE:KDYeBVd1RWE01H]eBWE
;MDYeBgE:MD]eBWE;MHYeBgF;MD]mRgE;OH]mBgf;OD]mRge;OH]m@8]mP0V
<OH]mS7f;OHamRgf<OH]mS8F;OHb5S7f<QLamS8G<QHb5c8F<QLb5S8G<QHb
5c8F=QLb5SHG<QLf5c8G=QLb5cHg<QLf=cHG=SLb5`8f=`0F=SPf=cHh=SLf
>3Hg=SPf=cXh=SLj>3Hg>SPf=cXh=SPjF3Hh>UPj>3YH=SP6>UP04SYI>UPj
F3YH?UTjF3YI>UPnFCYH?UTjF3ii>UPnNCYi?WTjN@XnN@0>@WXnNCii?WU2
NSii@YXnND:J?WU2VSjI@YXnV@=2VP03@YU2VT:J00Q2VP0>A[]2VTJj@YY6
^d:JA[]2^TJk@[Y6^dJjA[]6^P=6^`03A[Y6^dJk00A6^`0BB]]6^d[KA[]:
fdJkB]]6fd[LA]]:g4[KB]a:fd[LB]]:g4[K0d[L00e:fd[LB]a>o4[LC_a:
g4klB_a>o4[lC_a:o002C_`05TkmC_a>oDklC_e>o4kmC_a>oDklCae>o5<M
C_aC7DlMDae?7E<MCaeC7DlM0e<M01M?7E<MDaeC7U<MDaiC7E<nDaeC?U<M
EciC7ELnDceG?U<mEciC?ULnDceG?Woo00I[F@@000E[F@04@Q0Q25<nDch2
JeT1@Q018@P00006JeUoof]IJeT8SPB=0Woo00L8[PB=2:h4S@R^1:d8[P02
Ool010R]Oomoogoo0PR^0Woo00<8[Pb^2:h00Woo00@<c`R^3<h8[P9oo`03
3<l8cPc?009oo`063<h<cgooOol<cPc?0goo00<@c`c?3<l00Woo00d<cgoo
Ool@l0c_4>l<kgoo4>l@l0c_4?0@k`05Ool01Q3_4?0@l14@4?0E409oo`03
4?0E414@009oo`8E409oo`035A4E41DA009oo`035A0E4AD@009oo`0:5C4E
47ooOolI<ADa6C5ooaTa5C42Ool011Ta5C4I<ATa0Woo00HI<QTaOomooaUB
6C46Ool01AeB6E8MDQUB7E800Woo00<IDQeB7E800aeB0Woo00`MDQecOomo
oaeB8G<MLWoo7G8QLaeb8G<2Ool011ec8G=oogoo0b5c0Woo0R5c0Woo00<Q
Tb5c9I@00Woo00<QTbFD8I<00Woo00@UU26C9I@QT`<UU0079I<U]2FD9K@U
U2Fd9I@00RFd01@Y]2Fd9K@U]2Ve9K@Y]BFd:KDU]2Ve9K@Y]BVd:KDY]2WE
:KDYeBVd12WE01P]eBWE:MDYeBgE:MD]eBWE;MHYeBgE:MD]eRgE;MH]eBgf
;MD]mRgE;OH]mBgf;OD4;OH02C7f;OHamRgf<OH]mS7f;OHam`02<OH0<Bgf
<QLamS8G<OHb5c8F<QLb5S8G<QHb5c8F=QLb5cHG<QLf5c8G=QLb5cHg=QLf
=c8G=SPf5cHg=QLf>3Hg=SPf=cHh=SLf>3Hg>SPf=cXh=SLj>3Hh>SPf>3YH
=SPjF3Hh00PjF00@>UTjF3YI>UPnFCYH?UTjF3iI>UPnFCYH?WTjFCii>UT<
?WT0349j?WU2NSii@WXnND9j?WU2VSii@YXnN@a2VP0@AYY2VTJJ@YY6Vd:J
A[]2VTJk@YY6^d:JA[]6^TJkA[X3A[/00dJjA[]6^`02A[/054ZkA[]6^dJk
B]]6^d[KA[]:g4KKB]a6fd[LB]]:g4[KB]a:fd[LB]/3B]`00d[KC]a:g002
B]`02DklB]a>o4[LC_a:o4klB_a>o@03C_`024kmC_a>oDklC_e>o4kmC_`3
C_d02DklDae>oE<MC_eC7DlMDae?7@03Dad00dlMDaiC7@02Dad045<NDaeC
7U<MDaiC7E<nDaeG?U<MEciC7ELnDciG?U<n0eLn00AC?ULnEcioo`I[F@@0
00E[F@04@Q0Q25<nDch2JeT1@Q018@P00004JeUoof]IJeT218d2Ool318d0
10R^18d8[PB=0Woo00@8[WooOol4[@=oo`032:d8[PR^00Eoo`082:h8cWoo
Ool8[Pc>2<h<c`Aoo`032<h<c`c>009oo`033<moogoo009oo`033<l<k`c?
00Eoo`063>l@k`c_4>l<ka3`0Woo00X@ka3`4>l@l13_4?0@ka3`4>lA40Eo
o`035A0A41D@009oo`044A0E414@5A05Ool011DA5A0E4AD@17oo00<I<AD`
Ool017oo00<E<ATa5C4017oo0QTa00@I<WooOolI<@=oo`056E4MDQUA7E8I
D@02Ool011eB6E8MDQUB0QeB0Woo0QeB0Woo00@MLQeB7G<MDPEoo`037G8Q
Laeb009oo`048G<MLR5c7G<4Ool01B6C8G<QTb5c8I<01Woo00/QTbFD8I<U
U26C9I@QTbFD8I<UU26C008UU0049K@UTbFd9I@89K@03RVd9K@Y]2Fd:KDU
]2Ve9K@Y]BFd:KDY]2WE:K@3:MD00bWD:MDYe@04:MD05RgE:MD]eBWE;MDY
eBgE:MD]mRWE;OH]eBgf;MD]mRge;OH]mBgf;OD]mRge0Rgf02HamRgf<OH]
mS7f;OHamRgf<QH]mS8F<OHb5c7f<QLb5S8G<QHb5c8F<QLb5S8G<QHf5c8F
=QLb5cHG<QLf5c8G=SLb5cHg=QLf=c8g0SHg018f>3Hg=SPf=cHh=SLf>3Hg
>SPf=cXh=SLj>3Hg>SPf>3YH=SP3>UP00cIH>UPjF004>UP03SYI>UPjF3YH
?UTjF3iI>UPnNCYH?WTjF3ii>UP3?WT00cYi?WTnN@08?WT03T9j?WTnNCii
@YXnND:J?WU2VSii@YXnVD:J?YT:@YX04TJJ@YY2VT:JA[]2VTJj@YY6^d:J
A[]2^TJk@[Y6^dJjA[]6^P=6^`03A[Y6^dJk00A6^`0BB]]6^d[KA]]:fdKK
B]]6fd[LA]]:g4[KB]a:fd[LB]]:g4[K0T[L00i:o4[KB_a:g4klB]a>o4[l
C_a:o4klB_a>o4[l0Tkl01I>oDklC_e>o4kmC_a>oDklCae>o4lMC_eC7Dkl
Dae?7E<MCaeC7DlMDae?7@IC7@0BDaiC7E<NDaeC?U<MDciC7ELnDaeG?U<m
EciC?ELnDciG?Woo1F]I1P0016]I00A24248DciC?P9[F@52404Q200000M[
FGooJeU[F@R>18d8SP02Ool00`B=2:h4S@022:h2Ool82:h010b^2:h8[PR^
0Woo00h<cPR^3<l8[Pc?2<h<c`c>3<l8cPc?3<h<c`c>20c?010@k`c?4>l<
ca3`3>l@k`c_4?0@ka3`3>l@l13_4?0@k`9oo`034?0@ka3`008@l09oo`0;
4?0E413`5A0A41D@4A0E414@5A0A4002Ool051DA5A0E4AD@5A4E41DA5A0E
4AD@6C4E4ATa5A4I<ADa6C4E<ATa5C42Ool46C404aTb6C4I<QTa6E8I<AUB
6C4MDQTa7E8I<AeB6E8MDQUB7E8IDQeB009oo`DMDP9oo`0A7G<MDQec7E8Q
Laeb8G<MLR5c7G8QLaeb8G<MLb5c7G8QL`02Ool58G<0426C8G<QTb5c9I@Q
Tb6D8I<UU26C9I@QTbFD8I<UU26C0bFD00<UTbFD9I@00RFD00DU]2FD9K@U
U2Vd00<U]00<:KDU]2Ve9K@Y]BFd:KDU]2Ve:K@Y]BVd0RVe00HYeBVd:MDY
]BWE:KD4:MD052gE:MD]eBWE;MHYeBgE:MD]eRgE;MHYeBgf;MD]mRgE;OH]
mBgf;OD4;OH02C7f;OHamRgf<OH]mS7f;OHam`02<OH0=Bgf<QLamS8G<OHb
5c8F<QLb5S8G<QHb5c8F=QLb5cHG<QLf5c8G=QLb5cHG<QLf5c8G=SLf5cHg
=QLf>3Hg=SPf=cHh=SLf>3Hg>SPf=cXh=SLj>3Hh>SPf>3Xh=SPjF3Hh>UPj
>3YH>SP013YH010jFCYH>UTjF3iI>UPnFCYH?UTjF3iI>UPnNCYI?WTjF@`n
N@0<@WXnND9j?WU2NSii@WXnND:J?WU2VSii34:J0116VT:J@YY2VTJK@YY6
Vd:JA[]2VTJk@YY6^dJjA[]6^P=6^`03A[Y6^dJk0096^`0DB[]6^dJkA[]:
^dJkB]]6^d[LA[]:g4JkB]a:fd[LB]]:g4[KB]a:f`=:g003B]]:g4[L009:
g009C_a:g4klB]a>o4[LC_a:o4km009>o009B_a>oDklC_e>o4kmC_a>oDkl
00=>o@09C_aC7DkmDae>oE<MCaeC7DlM00=C7@03CaeC7U<M009C7@0DDaiC
7E<NDaeC7U<MDaiC7ELnDaeG?U<MEciC?ULnDciG?U<nEciC?PAG?P03Oom[
FF]I009[F@<0009[F@<000=[F@04@Q0Q25<nDch2JeT1@Q018@P00004JeUo
of]IJeT318d3Ool00`B=2:h4S@03Ool01`B]2:h4[@R^2:d8[PR]00D8[P9o
o`<8[P0B3<ioogoo2:h<c`S>3<l8cPc?2<h<c`c>3<l<cPc?3<h<c`c>1Pc?
00`@k`c?4>l<ka3_3>l@k`c_4?0<ka3`4>l2Ool0113`4>l@l13_0Woo00/A
413_4A0@l1D@4?0E414@5A0A41D@009oo`0D4A0E41D@5A4A41DA5A0E4AD@
5A4E41Da5A0E<AD@6C4E41Ta5C4I<@9oo`035C4I<ADa00<I<@045C4I<ATa
6C836C402QUB6C4IDQTa7E8IDAUB6E4MDQUA0Woo00@MDQUB7E8IDP=oo`<M
DP9oo`0<7G<MDQeb7G8QLaeb7G<MLR5c7G8QLaeb0Woo00@QLaec8G<MLP8Q
L`068I<QLb6C8G<QTb5c1R6C00XUU26C9I@QTbFD8I<UU26C9I@QT`8UU006
9K@UTbFd9I@U]2FD1RFd018Y]2Fd:K@U]2Ve9K@Y]BFd:KDU]2Ve:K@YeBVd
:MDY]BWE:K@6:MD05RgE:MD]eBWE;MDYeBgE:MD]eRWE;MH]eBgf;MD]mRge
;OH]mBgf;OD]mRge0Rgf02HamRgf<OH]mS7f;OHamRgf<QH]mS8F<OHb5c7f
<QLb5S8G<QHb5c8F<QLb5S8G<QHf5c8F=QLb5cHG<QLf5c8G=SLb5cHg=QLf
=c8G0SHg01Hf>3Hg=SPf=cHh=SLf>3Hg>SPf=cXh=SLj>3Hg>SPf>3YH=SPj
F3Xh>UPf>0HjF00B>UTjF3YH>UPnFCYH>UTjF3iI>UPnFCYH?WTjF3ii>WTn
NCYi2Sii00i2NSii?WTnND9j?WU2VSii@YXnND:J?YU2VSjI0d:J00=2VD:J
@YX024:J00i6^d:JA[Y2VTJk@YY6^d:jA[]2^TJkA[Y6^dJj0dJk00=6^TJk
A[/014Jk019:fdJkB]]6^d[KA[]:fdKKB]a6fd[LB]]:g4[KB]a:fd[LB]/3
B]`03D[KB]a:g4klB]a>o4[LC_a:o4klB_a>o4[l009>o00FC_e>o4kmC_a>
oDklC_e>o4kmC_a?7DklDae>o5<MCaeC7DlMDae?7E<MCad3Dad05dlMDaeC
7E<NDaeC7U<MDciC7E<nDaeG?U<MEciC?ELnDceG?U<nEciC?ELnOol016]I
0P0016]I0P000f]I00A24248DciC?P9[F@52404Q200000U[FGooJeU[F@R>
18d8[PB=2:h01Goo0`R^00<8[@R^2:h01PR^00P<[PR^2:h8[Pc?2:h<cPR^
0Woo00X<c`S>3<l<cPc?3<h<c`c>3<l<cP@<c`0D4<l<c`c?3<l@k`c?4>l<
ca3`3>l@k`c_4?0@ka3`3>l@l13_4?0@k`Ioo`0:4A0@l1D@4?0E413`5A0A
41D@4A025A02Ool061DA5A0E4AD@5A4E41DA5A0E<AD@5C4E41Ta5A4I<ADa
6C4E<ATa5C4I<ADa6C4E<@@I<@0A6C8I<ATb6C4IDQTa6E8I<AeB6E4MDQUA
7E8IDQeB6E8MDP07Ool47E803aecOomooaeB8G<MLR5c7G8QLaeb8G<MLR5c
7G<QL`02Ool78G<0426C8G<QTb5c9I@QTbFD8I<UU26C9I@QTbFD8I<UU26C
0bFD00LUTbFd9I@U]2FD9K@UU0029K@052Vd9K@U]2Fd:KDU]2Ve9K@Y]BFd
:KDU]2Ve:K@Y]BVd:MDY]BWE:K@4:MD062gE:MDYeBWE;MDYeBgE:MD]eRWE
;MDYeBgF;MD]eRgE;OH]eBgf;MD]mRge;OH]m@@]mP09<OH]mS7f;OHamRgf
<OH]mS7g008amP0a;OHb5c7f<QLamS8G<QHb5c8F<QLb5S8G<QHf5c8G=QLb
5cHG<QLf5c8G=SLf5cHg<QLf>3HG=SLf5cHh=SLf>3Hg=SPf=cHh=SLj>3Hg
>SPf=cXh=SPj>3Hh>UPf>3YH=SP023YH010jFCYH>UTjF3iI>UPnFCYH?UTj
F3iI>UPnNCYI?WTjF@`nN@0<@WXnND9j?WU2NSii@WXnND:J?WU2VSii34:J
0116VT:JAYY2VTJK@YY6^d:JA[]2VTJk@YY6^dJjA[]6^P=6^`03A[Y6^dJk
0096^`0DB[]6^dJkA[]:fdJkB]]6^d[LA]]:g4KKB]a:fd[LB]]:g4[KB]a:
f`=:g003B]]>g4[L009:g009C_a:g4klB]a>o4[lC_a:o4km00=>o008C_e>
o4kmC_a>oDklC_e>o0=>o@09C_aC7DkmDae>oE<MCaeC7DlM00=C7@03CaeC
7U<M009C7@0@DaiC7E<NDaeC7U<MDciC7ELnDaeG?U<MEciC?ULnDch3Ech0
15<nEciG?Woo3f]I00A24248DciC?P9[F@52404Q200000A[FGooJeU[F@L4
S@0:2:h4S@R^18d8[PB]2:h4[@R^1:d32:h00`R]2:h8[P062:h050S>2:h<
cPR^3<h8cPc?2<h<c`S>3<l8cPc?3<h<c`c>3<l<cPc?3<h23<l08@c_3<l<
k`c?4>l<ca3_3>l@k`c_4>l<ka3`3>l@l13_4?0@ka3`4>l@l13_4?0@ka4@
4>lA413`5A0@l1D@4A0E4002Ool00a4@5A0A40025A005QDA5A0E4AD@5A4E
41DA5A0E<AD@5C4E41Ta5C0I<ADa6C4E<ATa5C4I<ADa0aTa01DE<ATa6C4I
<QTa6E4I<AUB6C4IDQUA7E8IDAeB6E4MDQUA7E8IDQeB6E800aeB00TIDQeB
7E8MLQeB7G8MDQec7E800Qeb00HQLaeb7G<MLR5c7G82Ool01R5c7G8QLaec
8G<MLP8QL`068I<QLb6C8G<QTb5c0R6C00hUU26C8I<QTbFD8I<UU26C9I@Q
TbFD8I<UU26C0RFD00@U]2FC9K@UU0PU]00>:K@U]2Vd9K@Y]BFd:KDU]2Ve
9K@Y]BVd:MDY]0<Ye@03:M@YeBWE00@Ye@0F;MDYeBgE:MD]eBWE;MDYeBgf
:MD]mRgE;OH]eBgf;OD]mRge;OH]mBgf;OD2;OH09S7f;OHamRgf<OH]mS7f
;OHb5Rgf<QHamS8G<OHb5c8F<QLb5S8G<QHb5c8F<QLb5SHG<QHf5c8G=QLb
5cHG<QLf=c8G=SLf5cHg<SL2=SL04SHh=SLf>3Hg=SPf=cHh=SLj>3Hg>SPf
=cXh=SLj>3Hh>UPf>0<jF003=UPjF3YH00@jF00>>UTjF3YH>UPnFCYH?UTj
F3ii>UPnNCYH?WTjF0<nN@03>WTnNCii00PnN@0>@WXnNCii?WU2VSii@YXn
ND:J?WU2VSjI@YXnV@Y2VP0BAYY2VT:J@YY6^d:JA[Y2VTJk@YY6^d:jA[]2
^TJkA[Y6^dJj0dJk00=6^TJkA[/014Jk019:fdJkB]]6fd[KA]]:fdKKB]a6
fd[LB]]:g4[KB]a:fd[LB]/2B]`03T[lB]]:o4[LC_a:g4klB_a>o4[lC_a:
o4klB_`2C_`05TkmC_a>oDklC_e>o4kmC_a?7DklCae>oE<MC_aC7DlMDae?
7E<MCaeC7DlM1U<M019C7U<MDaiC7E<nDaeC?U<MEciC7ELnDceG?U<mEciC
?ULnOol?JeT0148@8@QC?U<n0V]I0D8@0B48000036]IOom[FF]I28h4S@R>
18d8[PB=2:h4S@<8[P032:d8[PR^00H8[P0D3:h8[PR^2:h<c`R^3<h8[Pc?
2:h<c`S>3<l<cPc?2<h<c`c>3<l<cPP<c`0D4>l<ca3_3<l@l0c_4>l<ka3`
4>l@l0c_4?0@ka3`4>l@l13_4?0@k`@@l00T5A0@l1D@4?0E414@5A0A41D@
4A0E414@5A4E41DA5A0E4AD@5A4E41DA5A0E4AD@6C4E4ATa5A4I<ADa6C4E
<ATa5C4I<ADa11Ta01@I<QTa6C8I<AUB6C4IDQTa7E8I<AeB6C4MDQUB7E8I
DQeB6E8MDQUB21eB010MLaeB7G<MDR5c7G8QLaeb8G<MLR5c7G8QLaec8G<M
LPPQL`0@8I<QLb6C8G<UU26C8I@QTbFD8I<UU26C9I@QTbFD8I<39I@00bFC
9I@UU0029I@01BFd9I@U]2FD:K@00bFd00`Y]BFd:KDU]2Ve9K@Y]BFd:KDY
]2Ve:K@2:KD01RWE:K@YeBVe:MDY]@@Ye@0D;MDYeBgE:MD]eRWE;MDYeBgF
;MD]eRWE;OH]eBgf;MD]mRge;OH]m@@]mP09<OH]mS7f;OHamRgf<OH]mS7g
008amP0e;OHb5c7f<QLamS8G<QHb5c8F<QLb5S8G<QHf5c8G=QLb5cHG<QLf
5c8G=QLb5cHG<QLf=cHG=SLf5cHh=SLf>3Hg=SPf=cHh=SLj>3Hg>SPf=cXh
=SPj>3Hh>SPf>3YH=SPjF3Xh>UPj>004>UP043YI>UPjFCYH?UTjF3iI>UPn
FCYH?UTjF3ii>UTnNCYI33ii00a2NSii@WXnND9j?WU2NSii@YXnND:J?WT<
@YX044JJ@YY2VT:JAY]2VTJK@YY6^d:JA[]2VTJkA[Y6^dJj0dJk00=6^TJk
A[/00TJk01A:^dJkA[]6^dZkA[]:fdJkB]a6^d[LA[]:g4[KB]a:fd[LB]]:
g4[K0d[L00=:fd[LB]`00T[L00U>o4[LC_a:g4klB]a>o4[lC_d00Tkl00U:
o4kmC_a>oDklC_e>o4kmC_`00dkm00U>o5<MC_eC7DkmDae?7E<MCad00e<M
00=?7E<NDad00U<M01AC7U<MDaiC7E<NDaeC7U<MEciC7ELnDaeG?U<nEciC
?ULnDciG?U<n15Ln00=oof]IJeT03F]I00A24248DciC?P9[F@52404Q2000
00A[FGooJeU[F@D4S@0>2:h4S@R^18d8[PB=2:h4[@R^1:d8[PR]2:h8[@X8
[P0B3<h8[Pc>2:h<c`S>3<l8cPc?2<h<c`c>3<l<cPc?3<h<c`c>1Pc?028@
k`c?4>l<ka3_3>l@k`c_4?0<ka3`4>l@l13_4?0@ka3`4>l@l13_4A0@ka4@
4?0E413`5A0A41D@4A0E414@5A0A408E400F5A4A41DA5A0E4AD@5A4E41Da
5A0E<AD@6C4E41Ta5C4I<ADa6C4E<ATa5C436C4011Da6C4I<ATb0aTa018I
DQTa6E8I<AeB6E4IDQUA7E8IDAeB6E8MDQUB7E8IDQeB6E867E804Qec7E8M
LQeb8G<MLQec7G8QLaeb8G<MLR5c7G8QLaec8G<MLP8QL`068I<QLb6C8G<Q
Tb5c1R6C00XUU26C9I@QTbFD8I<UU26C9I@QT`8UU0069K@UTbFd9I@U]2FD
1RFd018Y]2Fd:K@U]2Ve9K@Y]BFd:KDU]2Ve:K@YeBVd:MDY]BWE:K@6:MD0
5RgE:MD]eBWE;MDYeBgE:MD]eRWE;MH]eBgf;MD]mRge;OH]mBgf;OD]mRge
0Rgf02HamRgf<OH]mS7f;OHamRgf<QH]mS8F<OHb5c7f<QLb5S8G<QHb5c8F
<QLb5S8G<QHf5c8F=QLb5cHG<QLf5c8G=SLb5cHg=QLf=c8G0SHg01Hf>3Hg
=SPf=cHh=SLf>3Hg>SPf=cXh=SLj>3Hg>SPf>3YH=SPjF3Xh>UPf>0HjF00B
>UTjF3YH>UPnFCYH>UTjF3iI>UPnFCYH?WTjF3ii>WTnNCYi2Sii00i2NSii
?WTnND9j?WU2VSii@YXnND:J?YU2VSjI0d:J00=2VD:J@YX024:J00i6^d:J
A[Y2VTJk@YY6^d:jA[]2^TJkA[Y6^dJj0dJk00=6^TJkA[/014Jk019:fdJk
B]]6^d[KA[]:fdKKB]a6fd[LB]]:g4[KB]a:fd[LB]/3B]`03D[KB]a:g4kl
B]a>o4[LC_a:o4klB_a>o4[l009>o00FC_e>o4kmC_a>oDklC_e>o4kmC_a?
7DklDae>o5<MCaeC7DlMDae?7E<MCad3Dad05TlMDaeC7E<NDaeC7U<MDciC
7E<nDaeG?U<MEciC?ELnDceG?U<nEciC?ELn4Goo00<Q25<nDch00V]I0D8@
0B4800003V]IOom[FF]I28h4S@R^18d8[PB=2:h4S@R^1:d32:h00`R]2:h8
[P062:h050b^2:h8[PR^3<l8[Pc>2:h<c`S>3<l8cPc?3<h<c`c>3<l<cPc?
3<h43<l0613?3<l<c`c?4>l<ca3_3<l@l0c_4>l<ka3`4>l@l0c_4?0@ka3`
4>l@l13_4?0@k`8@l00:4A0@l1D@4?0E413`5A0A41D@4A035A006A4@5A4E
41DA5A0E4AD@5A4E41Da5A0E<AD@6C4E4ATa5C4I<ADa6C4E<ATa5C4I<ADa
00@I<@0D6C8I<ATb6C4IDQTa6E8I<AeB6E4MDQUA7E8IDQeB6E8MDQUB7E8I
DPPMDP0@7G<MDQec7E8QLaeb8G<MLR5c7G8QLaeb8G<MLb5c7G<88G<0426C
8G<QTb5c9I@QTbFD8I<UU26C9I@QTbFD8I<UU26C0bFD00LUTbFd9I@U]2FD
9K@UU0029K@052Vd9K@U]2Fd:KDU]2Ve9K@Y]BFd:KDU]2Ve:K@Y]BVd:MDY
]BWE:K@4:MD062gE:MDYeBWE;MDYeBgE:MD]eRWE;MDYeBgF;MD]eRgE;OH]
eBgf;MD]mRge;OH]m@@]mP09<OH]mS7f;OHamRgf<OH]mS7g008amP0a;OHb
5c7f<QLamS8G<QHb5c8F<QLb5S8G<QHf5c8G=QLb5cHG<QLf5c8G=SLf5cHg
<QLf>3HG=SLf5cHh=SLf>3Hg=SPf=cHh=SLj>3Hg>SPf=cXh=SPj>3Hh>UPf
>3YH=SP023YH010jFCYH>UTjF3iI>UPnFCYH?UTjF3iI>UPnNCYI?WTjF@`n
N@0<@WXnND9j?WU2NSii@WXnND:J?WU2VSii34:J0116VT:JAYY2VTJK@YY6
^d:JA[]2VTJk@YY6^dJjA[]6^P=6^`03A[Y6^dJk0096^`0DB[]6^dJkA[]:
fdJkB]]6^d[LA]]:g4KKB]a:fd[LB]]:g4[KB]a:f`=:g003B]]>g4[L009:
g009C_a:g4klB]a>o4[lC_a:o4km00=>o008C_e>o4kmC_a>oDklC_e>o0=>
o@09C_aC7DkmDae>oE<MCaeC7DlM00=C7@03CaeC7U<M009C7@0@DaiC7E<N
DaeC7U<MDciC7ELnDaeG?U<MEciC?ULnDch3Ech00e<nEciG?P0DDch2JeT1
@Q018@P00004JeUoof]IJeT718d02PR^18d8[PB=2:h4[@R^1:d8[PB]0`R^
00<8[@R^2:h01PR^01@8cPR^3<h8[Pc>2<h<c`S>3<l8cPc?2<h<c`c>3<l<
cPc?3<h<c`c>0Pc?02H<k`c?3>l<ca3_3<l@k`c_4>l<ka3_3>l@l0c_4?0@
ka3`4>l@l13_4?0@ka3`4>lA413_4A0@l1D@4?0E414@5A0A41D@4A0E414@
0QD@01HE4AD@5A4E41DA5A0E4AD@5C4E41Da5A0I<AD`6C4E<ATa5C4I<ADa
6C4E<@<I<@0E5C4I<ATa6C8I<AUA6C4IDQTa6E8IDAeB6E4MDQUA7E8IDAeB
6E8MDQUB00<MDP096E8MDQeB7G8MDQeb7E8MLaeB008MLP0>8G<MLQec7G8Q
Laeb8G<MLR5c7G8QLaec8G<MLP8QL`068I<QLb6C8G<QTb5c0R6C00hUU26C
8I<QTbFD8I<UU26C9I@QTbFD8I<UU26C0RFD00@U]2FC9K@UU0PU]00>:K@U
]2Vd9K@Y]BFd:KDU]2Ve9K@Y]BVd:MDY]0<Ye@03:M@YeBWE00@Ye@0F;MDY
eBgE:MD]eBWE;MDYeBgf:MD]mRgE;OH]eBgf;OD]mRge;OH]mBgf;OD2;OH0
9S7f;OHamRgf<OH]mS7f;OHb5Rgf<QHamS8G<OHb5c8F<QLb5S8G<QHb5c8F
<QLb5SHG<QHf5c8G=QLb5cHG<QLf=c8G=SLf5cHg<SL2=SL04SHh=SLf>3Hg
=SPf=cHh=SLj>3Hg>SPf=cXh=SLj>3Hh>UPf>0<jF003=UPjF3YH00@jF00>
>UTjF3YH>UPnFCYH?UTjF3ii>UPnNCYH?WTjF0<nN@03>WTnNCii00PnN@0>
@WXnNCii?WU2VSii@YXnND:J?WU2VSjI@YXnV@Y2VP0BAYY2VT:J@YY6^d:J
A[Y2VTJk@YY6^d:jA[]2^TJkA[Y6^dJj0dJk00=6^TJkA[/014Jk019:fdJk
B]]6fd[KA]]:fdKKB]a6fd[LB]]:g4[KB]a:fd[LB]/2B]`03T[lB]]:o4[L
C_a:g4klB_a>o4[lC_a:o4klB_`2C_`05TkmC_a>oDklC_e>o4kmC_a?7Dkl
Cae>oE<MC_aC7DlMDae?7E<MCaeC7DlM1U<M015C7U<MDaiC7E<nDaeC?U<M
EciC7ELnDceG?U<mEciC?ULn01AC?P9[F@52404Q200000=[FGooJeT0of]I
n6]I0D8@0B4800000f]IOom[F@3oJeWhJeT1@Q018@P00003JeUoogoo0?mo
ooQoo`52404Q2000of]Io6]I0B480000\
\>"], "Text",
  ImageSize->{508, 329},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
All option names, rules and values here are active. Below listed the actions \
on click in the cells with options:\
\>", "Text"],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  StyleBox["?", "MR"],
  " \[Dash] redirects to ",
  StyleBox["Help Browser", "SR"],
  " reference quide (if the function defined in a separate package button \
refers to ",
  StyleBox["Add-Ons", "SR"],
  ")\n\[FilledSmallSquare] Option name \[Dash] activates (disactivates) the \
option. \n\[FilledSmallSquare] Rule sign \[Dash] toggle between ",
  StyleBox["Rule", "MR"],
  ", ",
  StyleBox["(\[Rule])", "MR"],
  ", and ",
  StyleBox["RuleDelayed", "MR"],
  ", ",
  StyleBox["(\[RuleDelayed])", "MR"],
  ".\n\[FilledSmallSquare] Option value \[Dash] opens set of alternative \
options"
}], "Text"],

Cell[TextData[{
  "The buttons above options act on all listed options. The button ",
  StyleBox["[All]", "MR"],
  " activates and button ",
  StyleBox["[None]", "MR"],
  " disactivate all shown options. Button ",
  StyleBox["[", "MR"],
  StyleBox["Last]", "MR"],
  " sets the list of options applied the last time in the current ",
  StyleBox["Mathematica", "TI"],
  " session. This is default set of ",
  StyleBox["Options Selector Dialog", "MR"],
  ". It initially states all options disactivated and hence is equivalent to \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " default."
}], "Text"],

Cell[TextData[{
  "The buttons below close the dialog menu. Button ",
  StyleBox["[Cancel]", "MR"],
  " cancels all actions. Button ",
  StyleBox["[", "MR"],
  StyleBox["Ok]", "MR"],
  " accepts the changes and adds the activated options at the end of \
expression."
}], "Text"],

Cell[TextData[{
  "Thus there is direct access of information to the describtion of a \
function and to its options. Click on option ",
  StyleBox["Trig", "MR"],
  " to activate it as it shown in the following picture. Because the value ",
  StyleBox["False", "MR"],
  " is not defined yet it has to be inserted instead of ",
  StyleBox["True", "MR"],
  " manually after the options set is accepted."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007l0001BA000`40O003
h00Oob48oB4800000f]I@Q12403o@Q3i@Q018@P00003JeUoof]I0?m[FOQ[
F@52404Q200000=[FGooJeT0of]In6]I0D8@0B48000016]IOom[FF]Ioa[F
iA[F16]I00Eood8@@Q1[FGoo00924004JeUood8@@Q03JeT1@Q018@P00004
JeUoof]IJeWo6]KU6]H5JeT01Goo@Q1246]IOol00T8@00A[FGoo@Q12409[
F@52404Q200000A[FGooJeU[FOlJe^DJePI[F@05Oom2448@JeUoo`02@Q00
0f]IOom24002JeT1@Q018@P00004JeUoof]IJeWo6]KU6]H7JeT01Goo@Q12
46]IOol00T8@00E[FGooJeU[FD8@004Q200000A[FGooJeU[FOlJe^DJePQ[
F@05Oom2448@JeUoo`02@Q03JeT1@Q018@P00004JeUoof]IJeWo6]KU6]H9
JeT01Goo@Q1246]IOol00T8@0V]I0D8@0B48000016]IOom[FF]Ioa[FiA[F
2V]I00Iood8@@Q1[FGoo@Q02JeT1@Q018@P00004JeUoof]IJeWo6]KU6]H;
JeT01Goo@Q1246]IOol00V]I0D8@0B48000016]IOom[FF]Ioa[FiA[F36]I
00=ood8@@Q000f]I0D8@0B48000016]IOom[FF]Ioa[FiA[F3F]I00=ood8@
@Q000V]I0D8@0B48000016]IOom[FF]Ioa[FiA[F3V]I00Eood8@JeU[FD8@
004Q200000A[FGooJeU[FOlJe^DJePm[F@04Oom[FF]I@Q018@P00004JeUo
of]IJeWo6]KU6]HBJeT1@Q018@P00004JeUoof]IJeWo6]KU6]HBJeT1@Q01
8@P00004JeUoof]IJeWo6]KU6]HBJeT1@Q018@P00004JeUoof]IJeWo6]KU
6]HBJeT1@Q018@P00004JeUoof]IJeWo6]KU6]H@8@P2JeT1@Q018@P00004
JeUoof]IJeWo6]KU6]H00f]I@Q12400<@Q001248JeU[FD8@0B48000016]I
Oom[FF]Ioa[FiA[F00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[
FGooJeU[FOlJe^DJeP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004
JeUoof]IJeWo6]KU6]H00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B480000
16]IOom[FF]Ioa[FiA[F00=[FGooJeT02f]I00E24248JeU[FD8@004Q2000
00A[FGooJeU[FOlJe^DJeP03JeUoof]I00A[F@03001[FF]I00A[F@05@Q0Q
26]IJeU240018@P00004JeUoof]IJeWo6]KU6]H00f]IOom[F@03JeT30005
JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]Ioa[FiA[F00=[FGooJeT0
0V]I1@0016]I00E24248JeU[FD8@004Q200000A[FGooJeU[FOlJe^DJeP04
JeUoof]IJeT70003JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]Ioa[F
iA[F00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FOlJ
e^DJeP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeWo
6]KU6]H00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]I
oa[FiA[F00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[
FOlJe^DJeP03JeUoogoo00]oo`05@Q0Q26]IJeU240018@P00004JeUoof]I
JeWo6]KU6]H?JeT01248JeU[FD8@0B48000016]IOom[FF]Ioa[FiA[F00mo
of]IOom[FGooJeUoof]IOom[FGooJeUoof]IOol00f]I0D8@0B48000016]I
Oom[FF]Ioa[FiA[F011[FGooJeUoof]IOom[FGooJeUoof]IOom[FGooJeUo
o`9[F@52404Q200000A[FGooJeU[FOlJe^DJeP0?Oom[FGooJeUoof]IOom[
FGooJeUoof]IOom[FGoo00=[F@52404Q200000A[FGooJeU[FOlJe^DJeP0@
JeUoof]IOom[FGooJeUoof]IOom[FGooJeUoof]IOol2JeT1@Q018@P00004
JeUoof]IJeWo6]KU6]H03gooJeUoof]IOom[FGooJeUoof]IOom[FGooJeUo
o`03JeT1@Q018@P00004JeUoof]IJeWo6]KU6]H046]IOom[FGooJeUoof]I
Oom[FGooJeUoof]IOom[FGoo0V]I0D8@0B48000016]IOom[FF]Ioa[FiA[F
00moof]IOom[FGooJeUoof]IOom[FGooJeUoof]IOol00f]I0D8@0B480000
16]IOom[FF]Ioa[FiA[F011[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo
JeUoo`9[F@52404Q200000A[FGooJeU[FOlJe^DJeP0?Oom[FGooJeUoof]I
Oom[FGooJeUoof]IOom[FGoo00=[F@52404Q200000A[FGooJeU[FOlJe^DJ
eP0@JeUoof]IOom[FGooJeUoof]IOom[FGooJeUoof]IOol2JeT1@Q018@P0
0004JeUoof]IJeWo6]KU6]H03gooJeUoof]IOom[FGooJeUoof]IOom[FGoo
JeUoo`03JeT1@Q018@P00004JeUoof]IJeWo6]KU6]H046]IOom[FGooJeUo
of]IOom[FGooJeUoof]IOom[FGoo0V]I0D8@0B48000016]IOom[FF]Ioa[F
iA[F00moof]IOom[FGooJeUoof]IOom[FGooJeUoof]IOol00f]I0D8@0B48
000016]IOom[FF]Ioa[FiA[F011[FGooJeUoof]IOom[FGooJeUoof]IOom[
FGooJeUoo`9[F@52404Q200000A[FGooJeU[FOlJe^DJeP0?Oom[FGooJeUo
of]IOom[FGooJeUoof]IOom[FGoo00=[F@52404Q200000A[FGooJeU[FOlJ
e^DJeP0@JeUoof]IOom[FGooJeUoof]IOom[FGooJeUoof]IOol2JeT1@Q01
8@P00004JeUoof]IJeWo6]KU6]H03gooJeUoof]IOom[FGooJeUoof]IOom[
FGooJeUoo`03JeT1@Q018@P00004JeUoof]IJeWo6]KU6]H046]IOom[FGoo
JeUoof]IOom[FGooJeUoof]IOom[FGoo0V]I0D8@0B48000016]IOom[FF]I
oa[FiA[F00moof]IOom[FGooJeUoof]IOom[FGooJeUoof]IOol00f]I0D8@
0B48000016]IOom[FF]Ioa[FiA[F011[FGooJeUoof]IOom[FGooJeUoof]I
Oom[FGooJeUoo`9[F@52404Q200000A[FGooJeU[FOlJe^DJeP0?Oom[FGoo
JeUoof]IOom[FGooJeUoof]IOom[FGoo00=[F@52404Q200000A[FGooJeU[
FOlJe^DJeP0@JeUoof]IOom[FGooJeUoof]IOom[FGooJeUoof]IOol2JeT1
@Q018@P00004JeUoof]IJeWo6]KU6]H03gooJeUoof]IOom[FGooJeUoof]I
Oom[FGooJeUoo`03JeT1@Q018@P00004JeUoof]IJeWo6]KU6]H046]IOom[
FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo0V]I0D8@0B48000016]IOom[
FF]Ioa[FiA[F00moof]IOom[FGooJeUoof]IOom[FGooJeUoof]IOol00f]I
0D8@0B48000016]IOom[FF]Ioa[FiA[F011[FGooJeUoof]IOom[FGooJeUo
of]IOom[FGooJeUoo`9[F@52404Q200000A[FGooJeU[FOlJe^DJeP0?Oom[
FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo00=[F@52404Q200000A[FGoo
JeU[FOlJe^DJeP0@JeUoof]IOom[FGooJeUoof]IOom[FGooJeUoof]IOol2
JeT1@Q018@P00004JeUoof]IJeWo6]KU6]H03gooJeUoof]IOom[FGooJeUo
of]IOom[FGooJeUoo`03JeT1@Q018@P00004JeUoof]IJeWo6]KU6]H046]I
Oom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo0V]I0D8@0B48000016]I
Oom[FF]Ioa[FiA[F00moof]IOom[FGooJeUoof]IOom[FGooJeUoof]IOol0
0f]I0D8@0B48000016]IOom[FF]Ioa[FiA[F011[FGooJeUoof]IOom[FGoo
JeUoof]IOom[FGooJeUoo`9[F@52404Q200000A[FGooJeU[FOlJe^DJeP0?
Oom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo00=[F@52404Q200000A[
FGooJeU[FOlJe^DJeP0@JeUoof]IOom[FGooJeUoof]IOom[FGooJeUoof]I
Ool2JeT1@Q018@P00004JeUoof]IJeWo6]KU6]H03gooJeUoof]IOom[FGoo
JeUoof]IOom[FGooJeUoo`03JeT1@Q018@P00004JeUoof]IJeWo6]KU6]H0
46]IOom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo0V]I0D8@0B480000
16]IOom[FF]Ioa[FiA[F00moof]IOom[FGooJeUoof]IOom[FGooJeUoof]I
Ool00f]I0D8@0B48000016]IOom[FF]Ioa[FiA[F011[FGooJeUoof]IOom[
FGooJeUoof]IOom[FGooJeUoo`9[F@52404Q200000A[FGooJeU[FOlJe^DJ
eP0?Oom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo00=[F@52404Q2000
00A[FGooJeU[FOlJe^DJeP0@JeUoof]IOom[FGooJeUoof]IOom[FGooJeUo
of]IOol2JeT1@Q018@P00004JeUoof]IJeWo6]KU6]H03gooJeUoof]IOom[
FGooJeUoof]IOom[FGooJeUoo`03JeT1@Q018@P00004JeUoof]IJeWo6]KU
6]H046]IOom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo0V]I0D8@0B48
000016]IOom[FF]Ioa[FiA[F00moof]IOom[FGooJeUoof]IOom[FGooJeUo
of]IOol00f]I0D8@0B48000016]IOom[FF]Ioa[FiA[F011[FGooJeUoof]I
Oom[FGooJeUoof]IOom[FGooJeUoo`9[F@52404Q200000A[FGooJeU[FOlJ
e^DJeP0?Oom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo00=[F@52404Q
200000A[FGooJeU[FOlJe^DJeP0@JeUoof]IOom[FGooJeUoof]IOom[FGoo
JeUoof]IOol2JeT1@Q018@P00004JeUoof]IJeWo6]KU6]H03gooJeUoof]I
Oom[FGooJeUoof]IOom[FGooJeUoo`03JeT1@Q018@P00004JeUoof]IJeWo
6]KU6]H046]IOom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo0V]I0D8@
0B48000016]IOom[FF]Ioa[FiA[F00moof]IOom[FGooJeUoof]IOom[FGoo
JeUoof]IOol00f]I0D8@0B48000016]IOom[FF]Ioa[FiA[F011[FGooJeUo
of]IOom[FGooJeUoof]IOom[FGooJeUoo`9[F@52404Q200000A[FGooJeU[
FOlJe^DJeP0?Oom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo00=[F@52
404Q200000A[FGooJeU[FOlJe^DJeP0@JeUoof]IOom[FGooJeUoof]IOom[
FGooJeUoof]IOol2JeT1@Q018@P00004JeUoof]IJeWo6]KU6]H03gooJeUo
of]IOom[FGooJeUoof]IOom[FGooJeUoo`03JeT1@Q018@P00004JeUoof]I
JeWo6]KU6]H046]IOom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo0V]I
0D8@0B48000016]IOom[FF]IofNIiFNI00moof]IOom[FGooJeUoof]IOom[
FGooJeUoof]IOol00f]I0D8@0B48000016]IOom[FF]IofNIiFNI011[FGoo
JeUoof]IOom[FGooJeUoof]IOom[FGooJeUoo`9[F@52404Q200000A[FGoo
JeU[FOmWVNEWV@0?Oom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo00=[
F@52404Q200000A[FGooJeU[FOmWVNEWV@0@JeUoof]IOom[FGooJeUoof]I
Oom[FGooJeUoof]IOol2JeT1@Q018@P00004JeUoof]IJeWoIiWUIiT03goo
JeUoof]IOom[FGooJeUoof]IOom[FGooJeUoo`03JeT1@Q018@P00004JeUo
of]IJeWoIiWUIiT046]IOom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo
0V]I0D8@0B48000016]IOom[FF]IofNIiFNI00moof]IOom[FGooJeUoof]I
Oom[FGooJeUoof]IOol00f]I0D8@0B48000016]IOom[FF]IofNI<FNIC248
2VNIC2484VNI011[FGooJeUoof]IOom[FGooJeUoof]IOom[FGooJeUoo`9[
F@52404Q200000A[FGooJeU[FOmWVC5WV@03JeU2448@04Q240038@QWVFNI
00QWV@03JeU2448@04Q240038@QWVFNI011WV@0?Oom[FGooJeUoof]IOom[
FGooJeUoof]IOom[FGoo00=[F@52404Q200000A[FGooJeU[FOmWVC5WV@03
JeUooe/i04MK>@03@Q0Q26NI00UWV@03JeUooe/i04MK>@03@Q0Q26NI015W
V@0@JeUoof]IOom[FGooJeUoof]IOom[FGooJeUoof]IOol2JeT1@Q018@P0
0004JeUoof]IJeWoIiTaIiT00f]IOomK>@17FcT00d8@8@QWV@09IiT00f]I
OomK>@17FcT00d8@8@QWV@0AIiT03gooJeUoof]IOom[FGooJeUoof]IOom[
FGooJeUoo`03JeT1@Q018@P00004JeUoof]IJeWoIiTaIiT00f]IOomK>@17
FcT00d8@8@QWV@09IiT00f]IOomK>@17FcT00d8@8@QWV@0AIiT046]IOom[
FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo0V]I0D8@0B48000016]IOom[
FF]IofNI<FNI00=[FGooFcT0Ae/i00=24248IiT02FNI00=[FGooFcT0Ae/i
00=24248IiT04FNI00moof]IOom[FGooJeUoof]IOom[FGooJeUoof]IOol0
0f]I0D8@0B48000016]IOom[FF]IofNI<FNI00=[FGooFcT0Ae/i00=24248
IiT02FNI00=[FGooFcT0Ae/i00=24248IiT04FNI011[FGooJeUoof]IOom[
FGooJeUoof]IOom[FGooJeUoo`9[F@52404Q200000A[FGooJeU[FOmWVC5W
V@03JeUooe/i01iK>@<0009K>@800004FcT00000000NFcT00d8@8@QWV@09
IiT00f]IOomK>@0@FcT30004FcT8000015/i000000000U/i0`0015/i1000
0U/i1@0045/i00=24248IiT04FNI00moof]IOom[FGooJeUoof]IOom[FGoo
JeUoof]IOol00f]I0D8@0B48000016]IOom[FF]IofNI<FNI00=[FGooFcT0
7E/i00D005/iFcUK>@00009K>@04001K>E/i000OFcT00d8@8@QWV@09IiT0
0f]IOomK>@0?FcT01@00FcUK>E/i00000U/i00D005/iFcUK>@00009K>@05
001K>E/iFcT00002FcT01@00FcUK>E/i00000U/i00<005/iFcT01U/i00<0
05/iFcT045/i00=24248IiT04FNI011[FGooJeUoof]IOom[FGooJeUoof]I
Oom[FGooJeUoo`9[F@52404Q200000A[FGooJeU[FOmWVC5WV@03JeUooe/i
01eK>@05001K>E/iFcT00002FcT00`00FcT0000PFcT00d8@8@QWV@09IiT0
0f]IOomK>@0?FcT00`00FcUK>@04FcT01@00FcUK>E/i00000U/i00D005/i
FcUK>@00009K>@03001K>E/i00AK>@03001K>E/i00IK>@03001K>E/i011K
>@03@Q0Q26NI015WV@0?Oom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo
00=[F@52404Q200000A[FGooJeU[FOmWVC5WV@03JeUooe/i01eK>@05001K
>E/iFcT00002FcT3000PFcT00d8@8@QWV@09IiT00f]IOomK>@0?FcT00`00
FcUK>@05FcT40002FcT01@00FcUK>E/i00000U/i00<005/iFcT015/i1@00
15/i00<005/iFcT045/i00=24248IiT04FNI011[FGooJeUoof]IOom[FGoo
JeUoof]IOom[FGooJeUoo`9[F@52404Q200000A[FGooJeU[FOmWVC5WV@03
JeUooe/i01eK>@05001K>E/iFcT00002FcT01000FcUK>@007e/i00=24248
IiT02FNI00=[FGooFcT03e/i00<005/iFcT015/i00D005/iFcUK>@00009K
>@80009K>@04001K>E/i0003FcT01000FcUK>@000e/i00<005/iFcT00U/i
00<005/iFcT045/i00=24248IiT04FNI00moof]IOom[FGooJeUoof]IOom[
FGooJeUoof]IOol00f]I0D8@0B48000016]IOom[FF]IofNI<FNI00=[FGoo
FcT07E/i00D005/iFcUK>@00009K>@03001K>@00008001iK>@03@Q0Q26NI
00UWV@03JeUooe/i00mK>@03001K>E/i00EK>@<0009K>@800003FcT00000
00AK>@@000=K>@<000EK>@03001K>E/i011K>@03@Q0Q26NI015WV@0@JeUo
of]IOom[FGooJeUoof]IOom[FGooJeUoof]IOol2JeT1@Q018@P00004JeUo
of]IJeWoIiTaIiT00f]IOomK>@0MFcT01@00FcUK>E/i00000U/i00<005/i
FcT085/i00=24248IiT02FNI00=[FGooFcT03e/i00D005/iFcUK>@00021K
>@03001K>E/i011K>@03@Q0Q26NI015WV@0?Oom[FGooJeUoof]IOom[FGoo
JeUoof]IOom[FGoo00=[F@52404Q200000A[FGooJeU[FOmWVC5WV@03JeUo
oe/i01iK>@<0009K>@80029K>@03@Q0Q26NI00UWV@03JeUooe/i011K>@@0
01mK>@80019K>@03@Q0Q26NI015WV@0@JeUoof]IOom[FGooJeUoof]IOom[
FGooJeUoof]IOol2JeT1@Q018@P00004JeUoof]IJeWoIiTaIiT00f]IOomK
>@17FcT00d8@8@QWV@09IiT00f]IOomK>@17FcT00d8@8@QWV@0AIiT03goo
JeUoof]IOom[FGooJeUoof]IOom[FGooJeUoo`03JeT1@Q018@P00004JeUo
of]IJeWoIiTaIiT00f]IOomK>@17FcT00d8@8@QWV@09IiT00f]IOomK>@17
FcT00d8@8@QWV@0AIiT046]IOom[FGooJeUoof]IOom[FGooJeUoof]IOom[
FGoo0V]I0D8@0B48000016]IOom[FF]IofNI<FNI00=[FGooFcT0Ae/i00=2
4248IiT02FNI00=[FGooFcT0Ae/i00=24248IiT04FNI00moof]IOom[FGoo
JeUoof]IOom[FGooJeUoof]IOol00f]I0D8@0B48000016]IOom[FF]IofNI
<FNI00=[FGooOol0Agoo00=24248IiT02FNI00=[FGooOol0Agoo00=24248
IiT04FNI011[FGooJeUoof]IOom[FGooJeUoof]IOom[FGooJeUoo`9[F@52
404Q200000A[FGooJeU[FOmWVC5WVD][F@038@QWVFNI00QWVD][F@038@QW
VFNI011WV@0?Oom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo00=[F@52
404Q200000A[FGooJeU[FOmWVNEWV@0@JeUoof]IOom[FGooJeUoof]IOom[
FGooJeUoof]IOol2JeT1@Q018@P00004JeUoof]IJeWoIiWUIiT03gooJeUo
of]IOom[FGooJeUoof]IOom[FGooJeUoo`03JeT1@Q018@P00004JeUoof]I
JeWoIiWUIiT046]IOom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo0V]I
0D8@0B48000016]IOom[FF]IofNIiFNI00moof]IOom[FGooJeUoof]IOom[
FGooJeUoof]IOol00f]I0D8@0B48000016]IOom[FF]IofNIiFNI011[FGoo
JeUoof]IOom[FGooJeUoof]IOom[FGooJeUoo`9[F@52404Q200000A[FGoo
JeU[FOmWVNEWV@0?Oom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo00=[
F@52404Q200000A[FGooJeU[FOmkg^EkgP0@JeUoof]IOom[FGooJeUoof]I
Oom[FGooJeUoof]IOol2JeT1@Q018@P00004JeUoof]IJeWoNmkUNmh03goo
JeUoof]IOom[FGooJeUoof]IOom[FGooJeUoo`03JeT1@Q018@P00004JeUo
of]IJeWoNmkUNmh046]IOom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo
0V]I0D8@0B48000016]IOom[FF]I6G_N0P002g_N0P008g_N1000og_NUW_N
00moof]IOom[FGooJeUoof]IOom[FGooJeUoof]IOol00f]I0D8@0B480000
16]IOom[FF]I6G_N00<007_NNmh02g_N00<007_NNmh097_N0P00og_NUG_N
011[FGooJeUoof]IOom[FGooJeUoof]IOom[FGooJeUoo`9[F@52404Q2000
00A[FGooJeU[FAUkgP03001kgW_N00=kgP8000IkgP03001kgW_N00akgP@0
009kgPD0009kgPH0009kgP800003Nmh0000000YkgP03001kgW_N00AkgP@0
009kgPD000AkgPD00003Nmh0000000800?mkgV]kgP0?Oom[FGooJeUoof]I
Oom[FGooJeUoof]IOom[FGoo00=[F@52404Q200000A[FGooJeU[FAUkgP03
001kgW_N00]kgP03001kgW_N00ekgP8000AkgP8000IkgP8000=kgP800004
Nmh00000000;Nmh00`00NmikgP04Nmh20004Nmh20005Nmh2000017_N0000
07_N0P000g_N00<007_NNmh0og_NJ7_N011[FGooJeUoof]IOom[FGooJeUo
of]IOom[FGooJeUoo`9[F@52404Q200000A[FGooJeU[FAUkgP03001kgW_N
00AkgP03001kgW_N00AkgP03001kgW_N00ekgP8000AkgP8000IkgP8000=k
gP80009kgP8000AkgPT000EkgP8000AkgP8000EkgP800004Nmh00000Nmh2
003oNmi^Nmh03gooJeUoof]IOom[FGooJeUoof]IOom[FGooJeUoo`03JeT1
@Q018@P00004JeUoof]IJeTINmh00`00NmikgP05Nmh00`00NmikgP03Nmh0
0`00NmikgP0=Nmh20004Nmh20006Nmh20003Nmh20002Nmh2000;Nmh00`00
NmikgP04Nmh20004Nmh20005Nmh2000017_N000007_N1P00og_NJW_N011[
FGooJeUoof]IOom[FGooJeUoof]IOom[FGooJeUoo`9[F@52404Q200000A[
FGooJeU[FAUkgP03001kgW_N00IkgP03001kgW_N009kgP03001kgW_N00ek
gP8000AkgP<00003Nmh007_N009kgP8000=kgP800004Nmh00000000:Nmh0
0`00NmikgP05Nmh20004Nmh3000017_N001kgW_N0P0000AkgP00001kgP80
009kgP800?mkgVYkgP0?Oom[FGooJeUoof]IOom[FGooJeUoof]IOom[FGoo
00=[F@52404Q200000A[FGooJeU[FAUkgP03001kgW_N00=kgP04001kgW_N
0004Nmh00`00NmikgP0;Nmh01`00Nmh00000Nmh007_N00<00004Nmh00000
Nmh40004Nmh2000017_N000000003g_N00L007_N000007_N001kgP030000
17_N000007_N0`0000=kgP0000000W_N1000og_NJg_N011[FGooJeUoof]I
Oom[FGooJeUoof]IOom[FGooJeUoo`9[F@52404Q200000A[FGooJeU[FAUk
gP03001kgW_N00AkgP8000EkgP03001kgW_N00]kgP06001kgP00001kgP00
9G_N00H007_N000007_N003oNmioNmh03gooJeUoof]IOom[FGooJeUoof]I
Oom[FGooJeUoo`03JeT1@Q018@P00004JeUoof]IJeTINmh2000;Nmh2000=
Nmh6000:Nmh2000INmh6003oNmioNmh046]IOom[FGooJeUoof]IOom[FGoo
JeUoof]IOom[FGoo0V]I0D8@0B48000016]IOom[FF]Iog_NiG_N00moof]I
Oom[FGooJeUoof]IOom[FGooJeUoof]IOol00f]I0D8@0B48000016]IOom[
FF]Iog_NiG_N42480V]I0D8@0B48000016]IOom[FF]Iog_NiG_N00=[FD8@
@Q00348@00@Q26]IJeU2404Q200000A[FGooJeU[FOmkg^EkgP03JeUoof]I
00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeWoNmkUNmh00f]IOom[
F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]Iog_NiG_N00=[FGoo
JeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FOmkg^EkgP03JeUo
of]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeWoNmkUNmh00f]I
Oom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]Iog_NiG_N00=[
FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FOmkg^EkgP03
JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeTINmh2000;
Nmh2003oNmjmNmh00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]I
Oom[FF]I6G_N00<007_NNmh02g_N00<007_NNmh0og_N^g_N00=[FGooJeT0
2f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FAUkgP03001kgW_N00=k
gP8000IkgP03001kgW_N00ekgP<000=kgPD000=kgPP00005Nmh00000001k
gP040003Nmh50003Nmh30003Nmh500000g_N000000050002Nmh50003Nmh3
0002Nmh50003Nmh30002Nmh300001G_N00000000Nmh00`001G_N0P0000=k
gP0000000`0000AkgP000000009kgP<000EkgP<0009kgPD000=kgP<0009k
gP<00005Nmh00000001kgP04000;Nmh00`00NmikgP03Nmh3000017_N0000
00000W_N0P0000=kgP0000000g_N0`000g_N0`000W_N1`000W_N1@000g_N
0`000W_N1@000g_N0`00`W_N00=[FGooJeT02f]I00E24248JeU[FD8@004Q
200000A[FGooJeU[FAUkgP03001kgW_N00]kgP03001kgW_N00ikgP03001k
gW_N00=kgP03001kgW_N00=kgP05001kgW_NNmh00002Nmh01@00NmikgW_N
00000W_N00D007_NNmikgP0000=kgP03001kgW_N00=kgP05001kgW_NNmh0
0003Nmh00`00NmikgP03Nmh01@00Nmh007_N00000W_N00D007_NNmikgP00
00=kgP05001kgW_NNmh00003Nmh00`00NmikgP02Nmh01@00NmikgW_N0000
0W_N00D007_NNmikgP0000=kgP03001kgW_N00=kgP03001kgW_N0080009k
gP05001kgW_NNmh00002Nmh01@00NmikgW_N00000g_N00D007_NNmikgP00
00=kgP03001kgW_N009kgP05001kgW_NNmh00002Nmh01@00NmikgW_N0000
0W_N00D007_NNmikgP0000]kgP03001kgW_N00=kgP05001kgW_NNmh00002
Nmh00`00NmikgP020003Nmh01`00NmikgW_N001kgP0000=kgP08001kgW_N
001kgP00Nmh0009kgP05001kgW_NNmh00003Nmh01@00NmikgW_N00000g_N
00<007_NNmh00W_N00D007_NNmikgP000<5kgP03JeUoof]I00][F@05@Q0Q
26]IJeU240018@P00004JeUoof]IJeTINmh00`00NmikgP04Nmh00`00Nmik
gP04Nmh00`00NmikgP0>Nmh00`00NmikgP03Nmh00`00NmikgP03Nmh01@00
NmikgW_N00000W_N00D007_NNmikgP0000IkgP05001kgW_NNmh00005Nmh0
1@00NmikgW_N00000g_N00<007_NNmh00g_N00D007_N001kgP00009kgP05
001kgW_NNmh00003Nmh00`00NmikgP05Nmh00`00NmikgP02Nmh01@00Nmik
gW_N00000W_N00D007_NNmikgP0000=kgP03001kgW_N00=kgP05001kgW_N
Nmh00002Nmh01@00NmikgW_N00000W_N00<007_NNmh01G_N00<007_NNmh0
1G_N00<007_NNmh00W_N00D007_NNmikgP00009kgP05001kgW_NNmh00006
Nmh00`00NmikgP02Nmh90004Nmh50002Nmh01@00NmikgW_N00000g_N00<0
07_NNmh00g_N00D007_NNmikgP00009kgP05001kgP00Nmh00002Nmh01@00
NmikgW_N00000g_N00<007_NNmh01G_N00<007_NNmh00W_N00<007_NNmh0
`g_N00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FAUk
gP03001kgW_N00EkgP03001kgW_N00=kgP03001kgW_N00ikgP03001kgW_N
00=kgP03001kgW_N00AkgP@0009kgP05001kgW_NNmh00003Nmh30004Nmh0
0`00NmikgP03Nmh01@00NmikgW_N00000g_N00<007_NNmh00g_N00D007_N
001kgP0000=kgP@000=kgP03001kgW_N00EkgP03001kgW_N009kgP05001k
gW_NNmh00002Nmh01@00NmikgW_N00000g_N00<007_N00000g_N00D007_N
NmikgP00009kgP05001kgW_NNmh00002Nmh00`00NmikgP05Nmh00`00Nmik
gP05Nmh00`00NmikgP02Nmh01@00NmikgW_N00000W_N00D007_NNmikgP00
00=kgP<000akgP03001kgW_N00AkgP03001kgP0000=kgP05001kgW_NNmh0
0003Nmh00`00NmikgP03Nmh01@00NmikgW_N00000W_N00D007_N001kgP00
00=kgP@000=kgP03001kgW_N00EkgP03001kgW_N009kgP03001kgW_N0<=k
gP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeTINmh0
0`00NmikgP06Nmh00`00NmikgP02Nmh00`00NmikgP0>Nmh00`00NmikgP03
Nmh20004Nmh01@00NmikgW_N00000W_N0P000W_N00@007_NNmh000=kgP05
001kgW_NNmh00005Nmh01@00NmikgW_N00000g_N0P0017_N00D007_N001k
gP00009kgP05001kgW_NNmh00003Nmh00`00NmikgP05Nmh00`00NmikgP02
Nmh01@00NmikgW_N00000W_N0P000W_N00@007_NNmikgP<000=kgP05001k
gW_NNmh00002Nmh20002Nmh01000NmikgP000g_N00D007_NNmikgP0000Mk
gP03001kgW_N009kgP05001kgW_NNmh00002Nmh20002Nmh01000NmikgP00
0g_N00<007_NNmh027_N00<007_NNmh01G_N00<007_N00000g_N00D007_N
NmikgP0000=kgP03001kgW_N00=kgP05001kgW_NNmh00002Nmh01@00Nmh0
07_N00000W_N00D007_NNmikgP0000=kgP03001kgW_N00EkgP03001kgW_N
009kgP05001kgW_NNmh00031Nmh00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q00
0B48000016]IOom[FF]I6G_N00<007_NNmh00g_N00@007_NNmh000AkgP03
001kgW_N00ikgP03001kgW_N009kgP800003Nmh0000000=kgP<0009kgP80
0003Nmh0000000AkgP@0009kgPD000=kgP<000=kgP800004Nmh00000Nmh3
00000g_N001kgP03Nmh30003Nmh50002Nmh30005Nmh30002Nmh200000g_N
00000004Nmh00`00Nmh00002Nmh20002Nmh2000017_N000007_N0P0017_N
10000W_N1@000W_N0`001G_N0`000W_N0P0000=kgP00000017_N10004W_N
00<007_N00000W_N0P000W_N0P000W_N1@000g_N0`000W_N0`0000=kgP00
Nmh00g_N0`000g_N1@000W_N0`001G_N1000`G_N00=[FGooJeT02f]I00E2
4248JeU[FD8@004Q200000A[FGooJeU[FAUkgP03001kgW_N00AkgP8000Ek
gP03001kgW_N00]kgP04001kgW_N0002Nmh00`00NmikgP0LNmh00`00Nmik
gP0PNmh00`00NmikgP0INmh01@00NmikgW_N00005g_N00<007_NNmh0<7_N
00<007_NNmh02W_N00<007_NNmh06G_N00<007_NNmh0d7_N00=[FGooJeT0
2f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FAUkgP8000]kgP8000ek
gPL001mkgP<002MkgP03001kgW_N011kgPH001mkgP03001kgW_N02MkgP80
031kgP03001kgW_N0<QkgP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P0
0004JeUoof]IJeWoNmkUNmh00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48
000016]IOom[FF]Iog_NiG_N00=[FGooJeT02f]I00E24248JeU[FD8@004Q
200000A[FGooJeU[FOmkg^EkgP03JeUoof]I00][F@05@Q0Q26]IJeU24001
8@P00004JeUoof]IJeWoNmkUNmh00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q00
0B48000016]IOom[FF]Iog_NiG_N00=[FGooJeT02f]I00E24248JeU[FD8@
004Q200000A[FGooJeU[FOmkg^EkgP03JeUoof]I00][F@05@Q0Q26]IJeU2
40018@P00004JeUoof]IJeWoNmkUNmh00f]IOom[F@0;JeT01D8@8@Q[FF]I
@Q000B48000016]IOom[FF]Iog_NiG_N00=[FGooJeT02f]I00E24248JeU[
FD8@004Q200000A[FGooJeU[FOmkg^EkgP03JeUoof]I00][F@05@Q0Q26]I
JeU240018@P00004JeUoof]IJeWoNmkUNmh00f]IOom[F@0;JeT01D8@8@Q[
FF]I@Q000B48000016]IOom[FF]I6G_N0P002g_N0P00og_N_G_N00=[FGoo
JeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FAUkgP03001kgW_N
00]kgP03001kgW_N0?mkg[]kgP03JeUoof]I00][F@05@Q0Q26]IJeU24001
8@P00004JeUoof]IJeTINmh00`00NmikgP03Nmh20006Nmh00`00NmikgP0=
Nmh30003Nmh500000g_N000000050002Nmh40003Nmh30004Nmh30002Nmh3
00001G_N00000000Nmh010001G_N0`000W_N1@000g_N1@0000=kgP000000
0`0000EkgP00000007_N00<000=kgP<000YkgP03001kgW_N00EkgP<000Ak
gP<000AkgP<00?mkgRakgP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P0
0004JeUoof]IJeTINmh00`00NmikgP0;Nmh00`00NmikgP0>Nmh00`00Nmik
gP04Nmh00`00NmikgP02Nmh01@00Nmh007_N00000W_N00<007_NNmh017_N
00D007_NNmikgP00009kgP05001kgW_NNmh00002Nmh01@00NmikgW_N0000
0W_N00D007_NNmikgP0000=kgP05001kgW_NNmh00002Nmh00`00NmikgP03
Nmh01@00NmikgW_N000017_N00<007_NNmh00W_N00D007_NNmikgP0000=k
gP05001kgW_NNmh0000:Nmh00`00NmikgP03Nmh01@00NmikgW_N00000W_N
00D007_NNmikgP00009kgP05001kgW_NNmh0003oNmh[Nmh00f]IOom[F@0;
JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]I6G_N00<007_NNmh017_N
00<007_NNmh017_N00<007_NNmh03W_N00<007_NNmh017_N00<007_NNmh0
0W_N00D007_N001kgP00009kgP03001kgW_N00AkgP03001kgW_N00AkgP05
001kgW_NNmh00002Nmh01@00NmikgW_N00001W_N00D007_NNmikgP0000Ik
gP03001kgW_N00=kgP05001kgW_NNmh00004Nmh00`00NmikgP02Nmh01@00
NmikgW_N00000g_N00<007_NNmh01G_N2@0027_N00@007_NNmh000=kgP04
001kgW_N0003Nmh00`00NmikgP3oNmhYNmh00f]IOom[F@0;JeT01D8@8@Q[
FF]I@Q000B48000016]IOom[FF]I6G_N00<007_NNmh01G_N00<007_NNmh0
0g_N00<007_NNmh03W_N00<007_NNmh017_N00<007_NNmh00W_N00D007_N
001kgP00009kgPD0009kgP03001kgW_N00AkgP05001kgW_NNmh00002Nmh0
1@00NmikgW_N00000g_N0`0017_N00<007_NNmh017_N00<007_NNmh017_N
100017_N00<007_NNmh00W_N00D007_NNmikgP0000=kgP03001kgW_N00ak
gP03001kgW_N00MkgP04001kgW_N0003Nmh01000NmikgP000g_N00<007_N
Nmh0og_N:G_N00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGoo
JeU[FAUkgP03001kgW_N00IkgP03001kgW_N009kgP03001kgW_N00ikgP03
001kgW_N00AkgP03001kgW_N009kgP05001kgP00Nmh00002Nmh01@00Nmik
gW_N00000W_N00<007_NNmh017_N00D007_NNmikgP00009kgP80009kgP04
001kgW_N0003Nmh01@00NmikgW_N00001W_N0P0017_N00D007_NNmikgP00
00AkgP03001kgW_N009kgP80009kgP05001kgW_NNmh0000=Nmh00`00Nmik
gP06Nmh20003Nmh01@00NmikgW_N00000W_N00D007_NNmikgP000?mkgR]k
gP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeTINmh0
0`00NmikgP03Nmh01000NmikgP0017_N00<007_NNmh03W_N00<007_NNmh0
0W_N0`000g_N0`0000=kgP00Nmh00g_N0`000g_N00<007_NNmh01G_N0`00
0W_N0P0000=kgP00000017_N10000W_N1@000W_N0P0000=kgP0000000g_N
0`000g_N0`000g_N0P0000=kgP0000000g_N1@005G_N00@007_NNmh000=k
gP04001kgW_N0003Nmh00`00NmikgP3oNmhYNmh00f]IOom[F@0;JeT01D8@
8@Q[FF]I@Q000B48000016]IOom[FF]I6G_N00<007_NNmh017_N0P001G_N
00<007_NNmh02g_N00@007_NNmh0009kgP03001kgW_N01AkgP05001kgW_N
Nmh0000HNmh00`00NmikgP0PNmh00`00NmikgP0BNmh01@00NmikgW_N0000
0W_N00D007_NNmikgP00009kgP05001kgW_NNmh0003oNmh[Nmh00f]IOom[
F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]I6G_N0P002g_N0P00
3G_N1`000g_N00<007_NNmh04G_N1000;W_N00<007_NNmh087_N0`0017_N
0`0017_N0`00og_N;7_N00=[FGooJeT02f]I00E24248JeU[FD8@004Q2000
00A[FGooJeU[FOmkg^EkgP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P0
0004JeUoof]IJeWoNmkUNmh00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48
000016]IOom[FF]Iog_NiG_N00=[FGooJeT02f]I00E24248JeU[FD8@004Q
200000A[FGooJeU[FOmkg^EkgP03JeUoof]I00][F@05@Q0Q26]IJeU24001
8@P00004JeUoof]IJeWoNmkUNmh00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q00
0B48000016]IOom[FF]Iog_NiG_N00=[FGooJeT02f]I00E24248JeU[FD8@
004Q200000A[FGooJeU[FOmkg^EkgP03JeUoof]I00][F@05@Q0Q26]IJeU2
40018@P00004JeUoof]IJeWoNmkUNmh00f]IOom[F@0;JeT01D8@8@Q[FF]I
@Q000B48000016]IOom[FF]Iog_NiG_N00=[FGooJeT02f]I00E24248JeU[
FD8@004Q200000A[FGooJeU[FOmkg^EkgP03JeUoof]I00][F@05@Q0Q26]I
JeU240018@P00004JeUoof]IJeTINmh2000;Nmh2000RNmh3000XNmh4003o
Nmi/Nmh00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]I
6G_N00<007_NNmh02g_N00<007_NNmh08G_N00<007_NNmh0:G_N00<007_N
Nmh0og_NJg_N00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGoo
JeU[FAUkgP03001kgW_N00=kgP8000IkgP03001kgW_N00ekgP<000AkgP<0
009kgPL00003Nmh00000008000=kgPD000=kgP@00003Nmh00000009kgP80
009kgPD000AkgP<000AkgP03001kgW_N009kgP<000EkgP800003Nmh00000
00<00004Nmh000000002Nmh30005Nmh30002Nmh50003Nmh30002Nmh30000
17_N000000002G_N00<007_NNmh00g_N0`0000AkgP000000009kgP800003
Nmh0000000=kgP<000=kgP<0009kgPL0009kgPD000=kgP<0009kgPD000=k
gP<00>EkgP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]I
JeTINmh00`00NmikgP0;Nmh00`00NmikgP0<Nmh01@00NmikgW_N00000W_N
00D007_NNmikgP00009kgP05001kgP00Nmh00002Nmh01@00NmikgW_N0000
17_N00<007_NNmh00W_N00<007_NNmh017_N00@007_NNmh000EkgP03001k
gW_N00=kgP05001kgW_NNmh00003Nmh20004Nmh00`00NmikgP03Nmh00`00
NmikgP020002Nmh01@00NmikgW_N00000W_N00D007_NNmikgP0000=kgP05
001kgW_NNmh00003Nmh00`00NmikgP02Nmh01@00NmikgW_N00000W_N00D0
07_NNmikgP0000]kgP03001kgW_N00=kgP05001kgW_NNmh00002Nmh00`00
NmikgP020003Nmh01`00NmikgW_N001kgP0000=kgP08001kgW_N001kgP00
Nmh0009kgP05001kgW_NNmh00003Nmh01@00NmikgW_N00000g_N00<007_N
Nmh00W_N00D007_NNmikgP000>AkgP03JeUoof]I00][F@05@Q0Q26]IJeU2
40018@P00004JeUoof]IJeTINmh00`00NmikgP04Nmh00`00NmikgP04Nmh0
0`00NmikgP0<Nmh00`00NmikgP04Nmh01@00NmikgW_N00000W_N00D007_N
001kgP00009kgP05001kgW_NNmh00004Nmh00`00NmikgP02Nmh00`00Nmik
gP05Nmh20006Nmh00`00NmikgP03Nmh00`00NmikgP04Nmh00`00Nmh00004
Nmh00`00NmikgP03Nmh01@00NmikgW_N00000W_N00D007_NNmikgP00009k
gP03001kgW_N00EkgP03001kgW_N00EkgP03001kgW_N009kgP05001kgW_N
Nmh00002Nmh01@00NmikgW_N000017_N2@0017_N1@000W_N00D007_NNmik
gP0000=kgP03001kgW_N00=kgP05001kgW_NNmh00002Nmh01@00Nmh007_N
00000W_N00D007_NNmikgP0000=kgP03001kgW_N00EkgP03001kgW_N009k
gP03001kgW_N0>IkgP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004
JeUoof]IJeTINmh00`00NmikgP05Nmh00`00NmikgP03Nmh00`00NmikgP0<
Nmh00`00NmikgP04Nmh01@00NmikgW_N00000W_N00D007_N001kgP00009k
gP05001kgW_NNmh00004Nmh00`00NmikgP02Nmh50003Nmh20006Nmh00`00
NmikgP03Nmh00`00NmikgP04Nmh01000NmikgP000g_N00<007_N00000g_N
00D007_NNmikgP00009kgP05001kgW_NNmh00002Nmh00`00NmikgP05Nmh0
0`00NmikgP05Nmh00`00NmikgP02Nmh01@00NmikgW_N00000W_N00D007_N
NmikgP0000]kgP03001kgW_N00AkgP03001kgP0000=kgP05001kgW_NNmh0
0003Nmh00`00NmikgP03Nmh01@00NmikgW_N00000W_N00D007_N001kgP00
00=kgP@000=kgP03001kgW_N00EkgP03001kgW_N009kgP03001kgW_N0>Ik
gP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeTINmh0
0`00NmikgP06Nmh00`00NmikgP02Nmh00`00NmikgP0<Nmh00`00NmikgP04
Nmh01@00NmikgW_N00000W_N00D007_N001kgP00009kgP80009kgP03001k
gW_N009kgP03001kgW_N009kgP05001kgW_NNmh00002Nmh01000NmikgP00
1G_N00<007_NNmh00g_N00<007_NNmh00g_N00D007_NNmikgP0000=kgP<0
00=kgP05001kgW_NNmh00002Nmh20002Nmh01000NmikgP000g_N00D007_N
NmikgP0000MkgP03001kgW_N009kgP05001kgW_NNmh00002Nmh20002Nmh0
0`00NmikgP08Nmh00`00NmikgP05Nmh00`00Nmh00003Nmh01@00NmikgW_N
00000g_N00<007_NNmh00g_N00D007_NNmikgP00009kgP05001kgP00Nmh0
0002Nmh01@00NmikgW_N00000g_N00<007_NNmh01G_N00<007_NNmh00W_N
00D007_NNmikgP000>AkgP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P0
0004JeUoof]IJeTINmh00`00NmikgP03Nmh01000NmikgP0017_N00<007_N
Nmh037_N00<007_NNmh01G_N0`000W_N0`0000AkgP00NmikgP800003Nmh0
000000EkgP03001kgW_N00=kgP<0009kgP80009kgP80009kgP<000AkgPD0
0005Nmh00000001kgP030002Nmh00`00Nmh00002Nmh20002Nmh2000017_N
000007_N0P0017_N10000W_N1@000W_N0`001G_N0`000W_N0P0000=kgP00
00004g_N00<007_N00000W_N0P000W_N0P000W_N1@000g_N0`000W_N0`00
00=kgP00Nmh00g_N0`000g_N1@000W_N0`001G_N1000i7_N00=[FGooJeT0
2f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FAUkgP03001kgW_N00Ak
gP8000EkgP03001kgW_N00akgP05001kgW_NNmh0000INmh00`00NmikgP0H
Nmh00`00NmikgP0;Nmh01@00NmikgW_N00005g_N00<007_NNmh0:G_N00<0
07_NNmh02W_N00<007_NNmh06G_N00<007_NNmh0lg_N00=[FGooJeT02f]I
00E24248JeU[FD8@004Q200000A[FGooJeU[FAUkgP8000]kgP8000mkgP@0
01QkgP8001AkgP03001kgW_N011kgPH001mkgP03001kgW_N021kgP80031k
gP03001kgW_N0>]kgP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004
JeUoof]IJeWoNmkUNmh00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B480000
16]IOom[FF]Iog_NiG_N00=[FGooJeT02f]I00E24248JeU[FD8@004Q2000
00A[FGooJeU[FOmkg^EkgP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P0
0004JeUoof]IJeWoNmkUNmh00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48
000016]IOom[FF]Iog_NiG_N00=[FGooJeT02f]I00E24248JeU[FD8@004Q
200000A[FGooJeU[FOmkg^EkgP03JeUoof]I00][F@05@Q0Q26]IJeU24001
8@P00004JeUoof]IJeWoNmkUNmh00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q00
0B48000016]IOom[FF]Iog_NiG_N00=[FGooJeT02f]I00E24248JeU[FD8@
004Q200000A[FGooJeU[FOmkg^EkgP03JeUoof]I00][F@05@Q0Q26]IJeU2
40018@P00004JeUoof]IJeWoNmkUNmh00f]IOom[F@0;JeT01D8@8@Q[FF]I
@Q000B48000016]IOom[FF]I6G_N0P002g_N0P00<7_N0`00H7_N0`00og_N
9g_N00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FAUk
gP03001kgW_N00]kgP03001kgW_N02mkgP03001kgW_N03QkgP03001kgW_N
02EkgP03001kgW_N0?mkgRIkgP03JeUoof]I00][F@05@Q0Q26]IJeU24001
8@P00004JeUoof]IJeTINmh00`00NmikgP03Nmh20006Nmh00`00NmikgP0;
Nmh300001G_N00000000Nmh010000g_N100017_N0P0000=kgP0000001`00
00=kgP0000000P001G_N0`000W_N1@000g_N0`000W_N0`0000EkgP000000
07_N00@000EkgP03001kgW_N009kgP03001kgW_N00MkgP04001kgW_NNmh3
00001G_N00000000Nmh010000g_N100017_N0P0000=kgP0000001`0000=k
gP0000000P001G_N0`000W_N1@000g_N0`000W_N0`0000EkgP00000007_N
00@00?mkgP9kgP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUo
of]IJeTINmh00`00NmikgP0;Nmh00`00NmikgP0<Nmh01@00NmikgW_N0000
0W_N00D007_NNmikgP00009kgP05001kgW_NNmh00002Nmh00`00NmikgP02
0002Nmh01@00Nmh007_N00000W_N00D007_NNmikgP0000=kgP05001kgW_N
Nmh00003Nmh00`00NmikgP02Nmh01@00NmikgW_N00000W_N00D007_NNmik
gP00009kgP05001kgW_NNmh0000:Nmh00`00NmikgP04Nmh30004Nmh01@00
NmikgW_N00000W_N00D007_NNmikgP00009kgP05001kgW_NNmh00002Nmh0
0`00NmikgP020002Nmh01@00Nmh007_N00000W_N00D007_NNmikgP0000=k
gP05001kgW_NNmh00003Nmh00`00NmikgP02Nmh01@00NmikgW_N00000W_N
00D007_NNmikgP00009kgP05001kgW_NNmh0003oNmh1Nmh00f]IOom[F@0;
JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]I6G_N00<007_NNmh017_N
00<007_NNmh017_N00<007_NNmh037_N1@001W_N00<007_NNmh017_N00@0
07_NNmh000=kgP08001kgW_N001kgP00Nmh0009kgP05001kgW_NNmh00003
Nmh00`00NmikgP05Nmh00`00NmikgP02Nmh01@00NmikgW_N00000W_N00D0
07_NNmikgP0000IkgP03001kgW_N00AkgPH000EkgP04001kgW_N0003Nmh5
0006Nmh00`00NmikgP04Nmh01000NmikgP000g_N00P007_NNmh007_N001k
gP000W_N00D007_NNmikgP0000=kgP03001kgW_N00EkgP03001kgW_N009k
gP05001kgW_NNmh00002Nmh01@00NmikgW_N00001W_N00<007_NNmh0oW_N
00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FAUkgP03
001kgW_N00EkgP03001kgW_N00=kgP03001kgW_N00ekgP03001kgP0000Ak
gP<000AkgP<000=kgP05001kgW_NNmh00002Nmh01@00Nmh007_N00000W_N
00D007_NNmikgP0000=kgP03001kgW_N00EkgP03001kgW_N009kgP05001k
gW_NNmh00002Nmh01@00NmikgW_N00000g_N0`002g_N00<007_NNmh01G_N
0`0017_N00<007_N000017_N0`0017_N0`000g_N00D007_NNmikgP00009k
gP05001kgP00Nmh00002Nmh01@00NmikgW_N00000g_N00<007_NNmh01G_N
00<007_NNmh00W_N00D007_NNmikgP00009kgP05001kgW_NNmh00003Nmh3
003oNmh2Nmh00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[
FF]I6G_N00<007_NNmh01W_N00<007_NNmh00W_N00<007_NNmh03G_N00<0
07_N00000g_N00D007_NNmikgP00009kgP05001kgW_NNmh00002Nmh01@00
NmikgW_N00000W_N00D007_N001kgP00009kgP80009kgP05001kgW_NNmh0
0007Nmh00`00NmikgP02Nmh01@00NmikgW_N00000W_N0P000W_N00@007_N
Nmh000=kgP03001kgW_N009kgP03001kgW_N009kgP03001kgW_N00EkgP03
001kgW_N00EkgP03001kgP0000=kgP05001kgW_NNmh00002Nmh01@00Nmik
gW_N00000W_N00D007_NNmikgP00009kgP05001kgP00Nmh00002Nmh20002
Nmh01@00NmikgW_N00001g_N00<007_NNmh00W_N00D007_NNmikgP00009k
gP80009kgP04001kgW_N0003Nmh00`00NmikgP3nNmh00f]IOom[F@0;JeT0
1D8@8@Q[FF]I@Q000B48000016]IOom[FF]I6G_N00<007_NNmh00g_N00@0
07_NNmh000AkgP03001kgW_N00ekgP03001kgP0000AkgP@000=kgP@00003
Nmh00000009kgP800006Nmh00000001kgP000W_N0P0000=kgP0000000g_N
1@000W_N0`001G_N0`000W_N0P0000=kgP00000017_N10004G_N00<007_N
Nmh01G_N00<007_N000017_N10000g_N100000=kgP0000000W_N0P0000Ik
gP00000007_N0002Nmh200000g_N00000003Nmh50002Nmh30005Nmh30002
Nmh200000g_N00000004Nmh4003oNmh1Nmh00f]IOom[F@0;JeT01D8@8@Q[
FF]I@Q000B48000016]IOom[FF]I6G_N00<007_NNmh017_N0P001G_N00<0
07_NNmh03W_N00<007_NNmh09W_N00<007_NNmh0;g_N0`001G_N00<007_N
Nmh09W_N00<007_NNmh0og_N7W_N00=[FGooJeT02f]I00E24248JeU[FD8@
004Q200000A[FGooJeU[FAUkgP8000]kgP8000mkgP80031kgP03001kgW_N
02QkgP03001kgW_N00=kgP80031kgP03001kgW_N0?mkgQIkgP03JeUoof]I
00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeWoNmkUNmh00f]IOom[
F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]Iog_NiG_N00=[FGoo
JeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FOmkg^EkgP03JeUo
of]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeWoNmkUNmh00f]I
Oom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]Iog_NiG_N00=[
FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FOmkg^EkgP03
JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeWoNmkUNmh0
0f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]IofNIiFNI
00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FOmWVNEW
V@03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeWoIiWU
IiT00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]IofNI
iFNI00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FOmW
VNEWV@03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeWo
IiWUIiT00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]I
ofNIiFNI00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[
FOmWV@MWVClQ20MWVClQ20MWVClQ21=WV@03JeUoof]I00][F@05@Q0Q26]I
JeU240018@P00004JeUoof]IJeWoIiT7IiT00f]I@Q12400k@Q000b48IiUW
V@05IiT00f]I@Q12400k@Q000b48IiUWV@05IiT00f]I@Q12400k@Q000b48
IiUWV@0AIiT00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[
FF]IofNI1fNI00=[FGooFcT0>U/i00=24248IiT01VNI00=[FGooFcT0>U/i
00=24248IiT01VNI00=[FGooFcT0>U/i00=24248IiT04VNI00=[FGooJeT0
2f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FOmWV@MWV@03JeUooe/i
03YK>@03@Q0Q26NI00IWV@03JeUooe/i03YK>@03@Q0Q26NI00IWV@03JeUo
oe/i03YK>@03@Q0Q26NI019WV@03JeUoof]I00][F@05@Q0Q26]IJeU24001
8@P00004JeUoof]IJeWoIiT7IiT00f]IOomK>@0jFcT00d8@8@QWV@06IiT0
0f]IOomK>@0jFcT00d8@8@QWV@06IiT00f]IOomK>@0jFcT00d8@8@QWV@0B
IiT00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]IofNI
1fNI00=[FGooFcT0>U/i00=24248IiT01VNI00=[FGooFcT0>U/i00=24248
IiT01VNI00=[FGooFcT0>U/i00=24248IiT04VNI00=[FGooJeT02f]I00E2
4248JeU[FD8@004Q200000A[FGooJeU[FOmWV@MWV@03JeUooe/i03YK>@03
@Q0Q26NI00IWV@03JeUooe/i03YK>@03@Q0Q26NI00IWV@03JeUooe/i03YK
>@03@Q0Q26NI019WV@03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004
JeUoof]IJeWoIiT7IiT00f]IOomK>@0BFcT300001E/i00000000FcT01@00
0U/i1@0055/i00=24248IiT01VNI00=[FGooFcT03U/i0`0000=K>@000000
0e/i0`000U/i0`0000AK>@000000009K>@@0015K>@03@Q0Q26NI00IWV@03
JeUooe/i00mK>@D000=K>@D00003FcT00000008000EK>@<0015K>@03@Q0Q
26NI019WV@03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]I
JeWoIiT7IiT00f]IOomK>@0CFcT01@00FcUK>E/i000015/i00<005/iFcT0
15/i00<005/iFcT055/i00=24248IiT01VNI00=[FGooFcT03e/i00<005/i
FcT00P000U/i00D005/iFcUK>@00009K>@05001K>E/iFcT00002FcT00`00
FcUK>@0CFcT00d8@8@QWV@06IiT00f]IOomK>@0@FcT01000FcUK>@000U/i
00D005/iFcUK>@00009K>@05001K>E/iFcT00003FcT01@00FcUK>E/i0000
45/i00=24248IiT04VNI00=[FGooJeT02f]I00E24248JeU[FD8@004Q2000
00A[FGooJeU[FOmWV@MWV@03JeUooe/i01=K>@D000AK>@03001K>E/i00AK
>@03001K>E/i01AK>@03@Q0Q26NI00IWV@03JeUooe/i00mK>@05001K>@00
FcT00002FcT01@00FcUK>E/i00000U/i00D005/iFcUK>@00009K>@03001K
>E/i01=K>@03@Q0Q26NI00IWV@03JeUooe/i011K>@04001K>E/i0002FcT0
1@00FcUK>E/i00001U/i00D005/iFcUK>@0001AK>@03@Q0Q26NI019WV@03
JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeWoIiT7IiT0
0f]IOomK>@0DFcT00`00FcT00005FcT00`00FcUK>@04FcT00`00FcUK>@0D
FcT00d8@8@QWV@06IiT00f]IOomK>@0?FcT01@00FcT005/i00000U/i00D0
05/iFcUK>@00009K>@05001K>E/iFcT00002FcT5000AFcT00d8@8@QWV@06
IiT00f]IOomK>@0@FcT00`00FcUK>@04FcT40003FcT30004FcT00`00FcUK
>@0BFcT00d8@8@QWV@0BIiT00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48
000016]IOom[FF]IofNI1fNI00=[FGooFcT055/i00<005/i00001E/i00<0
05/iFcT015/i00<005/iFcT055/i00=24248IiT01VNI00=[FGooFcT03e/i
00D005/i001K>@00009K>@05001K>E/iFcT00002FcT20002FcT01000FcUK
>@000e/i00<005/iFcT03e/i00=24248IiT01VNI00=[FGooFcT045/i00<0
05/iFcT00e/i00D005/iFcUK>@00009K>@05001K>E/iFcT00003FcT00`00
FcUK>@0BFcT00d8@8@QWV@0BIiT00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q00
0B48000016]IOom[FF]IofNI1fNI00=[FGooFcT055/i00<005/i00001E/i
00<005/iFcT015/i00<005/iFcT055/i00=24248IiT01VNI00=[FGooFcT0
3e/i0P000U/i00@005/iFcUK>@<0009K>@800003FcT0000000AK>@<0019K
>@03@Q0Q26NI00IWV@03JeUooe/i011K>@03001K>E/i00AK>@<000AK>@@0
009K>@D0015K>@03@Q0Q26NI019WV@03JeUoof]I00][F@05@Q0Q26]IJeU2
40018@P00004JeUoof]IJeWoIiT7IiT00f]IOomK>@0EFcT00`00FcUK>@04
FcT00`00FcUK>@04FcT00`00FcUK>@0DFcT00d8@8@QWV@06IiT00f]IOomK
>@0?FcT20002FcT00`00FcUK>@0TFcT00d8@8@QWV@06IiT00f]IOomK>@0@
FcT00`00FcUK>@0BFcT00`00FcUK>@0BFcT00d8@8@QWV@0BIiT00f]IOom[
F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]IofNI1fNI00=[FGoo
FcT055/i0P001E/i0P001E/i0P005U/i00=24248IiT01VNI00=[FGooFcT0
3U/i0`0000AK>@00000002EK>@03@Q0Q26NI00IWV@03JeUooe/i00mK>@<0
02QK>@03@Q0Q26NI019WV@03JeUoof]I00][F@05@Q0Q26]IJeU240018@P0
0004JeUoof]IJeWoIiT7IiT00f]IOomK>@0jFcT00d8@8@QWV@06IiT00f]I
OomK>@0jFcT00d8@8@QWV@06IiT00f]IOomK>@0jFcT00d8@8@QWV@0BIiT0
0f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]IofNI1fNI
00=[FGooFcT0>U/i00=24248IiT01VNI00=[FGooFcT0>U/i00=24248IiT0
1VNI00=[FGooFcT0>U/i00=24248IiT04VNI00=[FGooJeT02f]I00E24248
JeU[FD8@004Q200000A[FGooJeU[FOmWV@MWV@03JeUooe/i03YK>@03@Q0Q
26NI00IWV@03JeUooe/i03YK>@03@Q0Q26NI00IWV@03JeUooe/i03YK>@03
@Q0Q26NI019WV@03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUo
of]IJeWoIiT7IiT00f]IOomoo`0jOol00d8@8@QWV@06IiT00f]IOomoo`0j
Ool00d8@8@QWV@06IiT00f]IOomoo`0jOol00d8@8@QWV@0BIiT00f]IOom[
F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]IofNI1fNI?V]I00<Q
26NIIiT01FNI?V]I00<Q26NIIiT01FNI?V]I00<Q26NIIiT04FNI00=[FGoo
JeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FOmWVNEWV@03JeUo
of]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeWoIiWUIiT00f]I
Oom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]IofNIiFNI00=[
FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FOmWVNEWV@03
JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeWoIiWUIiT0
0f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]IofNIiFNI
00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FOlJe^DJ
eP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeWo6]KU
6]H00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]Ioa[F
iA[F00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FOlJ
e^DJeP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeWo
6]KU6]H00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]I
oa[FiA[F00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[
FOlJe^DJeP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]I
JeWo6]KU6]H00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[
FF]I6a[F17oo3a[F17ooHA[F1GooPa[F1Goo9a[F1gooUQ[F00=[FGooJeT0
2f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FA/JePAoo`lJePAoof4J
ePEooh<JePEoobLJePMooiHJeP03JeUoof]I00][F@05@Q0Q26]IJeU24001
8@P00004JeUoof]IJeTK6]H2OolC6]H2OomR6]H2Oon66]H2Ool/6]H2OonH
6]H00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]I6a[F
0Woo21[F0goo21[F0Woo41[F0Woo00@JeWooOomoo`LJePIoo`<JePQoo`DJ
ePIoo`DJePIoo`HJePAoo`/JePEoo`@JeP9oo`036]Ioogoo009oo`LJePAo
o`@JePQoo`DJePEoo`@JePAoo`036]Ioogoo009oo`<JePIoo`/JePEoo`@J
ePQoo`dJeP9oo`046]IoogooOol56]H8Ool36]H3Ool011[FOomooa[F0goo
00@JeWooOolJePAoo`@JePQoo`<JePQoo`<JePQoo`HJeP9ooiLJeP03JeUo
of]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeTK6]H2Ool86]H3
Ool86]H2Ool@6]H7Ool56]H8Ool26]H8Ool46]H8Ool36]H8Ool46]H7Ool8
6]H7Ool36]H8Ool56]H7Ool26]H8Ool46]H7Ool36]H4Ool00a[FOomoo`02
Ool36]H7Ool96]H7Ool36]H8Ool=6]H7Ool46]H8Ool36]H3Ool011[FOomo
oa[F0goo00<JeWooOol01Woo0a[F27oo0a[F27oo0a[F27oo1Q[F0WooUa[F
00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FA/JeP9o
oa<JeP9ooa0JeP9oo`@JeP9oo`<JeP9oo``JeP9oo`HJeP9oo`TJeP=oo`DJ
eP03OolJeQ[F008JeP9oo`<JeP9oo`LJeP=oo`<JeP=oo`8JeP=oo`<JeP=o
o`@JeP9oo`<JeP9oo`DJeP9oo`HJeP=oo`<JeP=oo`<JeP9oo`<JeP9oo`@J
eP9oo`<JeP9oo`PJeP=oo`<JeP=oo`@JeP9ooa4JeP9oo`@JeP9oo`HJeP9o
o`LJeP9oo`046]Ioogoo6]H2Ool26]H3Ool36]H3Ool56]H2Ool96]H2Ool8
6]H2Ool96]H4OonF6]H00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B480000
16]IOom[FF]I6a[F0Woo2A[F0Woo21[F0Woo41[F0Woo11[F0Woo0a[F2Goo
1A[F0Woo1Q[F2Goo0Q[F0Woo2a[F0Woo31[F0Woo1A[F0Woo0Q[F0Woo1A[F
0Woo11[F0Woo2Q[F0Woo1Q[F0Woo1A[F0Woo0a[F0Woo0a[F0Woo1Q[F1Goo
21[F0Woo1A[F0Woo11[F0Woo4A[F0Woo11[F0Woo1Q[F0Woo1a[F0Woo00@J
eWooOolJeP9oo`8JeP9oo`DJeP9oo`DJeP9oo`TJeP9oo`PJeP9oo`TJeP9o
o`036]Ioogoo09DJeP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004
JeUoof]IJeTK6]H2Ool96]H3Ool76]H2OolD6]H4Ool36]H9Ool56]H2Ool6
6]H9Ool26]H2Ool56]H2Ool46]H2Ool<6]H2Ool56]H2Ool26]H2Ool56]H2
Ool46]H2Ool:6]H2Ool66]H2Ool56]H2Ool36]H2Ool36]H2Ool46]H5Ool:
6]H2Ool56]H2Ool46]H2OolE6]H4Ool66]H2Ool76]H2Ool011[FOomooa[F
0Woo0Q[F0Woo1A[F0Woo1A[F0Woo2A[F0Woo21[F0Woo21[F0Woo0Q[F0Woo
UA[F00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FA/J
eP9oo`TJePAoo`HJeP9ooa4JePIoo`@JeP9oo`DJeP9oo`DJeP9oo`HJeP9o
o`DJeP9oo`8JeP=oo`@JeP9oo`@JeP9oo``JeP=oo`<JeP=oo`8JeP=oo`<J
eP=oo`@JeP9oo`XJeP9oo`HJeP=oo`<JeP=oo`<JeP=oo`8JeP9oo`@JeP9o
o`<JeP9oo`PJeP=oo`<JeP=oo`@JeP9ooa8JePIoo`LJeP9oo`LJeP9oo`04
6]Ioogoo6]H2Ool26]H3Ool36]H3Ool56]H2Ool96]H2Ool86]H2Ool76]H2
Ool46]H2OonD6]H00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]I
Oom[FF]I6a[F0Woo2a[F0Woo1Q[F0Woo41[F17oo21[F1goo1Q[F0Woo1a[F
1goo11[F27oo0Q[F27oo2A[F1goo0Q[F2Goo0a[F27oo11[F17oo1a[F1goo
0a[F27oo11[F1goo2A[F1goo0a[F27oo3A[F17oo21[F17oo1Q[F2Goo00<J
eWooOol01goo1Q[F0Woo1a[F17oo1Q[F27oo0Q[F17oo0Q[F17ooTa[F00=[
FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FA/JeP9oo`HJ
eP9oo`<JeP9oo`HJeP9ooa0JeP9oo`@JeP9oo`DJePEoo`LJeP9oo`PJePEo
o`HJePEoo`046]Iooa[F6]H8Ool:6]H5Ool36]H3Ool00a[FOomoo`02Ool4
6]H8Ool46]H4Ool86]H5Ool46]H3Ool011[FOomoogoo1Q[F1Woo2Q[F1Goo
11[F27oo3A[F0Woo11[F0Woo11[F17oo1Q[F1Goo00<JeWooOol00Q[F0goo
00<JeWooOol00Woo1a[F0Woo1a[F17oo1Q[F27oo0Q[F17oo0Q[F17ooTa[F
00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FA/JeP9o
o`HJeP9oo`<JeP9oo`HJeP9ooa0JeP9oo`@JeP9ooa4JeP9ooahJeP9oob@J
eP9oodDJeP9ooa4JeP9oo`@JeP9oobLJeP9ooa<JeP9ooj<JeP03JeUoof]I
00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeTK6]H4Ool46]H6Ool5
6]H4OolA6]H7Ool?6]H4OolN6]H2OolT6]H2Ool:6]H2Ooli6]H7Ool=6]H7
Ool66]H2OolM6]H4Ool96]H2Ool86]H7OonN6]H00f]IOom[F@0;JeT01D8@
8@Q[FF]I@Q000B48000016]IOom[FF]I6a[F17oo1A[F17oo1Q[F17oo4Q[F
0goo00<JeWooOol03a[F17oo7Q[F0Woo91[F0Woo2Q[F0Woo>Q[F1Woo3Q[F
0goo00<JeWooOol01Q[F0Woo7A[F17oo2A[F0Woo2A[F1WooWQ[F00=[FGoo
JeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FOlJe^DJeP03JeUo
of]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeWo6]KU6]H00f]I
Oom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]Ioa[FiA[F00=[
FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FOlJe^DJeP03
JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeWo6]KU6]H0
0f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]Ioa[FiA[F
00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[FGooJeU[FOlJe^DJ
eP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeWo6]KU
6]H00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B48000016]IOom[FF]Ioa[F
iA[F00=[FGooOol02goo00E24248JeU[FD8@004Q200000A[FGooJeU[FOlJ
e^DJePm[F@048@Q[FF]I@Q018@P00004JeUoof]IJeWo6]KU6]H@8@P2JeT1
@Q018@P00004JeUoof]IJeWo6]KU6]H00f]I@Q12400<@Q001248JeU[FD8@
0B48000016]IOom[FF]Ioa[FiA[F00=[FGooJeT02f]I00E24248JeU[FD8@
004Q200000A[FGooJeU[FOlJe^DJeP03JeUoof]I00][F@05@Q0Q26]IJeU2
40018@P00004JeUoof]IJeWo6]KU6]H00f]IOom[F@0;JeT01D8@8@Q[FF]I
@Q000B48000016]IOom[FF]Ioa[FiA[F00=[FGooJeT02f]I00E24248JeU[
FD8@004Q200000A[FGooJeU[FOlJe^DJeP04JeUoof]IJeT70003JeT01D8@
8@Q[FF]I@Q000B48000016]IOom[FF]Ioa[FiA[F00=[FGooJeT00V]I1@00
16]I00E24248JeU[FD8@004Q200000A[FGooJeU[FOlJe^DJeP03JeUoof]I
00=[F@<000E[F@05@Q0Q26]IJeU240018@P00004JeUoof]IJeWo6]KU6]H0
0f]IOom[F@04JeT00`00JeU[F@04JeT01D8@8@Q[FF]I@Q000B48000016]I
Oom[FF]Ioa[FiA[F00=[FGooJeT02f]I00E24248JeU[FD8@004Q200000A[
FGooJeU[FOlJe^DJeP03JeUoof]I00][F@05@Q0Q26]IJeU240018@P00004
JeUoof]IJeWo6]KU6]H00f]IOom[F@0;JeT01D8@8@Q[FF]I@Q000B480000
16]IOom[FF]Ioa[FiA[F00=[FGooJeT02f]I00E24248JeU[FD8@004Q2000
00A[FGooJeU[FOlJe^DJeP03JeUoogoo00]oo`05@Q0Q26]IJeU240018@P0
0004JeUoof]IJeWoIBWUIBT?JeT01248JeU[FD8@0B4800000f]IOom[F@3o
JeWhJeT1@Q018@P0000<JeUoof]IJeT8SPB=28h4S@R^18d8[PB=0`R^00<8
[@R^2:h02PR^010<c`R^3<h8[Pc?2:h<c`R^3<l<cPc?2<h<c`c>3<l<cPP<
c`0D4>l<ca3_3<l@l0c_4>l<ka3`4>l@l0c_4?0@ka3`4>l@l13_4?0@k`@@
l00T5A0@l1D@4?0E414@5A0A41D@4A0E414@5A4E41DA5A0E4AD@5A4E41DA
5A0E4AD@6C4E4ATa5A4I<ADa6C4E<ATa5C4I<ADa11Ta01@I<QTa6C8I<ATb
6C4IDQTa7E8I<AeB6C4MDQUB7E8IDAeB6E8MDQUB21eB010MLaeB7G<MDR5c
7E8MLaeb8G<MLR5c7G8QLaec8G<MLPPQL`058I<QLb6C8G<UU0038I<022FD
8I<UU26C9I@QTbFD8I<39I@00b6C9I@UU0029I@012Fd9I@U]2FD12Fd01@Y
]BFd:K@U]2Ve9K@Y]BFd:KDY]2Ve9K@Y]BVd:KDY]2WE:KDYeBVe12WE01@]
eBWE;MDYeBgF:MD]eBWE;MHYeBgF:MD]eRgE;OH]eBgf;MD]mRgE12gf040a
mRgf<OH]mS7f;OHamRgf<OH]mS7f;OHb5c7f<QLamS8G<QHb5c8F<QLb5S8G
<QHf5c8G=QLb5cHG<QLf5c8G=QLb5cHG<QLf=cHG=SLf5cHh=SLf>3Hg=SPf
=cHh=SLj>3Hg>SPf=cXh=SPj>3Hg>SPf>3Xh=SPjF3Xh>UPj>0@jF00D>UTj
F3YI>UPnFCYH>UTjF3iI>UPnFCYH?UTjFCiI>UPnNCiI?WTnF@PnN@0@?WXn
NCii?WU2NSii@WXnND:J?WU2VSii@YY2NT:J?YT<@YX044JK@YY6VT:JA[]2
VTJk@YY6^dJjA[]2^TJkA[Y6^dJj24Jk01A:^dJkB[]6^d[LA[]:fdJkB]a6
fd[LA]]:g4[KB]a:fd[LB]]:g4[K14[L02A>g4[LC]a:g4klB]a>o4[LC_a:
o4klB_a>oDklC_e>o4kmC_a>oDklC_e>o4kmC_aBoDkmDae>oE<MC_eC7Dkm
Dae?7E<MCad4Dad055<NDaeC7U<MDaiC7E<NDaeG?U<MDciC7ELnDaiG?U<m
EciC?ULnDch4EchDDch2JeT1@Q018@P00004JeUoof]IJeT518d02@R^18d8
[PB=2:h4S@R^1:d8[P02Ool00`R]2:h8[@0:2:h04Pc>2:h<cPR^3<l8cPc?
2<h<c`S>3<l<cPc?3<h<c`c>3<l<cPH<c`0R4>l<ca3_3>l@k`c_4>l<ka3`
3>l@l13_4?0<ka3`4>l@l13_4?0@ka3`4>lA413`5A0@l1D@4A0E414@5A0A
41D@4A025A003QDA4A0E41D@5A4E41DA5A0E<AD@5C4E41Ta5A025C402QTa
5C4I<ADa6C4E<ATa5C4I<ADa0QTa01HI<QTa6C4I<AUB6C4IDQTa7E8I<AUB
6E4MDQUA7E8IDQeB6E4MDQUB7E8IDPHMDP0B7G8MDQeb7E8MLaeb7G<MLR5c
7G8QLaeb8G<MLR5c7G<QLaeb125c00DQTb5c8I<QLb6C00Aoo`0C8I<UU26C
9I@QTbFD8I<UU26C9I@QTbFD9I<U]2FC9K@UU2Fd9I@01RFd018Y]2Fd:K@U
]2Ve9K@Y]BFd:KDU]2Ve:K@YeBVd:MDY]2WE:K@6:MD05RgE:MD]eBWE;MDY
eBgE:MD]eRWE;MH]eBgf:MD]mRgE;OH]eBgf;OD]mRge0Rgf00hamRgf<OH]
mS7f;OHamRgf<OH]mS7f;OHb5bgf0S8F00Xb5c8F<QLb5S8G<QHb5c8F=QLb
5P8b5`0:=QLb5cHG<QLf5c8G=SLb5cHg<QL2=SL05SHh=SLf=cHg=SPf=cHh
=SLj>3Hg=SPf=cXh=SLj>3Hh>UPf=cYH=SPjF3Hh2SYH00hjFCYH>UTjF3iI
>UPnFCYH?WTjF3ii>UTnNCYH3Sii00i2NSii@WXnND:J?WU2VSii@YXnVD:J
@YU2VT:I2T:J0196VT:JAYY2VTJk@YY6^d:jA[]2^TJkA[Y6^d:jA[]6^TJk
A[X6A[/05T[KA[]:fdJkB]]6^d[KA]]:g4KKB]a:fd[LA]]:g4[KB]a:fd[L
B]]:g4[K0T[L00i>o4[LB_a:g4klB]a>o4[lC_a:o4klB_a>oD[l0Tkl01I>
oDklC_e>o4kmC_a>oDklDae>o4lMC_eC7DkmDae?7E<MCaeC7DlMDae?7@9C
7@0CDaiC7E<MDaeC7U<MDaiC7E<nDaeC?U<MEciC?ELnDciG?U<mEch055<n
0V]I0D8@0B4800003V]IOom[FF]I28h4S@R^18d8[PB=2:h4S@R^1:d32:h0
0`R]Oomoo`062:h050b^2:h8[PR^3<l8[Pc>2:h<c`S>3<l8cPc?3<h<c`c>
3<l<cPc?3<h83<l0513_3<l@k`c?4?0<ka3_3>l@l13_4?0<ka3`4>l@l13_
4?0@ka3`4>l44?0091D@4?0E413`5A0A41D@4A0E414@5A0A41DA5A0E4AD@
5A4E41DA5A0E<AD@5C4E41Ta5A4I<ADA6C4E<ATa5C4I<ADa6C4E<@@I<@0D
6C8I<ATb6C4IDQTa6E8I<AeB6E4MDQUA7E8IDQeB6E8MDQUB7E8IDPPMDP0@
7G<MDQec7E8QLaeb8G<MLR5c7G8QLaeb8G<MLb5c7G888G<02B6C8G<QTb5c
9IAoob6D8I<UU002Ool01B6C9I@QTbFD8I<00bFD00XUTbFD9I@U]2FD9K@U
U2Fd9I@Y]0<U]00B:KDU]2Vd9K@Y]BFd:KDU]2Ve:K@Y]BFd:MDY]2WE:K@Y
eBVe1RWE01@]eBWE;MDYeBgF:MD]eBWE;MH]eBgF:MD]mRgE;OH]eBgf;OD]
mRge12gf040amRgf<OH]mS7f;OHamRgf<OH]mS7f;OHb5c7f<QLamS8G<QHb
5c8F<QLb5S8G<QHf5c8G=QLb5cHG<QLf5c8G=QLb5cHG<QLf=cHG=SLf5cHh
=SLf>3Hg=SPf=cHh=SLj>3Hg>SPf=cXh=SPj>3Hh>SPf>3YH=SPjF3Xh>UPj
>0@jF00B>UTjF3YI>UPnFCYH>UTjF3iI>UPnFCYH?WTjFCii>UPnNCiI2Sii
00a2NSii?WXnND9j?WU2NSii@YXnND:J?WT3@YX00d:I@YY2VP0:@YX044JK
@YY6VT:JA[]2VTJk@YY6^dJjA[]2^TJkA[Y6^dJj24Jk01A:^dJkB[]6^d[L
A[]:fdJkB]a6fd[LA]]:g4[KB]a:fd[LB]]:g4[K14[L02A>o4[LC_a:g4kl
B]a>o4[LC_a:o4klB_a>oDklC_e>o4kmC_a>oDklC_e>o4kmC_aC7DkmDae>
oE<MCaeC7DlMDae?7E<MCad4Dad055<NDaeC7U<MDaiC7E<NDaeG?U<MEciC
7ELnDciG?U<nEciC?ULnDch2EchB8@P2Dch2JeT1@Q018@P00004JeUoof]I
JeT718d01`R^18d8[PB=2:h4[@R^009oo`051:d8[PR^2:h8[@082:h050S>
2:h<cPR^3<h8cPc?2<h<c`S>3<l8cPc?3<h<c`c>3<l<cPc?3<h23<l09Pc_
3<l<k`c?4>l<ca3_3>l@k`c_4>l<ka3`3>l@l13_4?0@ka3`4>l@l13_4?0@
ka4@4>lA413`5A0@l1D@4A0E414@5A0A41D@4A025A005QDA4A0E41D@5A4E
41DA5A0E<AD@5C4E41Ta5A0I<ADa6C4E<ATa5C4I<ADa0aTa00@E<ATa6C4I
<P<I<@0B6E8I<AUB6E4MDQUA6E8IDAeB6E4MDQUB7E8IDAeB6E8MDQUB11eB
00@MLQeB7G<MDP8MLP0>8G<MLQec7G8QLaeb8G<MLR5c7G8QLaec8G<MLP8Q
L`068I<QLb6C8G<QTb5c0b6C0Woo00/QTbFD8I<UU26C9I@QTbFD8I<UU26C
008UU0069K@UTbFd9I@U]2FD1RFd018Y]2Fd:K@U]2Ve9K@Y]BFd:KDU]2Ve
:K@YeBVd:MDY]2WE:M@6:MD05RgE:MD]eBWE;MDYeBgE:MD]eRWE;MH]eBgf
:MD]mRge;OH]mBgf;OD]mRge0Rgf00hamRgf<OH]mS7f;OHamRgf<QH]mS8F
<OHb5bgf0S8F01Hb5c8F<QLb5S8G<QHb5c8F=QLb5SHG<QLf5c8G=QLb5cHg
<QLf=c8G=SLb5`8f=`0F=SPf=cHg=SLf>3Hg=SPf=cXh=SLf>3Hg>SPf=cXh
=SPjF3Hg>UPf>3YH=SP6>UP04SYI>UPjF3YH>UTjF3YI>UPnFCYH?UTjF3ii
>UPnNCYi?WTjN0hnN@0:@WXnND:J?WU2VSii@YXnVD:J?YT3@YX00d:I@YY2
VP08@YX04TJj@YY6^T:JA[]2VTJk@[Y6^d:jA[]6^TJkA[Y6^dJjA[]6^PI6
^`0FB]]6^d[KA[]:fdJkB]]6fd[LA]]:g4[KB]a6fd[LB]]:g4[KB]a:fd[L
B]/2B]`02TklB]a>o4[LC_a:o4klB_a>o4[l0Tkl00i>oD[lC_a>o4kmC_a>
oDklC_e>o4kmC_aC7Dkl0TlM00YC7DlMDae?7E<MCaeC7DlMDae?7@9C7@0B
DaiC7E<MDaeC?U<MDciC7ELnDaeC?U<mEciC?ELnDciG?Woo448@00<Q25<n
Dch00V]I0D8@0B4800002F]IOom[FF]I28h4S@R>18d8[P05Ool010R^2:d8
[PR^1Woo10R^00H<cgooOomoo`c?2:h2Ool010c?3<h<c`S>17oo0`c?0Woo
0`c?00D@kgooOol<ca3`00Eoo`074?0<ka3`4>l@l13_4?001Woo00D@l1D@
4?0E413`00Eoo`034A0E414@009oo`045A4E41DA5A05Ool011D@6C4E4ATa
17oo00@E<ATa5C4I<@=oo`8I<@036C9oogoo009oo`036C4IDQTa009oo`09
7E8I<AeB6E8MDQUA7E8IDQeB00Moo`8MDP037G<MDQec009oo`037E8MLaeb
00Moo`047G8QLgooOol48G<4Ool00b5c9I@QT`028I<3Ool01B6COomoobFD
8I<00bFD00<QTbFD9I@00RFD00@U]2FD9K@UU0@U]00D:KDU]2Vd9K@Y]BFd
:KDU]2Ve:K@Y]BFd:KDY]2Ve:K@YeBVe:MDY]@@Ye@0D;MDYeBgE:MD]eRWE
;MDYeBgF:MD]eRWE;MH]eBgf;MD]mRgE;OH]e@@]mP10<OH]mS7f;OHamRgf
<OH]mS7f;OHamRgf<QLamS8G<OHb5c8F<QLb5S8G<QHb5c8F=QLb5cHG<QLf
5c8G=QLb5cHG<QLf5c8G=SLf5cHg=QLf>3Hg=SPf=cHh=SLf>3Hg>SPf=cXh
=SLj>3Hh>SPf=cXh=SPj>3Hh>UPj>3YH>SP4>UP053YI>UPjFCYH?UTjF3YI
>UPnFCYH?UTjF3iI>UTnFCYH?WTnFCii?UT8?WT043ij?WTnNCii@WXnND9j
?WU2VSii@YXnND:J@WY2VSjI34:J0116Vd:JAYY2VTJk@YY6^d:JA[]6^TJk
@[Y6^dJjA[]6^PQ6^`0DB[]6^dZkA[]:g4JkB]]6^d[LA]]:g4KKB]a:fd[L
B]]:g4[KB]a:f`A:g00TC]a:g4kLB]a>o4[LC_a:g4klB_a>o4[lC_e>o4km
C_a>oDklC_e>o4kmC_a>oDklD_e>oE<MC_eC7DkmDae>oE<MCaeC7DlM15<M
01AC7U<MDaiC7E<NDaeC7U<MEciC7E<nDaeG?U<NEciC?ELnDciG?U<n15Ln
00=oof]IJeT03F]I00A24248DciC?P9[F@52404Q200000A[FGooJeU[F@<4
S@=oo`0318d8[PB=00=oo`071:d8[WooOol8[@R^2:d00Woo0`R^0Woo0`R^
00H<cWooOol8[Pc?2<h2Ool01Pc?2<ioogoo3<l<cP9oo`043<l<cPc?3<l2
Ool01Pc?Ool@k`c?4>l<k`9oo`054>l<ka3`3>l@l002Ool010c_4?0@ka3`
0Woo00<@ka3`4>l00Woo00LE413`5A0A47oo4A0E4002Ool00a4@5A0E4002
Ool25A001ADA5A1ooaD@5C400Woo00HE41Ta5A1ooaDa6C42Ool011Da6C4E
<ATa0Woo00@E<ATaOomoo`8I<@9oo`096C4IDQTa7E8I<AUB6E4MDQUA009o
o`047E8IDAeB6E83Ool37E82Ool021eb7E9oogoo7G<MLQec7G82Ool01b5c
7G9oogoo8G<MLb5c009oo`8QL`9oo`038G<QTb5c009oo`8QT`=oo`0A8I<U
U26C9I@QTbFD8I<UU26C9I@UTbFd9I<U]2FD9K@UU0069K@04RVd9K@Y]2Fd
:KDU]2Ve9K@Y]BFd:KDY]2WE:K@YeBVd:MDY]0HYe@0F;MDYeBgE:MD]eBWE
;MDYeBgF:MD]eRgE;OHYeBgf;MD]mRgE;OH]mBgf;OD2;OH03S7f;OHamRgf
<OH]mS7f;OHamRgf<OH]mS8G;OH2<QH02S8G<QHb5c8F<QLb5S8G<QHf5c8F
0S8G00Xf5c8G=QLb5cHG<QLf=c8G=SLb5`8f=`0F=SPf=cHg=SLf>3Hg=SPf
=cXh=SLf>3Hg>SPf=cXh=SPjF3Hg>UPf>3YH=SP:>UP03SYI>UPjFCYH?UTj
F3iI>UPnNCYH?WTjFCii>UP>?WT03T9j?WU2NSii@YXnND:J?WU2VSjI@YY2
VD:J@YT:@YX04TJJ@YY6VT:JA[]2VTJk@[Y6^d:jA[]6^TJk@[Y6^dJjA[]6
^PI6^`0FB]]6^d[KA[]:fdJkB]]6fd[LA]]:g4[KB]a6fd[LB]]:g4[KB]a:
fd[LB]/2B]`03TklB]a:o4[LC_a:g4klB_a>o4[lC_a:o4kmB_`2C_`05Tkm
C_a>oDklC_e>o4kmC_aC7DklCae>oE<MC_eC7DlMDae?7E<MCaeC7DlM0U<M
01AC7U<MDaeC7E<NDaeC7U<MDciC7E<nDaeG?U<mEciC?ULnDceG?Woo3f]I
00A24248DciC?P9[F@52404Q200000M[FGooJeU[F@R>18d8[P02Ool01@B=
2:h4S@R^1:d00Woo00@8[PR]Oomoo`@8[P9oo`083:h8[WooOol<c`R^3<h8
[P9oo`083<l8cWooOol<c`c>3<l<cP9oo`033<moogoo00@<c`9oo`063<l@
k`c?4?0<ka3_0Woo00D@ka3`3>l@l13_009oo`054?0@ka3`4>l@l002Ool0
2a3`OomooaD@4?0E414@5A0A41D@4A000Woo00/E4AD@OomooaDA5A0E4AD@
5C4E41Da009oo`075A4I<ADA6C4E<ATa5C400Woo00<I<ADa6C400Woo00@I
<ATb6C4I<P9oo`0<6C5oogoo7E8IDAeB6E4MDQUB7E8IDQeB0Woo00<IDQeB
7E800QeB0Woo0QeB00DMLgooOolMDR5c009oo`047G8QLaeb8G<2Ool011ec
8G=oogoo0R5c0Woo0b5c00@QTgooOolQL`9oo`048I@QTbFD8I<2Ool012FD
8I<UU26C0bFD00XUTbFD9I@U]2FD9K@UU2Fd9I@Y]0<U]00B:KDU]2Vd9K@Y
]BFd:KDU]2Ve:K@Y]BFd:MDY]2WE:K@YeBVe1RWE01@]eBWE;MDYeBgF:MD]
eBWE;MH]eBgF:MD]mRgE;OH]eBgf;OD]mRge12gf040amRgf<OH]mS7f;OHa
mRgf<OH]mS7f;OHb5c7f<QLamS8G<QHb5c8F<QLb5S8G<QHf5c8G=QLb5cHG
<QLf5c8G=QLb5cHG<QLf=cHG=SLf5cHh=SLf>3Hg=SPf=cHh=SLj>3Hg>SPf
=cXh=SPj>3Hh>SPf>3YH=SPjF3Xh>UPj>0@jF00B>UTjF3YI>UPnFCYH>UTj
F3iI>UPnFCYH?WTjFCii>UPnNCiI2Sii00a2NSii?WXnND9j?WU2NSii@YXn
ND:J?WT3@YX00d:I@YY2VP0:@YX044JK@YY6VT:JA[]2VTJk@YY6^dJjA[]2
^TJkA[Y6^dJj24Jk01A:^dJkB[]6^d[LA[]:fdJkB]a6fd[LA]]:g4[KB]a:
fd[LB]]:g4[K14[L02A>o4[LC_a:g4klB]a>o4[LC_a:o4klB_a>oDklC_e>
o4kmC_a>oDklC_e>o4kmC_aC7DkmDae>oE<MCaeC7DlMDae?7E<MCad4Dad0
55<NDaeC7U<MDaiC7E<NDaeG?U<MEciC7ELnDciG?U<nEciC?ULnDch2Ech0
0gooJeU[F@02JeT20004JeT20003JeT0148@8@QC?U<n0V]I0D8@0B480000
16]IOom[FF]I0PB=0Woo0`B=00@8[PB=2:h4S@9oo`042:ioogoo1:d32:h2
Ool22:h2Ool32:h01@S>Oomoo`R^3<h00Woo00@8cPc?2<h<c`9oo`073<io
ogoo3<l<cPc?3<h00Woo00<<k`c?Ool01Goo00`@k`c_4>l<ka3`3>l@l13_
4?0@ka3`4>l2Ool02a3`Oomooa3_4A0@l1D@4?0E414@5A000Woo00LA41D@
OomooaD@5A4A40025A002aDA5A1oogoo5C4E41Da5A0I<AD@6C400Woo00<E
<ATa5C400Woo0aTa00@E<GooOolI<P9oo`096C4IDQTa6E8IDAeB6E4IDQUA
009oo`067E8IDQeB6E4MDQUB0Woo0QeB0Woo00@MLQeBOomoo`8MLP068G<M
LWooOolQLaeb0Woo00HQLaebOomoob5c7G828G<2Ool0126COomoob5c0b6C
0Woo00/QTbFD8I<UU26C9I@QTbFD8I<UU26C008UU0069K@UTbFd9I@U]2FD
1RFd018Y]2Fd:K@U]2Ve9K@Y]BFd:KDU]2Ve:K@YeBVd:MDY]2WE:M@6:MD0
5RgE:MD]eBWE;MDYeBgE:MD]eRWE;MH]eBgf:MD]mRge;OH]mBgf;OD]mRge
0Rgf00hamRgf<OH]mS7f;OHamRgf<QH]mS8F<OHb5bgf0S8F01Hb5c8F<QLb
5S8G<QHb5c8F=QLb5SHG<QLf5c8G=QLb5cHg<QLf=c8G=SLb5`8f=`0F=SPf
=cHg=SLf>3Hg=SPf=cXh=SLf>3Hg>SPf=cXh=SPjF3Hg>UPf>3YH=SP6>UP0
4SYI>UPjF3YH>UTjF3YI>UPnFCYH?UTjF3ii>UPnNCYi?WTjN0hnN@0:@WXn
ND:J?WU2VSii@YXnVD:J?YT3@YX00d:I@YY2VP08@YX04TJj@YY6^T:JA[]2
VTJk@[Y6^d:jA[]6^TJkA[Y6^dJjA[]6^PI6^`0FB]]6^d[KA[]:fdJkB]]6
fd[LA]]:g4[KB]a6fd[LB]]:g4[KB]a:fd[LB]/2B]`02TklB]a>o4[LC_a:
o4klB_a>o4[l0Tkl00i>oD[lC_a>o4kmC_a>oDklC_e>o4kmC_aC7Dkl0TlM
00YC7DlMDae?7E<MCaeC7DlMDae?7@9C7@0BDaiC7E<MDaeC?U<MDciC7ELn
DaeC?U<mEciC?ELnDciG?Woo16]I0`000V]I0`000f]I00A24248DciC?P9[
F@52404Q200000I[FGooJeU[F@R>18d2Ool010R^18d8[PB=0`R^0Woo00<8
[WooOol010R^0Woo0PR^0Woo00@<cPR^3<l8[P9oo`083<l<cWooOol<c`c>
3<l<cP9oo`033<moogoo00<<c`044>moogoo3<l6Ool02a3`3>l@l13_4?0@
ka3`4>l@l13_4?0017oo00<@l7ooOol01Woo00HE414@OomooaDA5A08Ool0
2QTaOomooaDA6C4E<ATa5C4I<ADa0Woo0aTa0Woo00@I<ATb6C4I<P9oo`0<
6C5oogoo7E8I<AeB6E8MDQUA7E8IDQeB0Woo1QeB0Woo00LMDQecOomooaeB
7G<MLP07Ool011eb8G=oogoo0R5c0Woo00@QLb6C8G<QT`9oo`078I=oogoo
9I@QTbFD8I<00Woo00<UU26C9I@00RFD00<QTbFD9I@00RFD00@U]2FD9K@U
U0@U]00D:KDU]2Vd9K@Y]BFd:KDU]2Ve:K@Y]BFd:KDY]2Ve:K@YeBVe:MDY
]@@Ye@0D;MDYeBgE:MD]eRWE;MDYeBgF:MD]eRWE;MH]eBgf;MD]mRgE;OH]
e@@]mP10<OH]mS7f;OHamRgf<OH]mS7f;OHamRgf<QLamS8G<OHb5c8F<QLb
5S8G<QHb5c8F=QLb5cHG<QLf5c8G=QLb5cHG<QLf5c8G=SLf5cHg=QLf>3Hg
=SPf=cHh=SLf>3Hg>SPf=cXh=SLj>3Hh>SPf=cXh=SPj>3Hh>UPj>3YH>SP4
>UP053YI>UPjFCYH?UTjF3YI>UPnFCYH?UTjF3iI>UTnFCYH?WTnFCii?UT8
?WT043ij?WTnNCii@WXnND9j?WU2VSii@YXnND:J@WY2VSjI34:J0116Vd:J
AYY2VTJk@YY6^d:JA[]6^TJk@[Y6^dJjA[]6^PQ6^`0DB[]6^dZkA[]:g4Jk
B]]6^d[LA]]:g4KKB]a:fd[LB]]:g4[KB]a:f`A:g00TC]a:g4kLB]a>o4[L
C_a:g4klB_a>o4[lC_e>o4kmC_a>oDklC_e>o4kmC_a>oDklD_e>oE<MC_eC
7DkmDae>oE<MCaeC7DlM15<M01AC7U<MDaiC7E<NDaeC7U<MEciC7E<nDaeG
?U<NEciC?ELnDciG?U<n15Ln00=oof]IJeT00f]I1P0016]I00A24248DciC
?P9[F@52404Q200000A[FGooJeU[F@84S@9oo`0718d8[PB=2:h4S@R^18d0
0Woo00L8[WooOol8[@R^2:d8[P02Ool22:h2Ool32:h01@c>Oomoo`R^3<l0
0Woo00@8cPc?2<h<c`9oo`053<ioogoo3<l<cP023<l2Ool03Pc?Oomoo`c?
4>l<ka3_3>l@k`c_4?0<ka3`4>l7Ool0213_4?1oogoo4?0E413`5A02Ool0
1Q4@5A1oogoo4A0E409oo`044A0E41D@5A42Ool01aD@OomooaDa5A0I<AD@
008E<@066C5oogoo5C4I<ADa0Woo00@I<ADa6C4I<@9oo`0<6C5oogoo6C4I
DQTa7E8I<AUB6E4MDQUA0Woo00HMDQUA7E8IDQeB6E82Ool27E82Ool021eb
7E8MLQeB7G<MLQec7G82Ool01R5c7G9oogoo8G<ML`9oo`@QL`9oo`038I=o
ogoo00@QT`9oo`0A8I<UU26C9I@QTbFD8I<UU26C9I@UTbFd9I<U]2FD9K@U
U0069K@04RVd9K@Y]2Fd:KDU]2Ve9K@Y]BFd:KDY]2WE:K@YeBVd:MDY]0HY
e@0F;MDYeBgE:MD]eBWE;MDYeBgF:MD]eRgE;OHYeBgf;MD]mRgE;OH]mBgf
;OD2;OH03S7f;OHamRgf<OH]mS7f;OHamRgf<OH]mS8G;OH2<QH02S8G<QHb
5c8F<QLb5S8G<QHf5c8F0S8G00Xf5c8G=QLb5cHG<QLf=c8G=SLb5`8f=`0F
=SPf=cHg=SLf>3Hg=SPf=cXh=SLf>3Hg>SPf=cXh=SPjF3Hg>UPf>3YH=SP:
>UP03SYI>UPjFCYH?UTjF3iI>UPnNCYH?WTjFCii>UP>?WT03T9j?WU2NSii
@YXnND:J?WU2VSjI@YY2VD:J@YT:@YX04TJJ@YY6VT:JA[]2VTJk@[Y6^d:j
A[]6^TJk@[Y6^dJjA[]6^PI6^`0FB]]6^d[KA[]:fdJkB]]6fd[LA]]:g4[K
B]a6fd[LB]]:g4[KB]a:fd[LB]/2B]`03TklB]a:o4[LC_a:g4klB_a>o4[l
C_a:o4kmB_`2C_`05TkmC_a>oDklC_e>o4kmC_aC7DklCae>oE<MC_eC7DlM
Dae?7E<MCaeC7DlM0U<M01AC7U<MDaeC7E<NDaeC7U<MDciC7E<nDaeG?U<m
EciC?ULnDceG?Woo1V]I10001F]I00A24248DciC?P9[F@52404Q200000I[
FGooJeU[F@R>18d2Ool01`R^18d8[PB=2:h4[@R^009oo`042:eoogooOol2
2:h2Ool00`R^3:h8[P02Ool010c?2:h<cPR^0Woo00<<c`S>3<l00Woo00H<
cPc?Oomoo`c>3<l3Ool33<l2Ool03@c?Oomooa3`3>l@k`c_Ool@ka3`3>l@
l13_00Eoo`034>l@l13`008@l0065A1oogoo4?0E414@0Woo00LE414@Oomo
oaDA5A0E4@02Ool00aD@5A4E4002Ool02QDa5A1oogoo6C4E4ATaOolI<ADa
0Woo00@I<ADa6C4I<@9oo`066C8I<GooOolIDQTa1Woo00DMDQUB7E8IDQeB
009oo`036E8MDQeB00<MDP9oo`0<7E8MLgooOolMDR5c7G9ooaeb8G<MLR5c
0Woo00@MLb5cOomoo`<QL`9oo`8QL`9oo`038I<QLbFD009oo`038I<UU26C
009oo`049I@QTbFD8I<39I@02RFC9I@UU2Fd9I@U]2FD9K@UU2Vd0bFd018Y
]BFd:K@U]2Ve9K@Y]BFd:KDY]2Ve9K@YeBVd:MDY]2WE:KD6:MD052gE:MD]
eBWE;MHYeBgE:MD]eRgE;MHYeBgf;MD]mRgE;OH]mBgf;OD4;OH0@37f;OHa
mRgf<OH]mS7f;OHamRgf<OH]mS8G<OHb5c7f<QLb5S8G<QHb5c8F<QLb5SHG
<QLf5c8G=QLb5cHG<QLf5c8G=QLb5cHg=QLf=cHG=SPf=cHh=SLf>3Hg=SPf
=cXh=SLj>3Hg>SPf>3Xh=SPj>3Hh>UPf>3YH>SPjF3Xh13YH018jFCYH>UTj
F3iI>UPjFCYH?UTjF3iI>UPnNCYI?WTjF3ii?UT:?WT0349j?WTnNSii@WXn
ND9j?WU2VSii@YXnN@=2VP03@YU2VT:J00Y2VP0@AY]2VTJJ@YY6^d:JA[]2
VTJkA[Y6^d:jA[]6^TJkA[X8A[/054ZkA[]:^dJkB]a6^d[KA[]:g4KKB]a6
fd[LB]]:g4[KB]a:fd[LB]/4B]`094klB]a>o4[LC_a:g4klB]a>o4[lC_a:
o4kmC_a>oDklC_e>o4kmC_a>oDklC_e>o5<MC_eC7DkmDae?7E<MCaeC7DlM
Dae?7@AC7@0DDaiC7E<NDaeC7U<MDaiC7ELnDaeG?U<MEciC?ULnDciG?U<n
EciC?P9G?P03Oom[FF]I00A[F@@000E[F@04@Q0Q25<nDch2JeT1@Q018@P0
0004JeUoof]IJeT218d2Ool318d010R^18d8[PB=0Woo00@8[WooOol4[@=o
o`032:d8[PR^00Eoo`082:h8cWooOol8[Pc>2<h<c`Aoo`032<h<c`c>009o
o`033<moogoo009oo`033<l<k`c?00Eoo`063>l@k`c_4>l<ka3`0Woo00X@
ka3`4>l@l13_4?0@ka3`4>lA40Eoo`035A0A41D@009oo`044A0E414@5A05
Ool011DA5A0E4AD@17oo00<I<AD@Ool017oo00<E<ATa5C4017oo0QTa00@I
<WooOolI<@=oo`056E4MDQUA6E8ID@02Ool01QeB6E8MDQUA7E8IDP9oo`8M
DP9oo`047G8MDQec7E85Ool00aeb8G<MLP02Ool0125c7G8QLaec17oo00DQ
Tb5c8I<QLb6C00Ioo`0;8I<UU26C9I@QTbFD8I<UU26C9I@QT`029I@01RFd
9I<U]2FD9K@UU0HU]00B:K@U]2Vd9K@Y]BFd:KDU]2Ve9K@Y]BVd:MDY]2WE
:K@YeBWD1RWE01H]eBWE;MDYeBgE:MD]eBWE;MHYeBgF;MD]mRWE;OH]mBgf
;OD]mRge;OH]m@8]mP0><OH]mS7f;OHamRgf<OH]mS8F;OHb5S7f<QL]mP8b
5P0F<QLb5S8G<QHb5c8F<QLb5SHG<QHf5c8G=QLb5cHG<QLf=c8G=SLb5cHg
<QL2=SL05SHh=SLf=cHg=SPf=cHh=SLj>3Hg=SPf=cXh=SLj>3Hh>UPf=cYH
=SPjF3Hh1SYH018jFCYH>UPjF3YI>UPjFCYH?UTjF3iI>UPnNCYH?WTjNCii
>WP>?WT02T9j?WU2VSii@YXnND:J?YU2VSjI0d:J00=2VD:J@YX024:J0196
^T:JA[Y2VTJk@YY6^d:jA[]2^TJkA[Y6^dJjA[]6^TJkA[X6A[/05T[KA[]:
fdJkB]]6^d[KA]]:g4KKB]a:fd[LA]]:g4[KB]a:fd[LB]]:g4[K0T[L00Y>
o4[LC_a:g4klB_a>o4[lC_a:o09>o00>C_e:o4klC_a>oDklC_e>o4kmC_a>
oDklDae>o09?7@0:Dae?7E<MCaeC7DlMDae?7E<MCad2Dad04U<NDaeC7E<M
DciC7E<nDaeG?U<MDciC?ELnDceG?U<nEcioo`E[F@H000A[F@04@Q0Q25<n
Dch2JeT1@Q018@P00007JeUoof]IJeT8SPB=28h00Woo00<4S@R^18d00PR^
0Woo30R^0Woo00h<cPR^3<l8[Pc?2:h<c`c>3<l8cPc?3<h<c`c>20c?010@
k`c?4>l<ca3`3>l@k`c_4?0@ka3`3>l@l13_4?0@k`9oo`034?0@ka3`008@
l09oo`0;4?0E413`5A0A41D@4A0E414@5A0A4002Ool051DA5A0E4AD@5A4E
41DA5A0E4AD@6C4E4ATa5A4I<ADa6C4E<ATa5C42Ool46C404aTb6C4I<QTa
6C8I<AUB6C4MDQTa7E8I<AeB6E8MDQUA7E8IDQeB009oo`DMDP9oo`0A7G<M
DQec7E8QLaeB7G<MLR5c7G8QLaeb8G<MLb5c7G8QL`02Ool58G<01B6C8G<Q
Tb5c9I@00b6C00PUU26C9I@QTbFD8I<UU26C0bFD00<QTbFD9I@00RFD00@U
]2FD9K@UU0@U]00D:KDU]2Vd9K@Y]BFd:KDU]2Ve:K@Y]BFd:KDY]2Ve:K@Y
eBVe:MDY]@@Ye@0D;MDYeBgE:MD]eRWE;MDYeBgF:MD]eRWE;MH]eBgf;MD]
mRgE;OH]e@@]mP10<OH]mS7f;OHamRgf<OH]mS7f;OHamRgf<QLamS8G<OHb
5c8F<QLb5S8G<QHb5c8F=QLb5cHG<QLf5c8G=QLb5cHG<QLf5c8G=SLf5cHg
=QLf>3Hg=SPf=cHh=SLf>3Hg>SPf=cXh=SLj>3Hh>SPf=cXh=SPj>3Hh>UPj
>3YH>SP4>UP053YI>UPjFCYH?UTjF3YI>UPnFCYH?UTjF3iI>UTnFCYH?WTn
FCii?UT8?WT043ij?WTnNCii@WXnND9j?WU2VSii@YXnND:J@WY2VSjI34:J
0116Vd:JAYY2VTJk@YY6^d:JA[]6^TJk@[Y6^dJjA[]6^PQ6^`0DB[]6^dZk
A[]:g4JkB]]6^d[LA]]:g4KKB]a:fd[LB]]:g4[KB]a:f`A:g00TC]a:g4kL
B]a>o4[LC_a:g4klB_a>o4[lC_e>o4kmC_a>oDklC_e>o4kmC_a>oDklD_e>
oE<MC_eC7DkmDae>oE<MCaeC7DlM15<M01AC7U<MDaiC7E<NDaeC7U<MEciC
7E<nDaeG?U<NEciC?ELnDciG?U<n15Ln00=oof]IJeT00V]I0`000V]I0`00
0f]I00A24248DciC?P9[F@52404Q200000A[FGooJeU[F@<4S@=oo`0318d8
[PB=00=oo`071:d8[PB]2:h8[@R^2:d01@R^0Woo0`R^018<cWooOol8[Pc?
2<h<c`S>3<l8cPc?3<h<c`c>3<l<cPc?3<h63<l0313_3<l@k`c_4>l<ka3_
3>l@l0c_4?0@k`9oo`044?0@ka3`4>l2Ool02a3`4>lA413`5A0@l1D@4A0E
414@5A000Woo00DA41D@5A0E4A4@008E400:5A4E41DA5A0E<AD@5C4E41Ta
5A025C402QTaOomooaDa6C4E<ATa5C4I<ADa0QTa00hI<QTa6C4I<AUB6C4I
DQTa7E8I<AUB6E4MDQUA0Woo00@MDQUA7E8IDP=oo`<MDP9oo`0<7G8MDQeb
7E8MLaeb7G<MLR5c7G8QLaeb0Woo00@QLaec8G<MLP@QL`048I<QLb6C8G<6
8I<04RFD8I<UU26C9I@QTbFD8I<UU26C9I@UTbFd9I<U]2FD9K@UU0HU]00B
:K@U]2Vd9K@Y]BFd:KDU]2Ve9K@Y]BVd:MDY]2WE:K@YeBVd1RWE01H]eBWE
;MDYeBgE:MD]eBWE;MHYeBgF;MD]mRWE;OH]eBgf;MD]mRge;OH]m@8]mP0>
<OH]mS7f;OHamRgf<OH]mS7f;OHamRgf<QL]mP8b5P0:<QLb5S8G<QHb5c8F
<QLb5SHG<QH2<QL02SHG<QLf5c8G=QLb5cHg<QLf=c8G0SHg01Hf>3Hg=SLf
=cHh=SLf>3Hg>SPf=cHh=SLj>3Hg>SPf>3YH=SLjF3Hh>UPf>0XjF00>>UTj
F3YI>UPnFCYH?UTjF3ii>UPnNCYI?WTjF0hnN@0>@WXnND9j?WU2VSii@YXn
ND:J?YU2VT:I@YY2V@Y2VP0BAYY2VTJJ@YY6^d:JA[]2^TJk@[Y6^dJjA[]2
^TJkA[Y6^dJj1TJk01I:fdJkB]]6^d[KA[]:fdKKB]a6fd[LB]]:g4KKB]a:
fd[LB]]:g4[KB]a:f`9:g00>C_a:g4[lB]a>o4[LC_a:o4klB_a>o4[lC_e:
o09>o00FC_e>o4kmC_a>oDklC_e>o5<MC_a?7DkmDae>oE<MCaeC7DlMDae?
7E<MCad2Dad055<NDaeC7E<MDaiC7E<NDaeC?U<MDciC7ELnDceG?U<nEciC
?ELnOol4JeT20004JeT20003JeT0148@8@QC?U<n0V]I0D8@0B4800002F]I
Oom[FF]I28h4S@R^18d8[P05Ool32:h00`R]2:h8[P062:h020b^2:h8[PR^
3<l8[Pc>2:h2Ool02Pc?2<h<c`c>3<l<cPc?3<h<c`c>20c?010@k`c?4>l<
ca3`3>l@k`c_4?0@ka3`3>l@l13_4?0@k`Ioo`8@l00:5A0@l1D@4?0E414@
5A0A41D@4A02Ool061DA5A0E4AD@5A4E41DA5A0E<AD@5C4E41Ta5A4I<ADA
6C4E<ATa5C4I<ADa6C4E<@@I<@0A6C8I<ATb6C4IDQTa6E8I<AeB6E4MDQUA
7E8IDQeB6E8MDP07Ool47E803aecOomooaeB8G<MLR5c7G8QLaeb8G<MLR5c
7G<QL`02Ool78G<0426C8G<QTb5c9I@QTb6D8I<UU26C9I@QTbFD8I<UU26C
0bFD00XUTbFD9I@U]2FD9K@UU2Fd9I@Y]0<U]00B:KDU]2Vd9K@Y]BFd:KDU
]2Ve:K@Y]BFd:MDY]2WE:K@YeBVe1RWE01@]eBWE;MDYeBgF:MD]eBWE;MH]
eBgF:MD]mRgE;OH]eBgf;OD]mRge12gf040amRgf<OH]mS7f;OHamRgf<OH]
mS7f;OHb5c7f<QLamS8G<QHb5c8F<QLb5S8G<QHf5c8G=QLb5cHG<QLf5c8G
=QLb5cHG<QLf=cHG=SLf5cHh=SLf>3Hg=SPf=cHh=SLj>3Hg>SPf=cXh=SPj
>3Hh>SPf>3YH=SPjF3Xh>UPj>0@jF00B>UTjF3YI>UPnFCYH>UTjF3iI>UPn
FCYH?WTjFCii>UPnNCiI2Sii00a2NSii?WXnND9j?WU2NSii@YXnND:J?WT3
@YX00d:I@YY2VP0:@YX044JK@YY6VT:JA[]2VTJk@YY6^dJjA[]2^TJkA[Y6
^dJj24Jk01A:^dJkB[]6^d[LA[]:fdJkB]a6fd[LA]]:g4[KB]a:fd[LB]]:
g4[K14[L02A>o4[LC_a:g4klB]a>o4[LC_a:o4klB_a>oDklC_e>o4kmC_a>
oDklC_e>o4kmC_aC7DkmDae>oE<MCaeC7DlMDae?7E<MCad4Dad055<NDaeC
7U<MDaiC7E<NDaeG?U<MEciC7ELnDciG?U<nEciC?ULnDch2Ech00gooJeU[
F@0=JeT0148@8@QC?U<n0V]I0D8@0B48000016]IOom[FF]I1`B=00X8[PB=
2:h4S@R^1:d8[PB]2:h4[@<8[P032:d8[PR^00H8[P0D2<h8[Pc>2:h<cPS>
3<l8cPc?2<h<c`S>3<l<cPc?3<h<c`c>3<l<cP8<c`0Q3>l<c`c_3<l@k`c?
4>l<ka3_3>l@k`c_4?0<ka3`4>l@l13_4?0@ka3`4>l@l13_4A0@ka4@4?0E
413`5A0A41D@009oo`034A0E414@008E400F5A4A41D@5A0E4AD@5A4E41Da
5A0E<AD@6C4E41Ta5C4I<ADa6C4E<ATa5C436C4011Da6C4I<ATb0aTa018I
DQTa6E8IDAeB6E4IDQUA7E8IDAeB6E8MDQUA7E8IDQeB6E847E8011eb7E8M
LaeB0Qeb00HQLaeb7G<MLR5c7G82Ool01R5c7G8QLaec8G<MLP8QL`068I<Q
Lb6C8G<QTb5c1R6C00XUU26C9I@QTbFD8I<UU26C9I@QT`8UU0069K@UTbFd
9I@U]2FD1RFd018Y]2Fd:K@U]2Ve9K@Y]BFd:KDU]2Ve:K@YeBVd:MDY]2WE
:M@6:MD05RgE:MD]eBWE;MDYeBgE:MD]eRWE;MH]eBgf:MD]mRge;OH]mBgf
;OD]mRge0Rgf00hamRgf<OH]mS7f;OHamRgf<QH]mS8F<OHb5bgf0S8F01Hb
5c8F<QLb5S8G<QHb5c8F=QLb5SHG<QLf5c8G=QLb5cHg<QLf=c8G=SLb5`8f
=`0F=SPf=cHg=SLf>3Hg=SPf=cXh=SLf>3Hg>SPf=cXh=SPjF3Hg>UPf>3YH
=SP6>UP04SYI>UPjF3YH>UTjF3YI>UPnFCYH?UTjF3ii>UPnNCYi?WTjN0hn
N@0:@WXnND:J?WU2VSii@YXnVD:J?YT3@YX00d:I@YY2VP08@YX04TJj@YY6
^T:JA[]2VTJk@[Y6^d:jA[]6^TJkA[Y6^dJjA[]6^PI6^`0FB]]6^d[KA[]:
fdJkB]]6fd[LA]]:g4[KB]a6fd[LB]]:g4[KB]a:fd[LB]/2B]`02TklB]a>
o4[LC_a:o4klB_a>o4[l0Tkl00i>oD[lC_a>o4kmC_a>oDklC_e>o4kmC_aC
7Dkl0TlM00YC7DlMDae?7E<MCaeC7DlMDae?7@9C7@0BDaiC7E<MDaeC?U<M
DciC7ELnDaeC?U<mEciC?ELnDciG?Woo3f]I00A24248DciC?P9[F@52404Q
200000a[FGooJeU[F@R>18d8SPB=2:h4S@R^18d32:h00`R]2:h8[P0:2:h0
40c?2:h<cPR^3<l8[Pc?2:h<c`c>3<l8cPc?3<h<c`c>20c?01@@k`c?4>l<
ca3`3>l@k`c_4?0@ka3`3>l@l13_4?0@ka3`4>l@l13_113`02@E413`5A0@
l1D@4A0E414@5A0A41D@4A0E4AD@5A4E41DA5A0E4AD@5A4E41DA5A0I<ADA
6C4E4ATa5C4I<ADa6C4E<ATa5C446C4051Tb6C4I<QTa6C8I<AUB6C4MDQTa
7E8I<AeB6E8MDQUA7E8IDQeB6E887E8041ec7E8MLaeB8G<MDQec7G8QLaeb
8G<MLR5c7G<QLaeb225c00DQTb5c8I<QLbFD00<QT`089I@QTbFD8I<UU26C
9I@QT`<UU0038I<UU2FD008UU0049K@UU2Fd9I@49K@052Ve9K@Y]2Fd:KDU
]2Ve9K@Y]BVd:KDU]2Ve:K@Y]BVd:MDY]BWE:KD4:MD052gE:MD]eBWE;MHY
eBgE:MD]eRWE;MHYeBgF;MD]mRgE;OH]eBgf;MD4;OH0@37f;OHamRgf<OH]
mS7f;OHamRgf<OH]mS8G<OHb5c7f<QLb5S8G<QHb5c8F<QLb5SHG<QLf5c8G
=QLb5cHG<QLf5c8G=QLb5cHg=QLf=cHG=SPf=cHh=SLf>3Hg=SPf=cXh=SLj
>3Hg>SPf>3Xh=SLj>3Hh>SPf>3YH>SPjF3Xh13YH01@jFCYH>UTjF3iI>UPj
FCYH?UTjF3iI>UPnFCYI?UTjF3ii?UTnNCiI23ii010nNSii?WTnND9j?WU2
NSii@YXnND:J?WU2VT9j@YXnV@a2VP0@AY]2VTJJ@YY6^d:JA[]2VTJkA[Y6
^d:jA[]6^TJkA[X8A[/054ZkA[]:^dJkB]a6^d[KA[]:g4KKB]a6fd[LB]]:
g4[KB]a:fd[LB]/4B]`094kLB]a>g4[LC_a:g4klB]a>o4[lC_a:o4kmC_a>
oDklC_e>o4kmC_a>oDklC_e>o5;mC_eC7DkmDae>oE<MC_eC7DlMDae?7@AC
7@0DDaiC7E<NDaeC7U<MDaiC7ELnDaeC?U<MEciC7ULnDceG?U<nEciC?PAG
?P03Oom[FF]I00e[F@04@Q0Q25<nDch2JeT1@Q018@P00004JeUoof]IJeT5
18d03PR^18d8[PB=2:h4S@R^1:d8[PB]2:h8[@R^2:d:2:h04Pc>2:h<cPR^
3<l8cPc?2<h<c`S>3<l<cPc?3<h<c`c>3<l<cPH<c`0R4>l<ca3_3>l@k`c_
4>l<ka3`3>l@l13_4?0<ka3`4>l@l13_4?0@ka3`4>lA413`5A0@l1D@4A0E
414@5A0A41D@4A025A003QDA4A0E41D@5A4E41DA5A0E<AD@5C4E41Ta5A02
5C402QTa5C4I<ADa6C4E<ATa5C4I<ADa0QTa01HI<QTa6C4I<AUB6C4IDQTa
7E8I<AUB6E4MDQUA7E8IDQeB6E4MDQUB7E8IDPHMDP0B7G8MDQeb7E8MLaeb
7G<MLR5c7G8QLaeb8G<MLR5c7G<QLaeb125c00@QTb5c8I<QL`HQT`0B9I@Q
TbFD8I<UU26C9I@QTbFD8I<UU2FC9K@UTbFd9I@U]2FD1RFd018Y]2Fd:K@U
]2Ve9K@Y]BFd:KDU]2Ve:K@YeBVd:MDY]2WE:K@6:MD05RgE:MD]eBWE;MDY
eBgE:MD]eRWE;MH]eBgf:MD]mRgE;OH]eBgf;OD]mRge0Rgf00hamRgf<OH]
mS7f;OHamRgf<OH]mS7f;OHb5bgf0S8F00Xb5c8F<QLb5S8G<QHb5c8F=QLb
5P8b5`0:=QLb5cHG<QLf5c8G=SLb5cHg<QL2=SL05SHh=SLf=cHg=SPf=cHh
=SLj>3Hg=SPf=cXh=SLj>3Hh>UPf=cYH=SPjF3Hh2SYH00hjFCYH>UTjF3iI
>UPnFCYH?WTjF3ii>UTnNCYH3Sii00i2NSii@WXnND:J?WU2VSii@YXnVD:J
@YU2VT:I2T:J0196VT:JAYY2VTJk@YY6^d:jA[]2^TJkA[Y6^d:jA[]6^TJk
A[X6A[/05T[KA[]:fdJkB]]6^d[KA]]:g4KKB]a:fd[LA]]:g4[KB]a:fd[L
B]]:g4[K0T[L00i>o4[LB_a:g4klB]a>o4[lC_a:o4klB_a>oD[l0Tkl01I>
oDklC_e>o4kmC_a>oDklDae>o4lMC_eC7DkmDae?7E<MCaeC7DlMDae?7@9C
7@0CDaiC7E<MDaeC7U<MDaiC7E<nDaeC?U<MEciC?ELnDciG?U<mEch04Goo
00<Q25<nDch00V]I0D8@0B4800003V]IOom[FF]I28h4S@R^18d8[PB=2:h4
S@R^1:d32:h00`R]2:h8[P062:h050b^2:h8[PR^3<l8[Pc>2:h<c`S>3<l8
cPc?3<h<c`c>3<l<cPc?3<h83<l0513_3<l@k`c?4?0<ka3_3>l@l13_4?0<
ka3`4>l@l13_4?0@ka3`4>l44?0091D@4?0E413`5A0A41D@4A0E414@5A0A
41DA5A0E4AD@5A4E41DA5A0E<AD@5C4E41Ta5A4I<ADA6C4E<ATa5C4I<ADa
6C4E<@@I<@0D6C8I<ATb6C4IDQTa6E8I<AeB6E4MDQUA7E8IDQeB6E8MDQUB
7E8IDPPMDP0@7G<MDQec7E8QLaeb8G<MLR5c7G8QLaeb8G<MLb5c7G888G<0
426C8G<QTb5c9I@QTb6D8I<UU26C9I@QTbFD8I<UU26C0bFD00XUTbFD9I@U
]2FD9K@UU2Fd9I@Y]0<U]00B:KDU]2Vd9K@Y]BFd:KDU]2Ve:K@Y]BFd:MDY
]2WE:K@YeBVe1RWE01@]eBWE;MDYeBgF:MD]eBWE;MH]eBgF:MD]mRgE;OH]
eBgf;OD]mRge12gf040amRgf<OH]mS7f;OHamRgf<OH]mS7f;OHb5c7f<QLa
mS8G<QHb5c8F<QLb5S8G<QHf5c8G=QLb5cHG<QLf5c8G=QLb5cHG<QLf=cHG
=SLf5cHh=SLf>3Hg=SPf=cHh=SLj>3Hg>SPf=cXh=SPj>3Hh>SPf>3YH=SPj
F3Xh>UPj>0@jF00B>UTjF3YI>UPnFCYH>UTjF3iI>UPnFCYH?WTjFCii>UPn
NCiI2Sii00a2NSii?WXnND9j?WU2NSii@YXnND:J?WT3@YX00d:I@YY2VP0:
@YX044JK@YY6VT:JA[]2VTJk@YY6^dJjA[]2^TJkA[Y6^dJj24Jk01A:^dJk
B[]6^d[LA[]:fdJkB]a6fd[LA]]:g4[KB]a:fd[LB]]:g4[K14[L02A>o4[L
C_a:g4klB]a>o4[LC_a:o4klB_a>oDklC_e>o4kmC_a>oDklC_e>o4kmC_aC
7DkmDae>oE<MCaeC7DlMDae?7E<MCad4Dad055<NDaeC7U<MDaiC7E<NDaeG
?U<MEciC7ELnDciG?U<nEciC?ULnDch2EchDDch2JeT1@Q018@P00004JeUo
of]IJeT718d02PR^18d8[PB=2:h4[@R^1:d8[PB]0`R^00<8[@R^2:h01PR^
01@8cPR^3<h8[Pc>2<h<c`S>3<l8cPc?2<h<c`c>3<l<cPc?3<h<c`c>0Pc?
02H<k`c?3>l<ca3_3<l@k`c_4>l<ka3_3>l@l0c_4?0@ka3`4>l@l13_4?0@
ka3`4>lA413_4A0@l1D@4?0E414@5A0A41D@4A0E414@0QD@01HE4A4@5A0E
41DA5A0E4AD@5C4E41Da5A0I<AD@6C4E<ATa5C4I<ADa6C4E<@<I<@045C4I
<ATa6C836C404QUB6C4IDQUA7E8IDAUB6E4MDQUA7E8IDQeB6E4MDQUB7E8I
DP@MDP047G8MDQec7E827G803R5c7G8MLaeb8G<MLR5c7G8QLaeb8G<MLb5c
7G828G<01R6C8G<QTb5c8I<QL`HQT`0:9I@QTbFD8I<UU26C9I@QTbFD8I<2
9I@01RFd9I<U]2FD9K@UU0HU]00B:K@U]2Vd9K@Y]BFd:KDU]2Ve9K@Y]BVd
:MDY]2WE:K@YeBWD1RWE01H]eBWE;MDYeBgE:MD]eBWE;MHYeBgF;MD]mRWE
;OH]mBgf;OD]mRge;OH]m@8]mP0><OH]mS7f;OHamRgf<OH]mS8F;OHb5S7f
<QL]mP8b5P0F<QLb5S8G<QHb5c8F<QLb5SHG<QHf5c8G=QLb5cHG<QLf=c8G
=SLb5cHg<QL2=SL05SHh=SLf=cHg=SPf=cHh=SLj>3Hg=SPf=cXh=SLj>3Hh
>UPf=cYH=SPjF3Hh1SYH018jFCYH>UPjF3YI>UPjFCYH?UTjF3iI>UPnNCYH
?WTjNCii>WP>?WT02T9j?WU2VSii@YXnND:J?YU2VSjI0d:J00=2VD:J@YX0
24:J0196^T:JA[Y2VTJk@YY6^d:jA[]2^TJkA[Y6^dJjA[]6^TJkA[X6A[/0
5T[KA[]:fdJkB]]6^d[KA]]:g4KKB]a:fd[LA]]:g4[KB]a:fd[LB]]:g4[K
0T[L00Y>o4[LC_a:g4klB_a>o4[lC_a:o09>o00>C_e:o4klC_a>oDklC_e>
o4kmC_a>oDklDae>o09?7@0:Dae?7E<MCaeC7DlMDae?7E<MCad2Dad04E<N
DaeC7E<MDciC7E<nDaeG?U<MDciC?ELnDceG?U<nEch055<n0V]I0D8@0B48
00000f]IOom[F@3oJeWhJeT1@Q018@P00003JeUoof]I0?m[FOQ[F@52404Q
200000=[FGooOol0ogoon7oo0D8@0B48003oJeWlJeT18@P00001\
\>"], "Text",
  ImageSize->{508, 329},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Next time the activated options will be selected automatically.\
\>", "Text"],

Cell[TextData[{
  "Thus ",
  StyleBox["OptionSelector", "MR"],
  " can be used for quick glance on the options of a function and for support \
in entering of their values. But more efficient to use ",
  StyleBox["OptionSelector", "MR"],
  " with defined alternative and preset values of options."
}], "Text"],

Cell["\<\
Note that the described action will work only if the cursor will remain in \
the same position of the editing notebook while the dialog window is open.\
\>", "Text"]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
ScreenStyleEnvironment->"Working",
WindowSize->{676, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 38, 0, 39, "Subsection"],
Cell[1817, 55, 249, 7, 42, "Text"],
Cell[2069, 64, 112, 3, 25, "Text"],

Cell[CellGroupData[{
Cell[2206, 71, 54, 1, 29, "Input"],
Cell[2263, 74, 48, 1, 27, "Output"]
}, Open  ]],
Cell[2326, 78, 340, 11, 42, "Text"],

Cell[CellGroupData[{
Cell[2691, 93, 77, 1, 29, "Input"],
Cell[2771, 96, 49, 1, 40, "Output"]
}, Open  ]],
Cell[2835, 100, 567, 12, 76, "Text"],
Cell[3405, 114, 67699, 1112, 337, 67607, 1109, "GraphicsData", "Bitmap", \
"Text"],
Cell[71107, 1228, 138, 3, 25, "Text"],
Cell[71248, 1233, 642, 19, 100, "Text"],
Cell[71893, 1254, 609, 17, 59, "Text"],
Cell[72505, 1273, 278, 8, 42, "Text"],
Cell[72786, 1283, 412, 9, 59, "Text"],
Cell[73201, 1294, 66987, 1100, 337, 66895, 1097, "GraphicsData", "Bitmap", \
"Text"],
Cell[140191, 2396, 87, 2, 25, "Text"],
Cell[140281, 2400, 308, 7, 42, "Text"],
Cell[140592, 2409, 175, 3, 42, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

