(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6508,        235]*)
(*NotebookOutlinePosition[      7193,        258]*)
(*  CellTagsIndexPosition[      7149,        254]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["OptoinsExplorer Installation", "Section"],

Cell[CellGroupData[{

Cell["About", "Subsection"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has too many functions and it is not easy to remember all of their \
properties. ",
  StyleBox["OptionsExplorer", "MR"],
  " provides an interactive tool to simplify the work with options of the \
functions. It opens a dialog window designed for getting information about \
functions, selecting their values and inserting the activated options into \
the editing expression. In addition to the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " default set of options the package introduces alternative and preset \
options. Alternative options may include several values for a particular \
option thus any possible combination of alternatives can be selected. Preset \
options allow choosing extra sets of options."
}], "Text"],

Cell["\[Copyright] Yuri E. Kandrashkin, 2004-2006", "Text",
  TextAlignment->Right]
}, Open  ]],

Cell[CellGroupData[{

Cell["Installation", "Subsection"],

Cell[CellGroupData[{

Cell["Find the installation directory", "Subsubsection"],

Cell["\<\
Evaluate the following cell to get user base directory on your system: \
\>", "Text"],

Cell[BoxData[{
    \($BaseDirectory\), "\[IndentingNewLine]", 
    \($UserBaseDirectory\)}], "Input"],

Cell["This gives the folders where the package can be placed.", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Copy files to a selected directory", "Subsubsection"],

Cell[TextData[{
  "If previous version of ",
  StyleBox["OptionsExplorer", "MR"],
  " was installed remove its folder. Unpack and copy the directory ",
  StyleBox["OptionsExplorer", "MR"],
  " into ",
  StyleBox["Applications", "MR"],
  " subdirectory of ",
  StyleBox["$BaseDirectory", "MR"],
  " or ",
  StyleBox["$UserBaseDirectory", "MR"],
  ". \nThis allows loading the package through its context name or short \
path:"
}], "Text"],

Cell[BoxData[
    \(Needs["\<OptionsExplorer`\>"]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Rebuild Help Index", "Subsubsection"],

Cell[TextData[{
  "Execute the menu command ",
  StyleBox["Help \[RightTriangle] Rebuild Help Index", "SR"]
}], "Text"],

Cell[TextData[{
  "This adds ",
  StyleBox["OptionsExplorer", "MR"],
  " help file in ",
  StyleBox["Help", "SR"],
  " ",
  StyleBox["Browser", "SR"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Add menu and keyboard shortcut command", "Subsubsection"],

Cell[TextData[{
  StyleBox["OptionsExplorer", "MR"],
  " needs menu command to be added in file ",
  StyleBox["MenuSetup.tr", "MR"],
  ". To get path to this file evaluate next cell ",
  "(for OS Windows)",
  ":"
}], "Text"],

Cell[BoxData[
    \(ToFileName[{$TopDirectory, "\<SystemFiles\>", "\<FrontEnd\>", \
"\<TextResources\>", "\<Windows\>"}]\)], "Input"],

Cell[TextData[{
  "Create the subdirectories in the same order in your base directory and \
copy the file ",
  StyleBox["MenuSetup.tr", "MR"],
  " there. Insert the following lines after the ",
  StyleBox["Item[\"&Make Template\",...]", "MR"],
  ":"
}], "Text"],

Cell[TextData[StyleBox["\t, Item[\"Options &Explorer\", \
KernelExecute[ToExpression[\"OptionsExplorer[]\"]],\n \t\t\
MenuKey[\"o\",Modifiers->{Control,Command}], MenuEvaluator->Automatic]", \
"MR"]], "Text",
  CellFrame->True],

Cell[TextData[{
  "and restart ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  "
}], "Text"],

Cell[TextData[{
  "This adds new menu item ",
  StyleBox["Input \[RightTriangle] Options Explorer", "SR"],
  " and sets keyboard shortcut \[AltKey]",
  StyleBox["\[KeyBar]", "MR"],
  "\[ControlKey]\[LeftModified]o\[RightModified] (for Windows). These \
commands applied to selected function in input cell opens ",
  StyleBox["OptionExplorer", "MR"],
  " dialog window."
}], "Text"],

Cell[TextData[{
  "Note, this feature doesn't work on cells with format type ",
  StyleBox["InputForm", "SR"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Make autoloading package", "Subsubsection"],

Cell[TextData[{
  "Save in the directory ",
  StyleBox["Kernel", "MR"],
  " of your ",
  StyleBox["$BaseDirectory", "MR"],
  " or ",
  StyleBox["$UserBaseDirectory", "MR"],
  " the file ",
  StyleBox["init.m", "MR"],
  " with the following line (or add this line if the file ",
  StyleBox["init.m", "MR"],
  " already exists):"
}], "Text"],

Cell[TextData[{
  StyleBox["\tNeeds[\"", "MR"],
  StyleBox["OptionsExplorer", "MR"],
  StyleBox["`\"]", "MR"]
}], "Text",
  CellFrame->True],

Cell[TextData[{
  "This allows the package to load with the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " kernel. "
}], "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1152}, {0, 781}},
WindowSize->{496, 740},
WindowMargins->{{Automatic, 182}, {-36, Automatic}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 47, 0, 65, "Section"],

Cell[CellGroupData[{
Cell[1848, 57, 27, 0, 39, "Subsection"],
Cell[1878, 59, 808, 16, 144, "Text"],
Cell[2689, 77, 83, 1, 25, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2809, 83, 34, 0, 39, "Subsection"],

Cell[CellGroupData[{
Cell[2868, 87, 56, 0, 35, "Subsubsection"],
Cell[2927, 89, 95, 2, 25, "Text"],
Cell[3025, 93, 101, 2, 49, "Input"],
Cell[3129, 97, 71, 0, 25, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3237, 102, 59, 0, 35, "Subsubsection"],
Cell[3299, 104, 437, 13, 84, "Text"],
Cell[3739, 119, 62, 1, 29, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3838, 125, 43, 0, 35, "Subsubsection"],
Cell[3884, 127, 119, 3, 25, "Text"],
Cell[4006, 132, 168, 8, 25, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4211, 145, 63, 0, 35, "Subsubsection"],
Cell[4277, 147, 224, 7, 42, "Text"],
Cell[4504, 156, 133, 2, 49, "Input"],
Cell[4640, 160, 261, 7, 59, "Text"],
Cell[4904, 169, 227, 4, 100, "Text"],
Cell[5134, 175, 105, 5, 25, "Text"],
Cell[5242, 182, 381, 9, 59, "Text"],
Cell[5626, 193, 128, 4, 25, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5791, 202, 49, 0, 35, "Subsubsection"],
Cell[5843, 204, 339, 12, 59, "Text"],
Cell[6185, 218, 140, 5, 41, "Text"],
Cell[6328, 225, 140, 5, 25, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

